"""Sustainability search terms as defined by the United Nations Sustainable Development Goals."""

SDG_keys = [{'SDG_id': 'SDG1_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=1\\b)|No Poverty', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG2_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=2\\b)|Zero Hunger', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG3_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=3\\b)|Good Health and Well-being', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG4_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=4\\b)|Quality Education', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG5_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=5\\b)|Gender Equality', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG6_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=6\\b)|Clean Water and Sanitation', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG7_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=7\\b)|Affordable and Clean Energy', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG8_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=8\\b)|Decent Work and Economic Growth', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG9_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=9\\b)|Industry, Innovation, and Infrastructure', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG10_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=10\\b)|Reducing Inequality', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG11_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=11\\b)|Sustainable Cities and Communities', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG12_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=12\\b)|Responsible Consumption and Production', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG13_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=13\\b)|Climate Action', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG14_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=14\\b)|Life Below Water', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG15_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=15\\b)|Life On Land', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG16_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=16\\b)|Peace, Justice, and Strong Institutions', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_general', 'SDG_keywords': '(sdg|goal)[^0-9]{0,2}(?=17\\b)|Partnerships for the Goals', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG1_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=1\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG1_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=1\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG1_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=1\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG1_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=1\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG1_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=1\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG1_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=1\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG1_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=1\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG2_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=2\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG2_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=2\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG2_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=2\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG2_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=2\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG2_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=2\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG2_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=2\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG2_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=2\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG2_c', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=2\\.c[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG3_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=3\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG3_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=3\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG3_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=3\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG3_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=3\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG3_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=3\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG3_6', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=3\\.6[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG3_7', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=3\\.7[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG3_8', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=3\\.8[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG3_9', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=3\\.9[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG3_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=3\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG3_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=3\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG3_c', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=3\\.c[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG3_d', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=3\\.d[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG4_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=4\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG4_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=4\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG4_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=4\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG4_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=4\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG4_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=4\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG4_6', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=4\\.6[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG4_7', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=4\\.7[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG4_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=4\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG4_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=4\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG4_c', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=4\\.c[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG5_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=5\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG5_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=5\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG5_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=5\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG5_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=5\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG5_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=5\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG5_6', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=5\\.6[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG5_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=5\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG5_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=5\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG5_c', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=5\\.c[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG6_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=6\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG6_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=6\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG6_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=6\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG6_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=6\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG6_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=6\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG6_6', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=6\\.6[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG6_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=6\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG6_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=6\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG7_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=7\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG7_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=7\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG7_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=7\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG7_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=7\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG7_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=7\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG8_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=8\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG8_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=8\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG8_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=8\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG8_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=8\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG8_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=8\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG8_6', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=8\\.6[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG8_7', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=8\\.7[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG8_8', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=8\\.8[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG8_9', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=8\\.9[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG8_10', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=8\\.10[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG8_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=8\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG8_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=8\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG9_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=9\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG9_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=9\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG9_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=9\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG9_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=9\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG9_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=9\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG9_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=9\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG9_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=9\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG9_c', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=9\\.c[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG10_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=10\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG10_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=10\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG10_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=10\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG10_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=10\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG10_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=10\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG10_6', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=10\\.6[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG10_7', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=10\\.7[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG10_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=10\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG10_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=10\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG10_c', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=10\\.c[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG11_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=11\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG11_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=11\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG11_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=11\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG11_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=11\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG11_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=11\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG11_6', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=11\\.6[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG11_7', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=11\\.7[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG11_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=11\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG11_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=11\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG11_c', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=11\\.c[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG12_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=12\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG12_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=12\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG12_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=12\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG12_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=12\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG12_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=12\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG12_6', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=12\\.6[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG12_7', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=12\\.7[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG12_8', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=12\\.8[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG12_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=12\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG12_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=12\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG12_c', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=12\\.c[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG13_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=13\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG13_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=13\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG13_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=13\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG13_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=13\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG13_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=13\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG14_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=14\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG14_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=14\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG14_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=14\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG14_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=14\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG14_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=14\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG14_6', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=14\\.6[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG14_7', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=14\\.7[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG14_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=14\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG14_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=14\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG14_c', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=14\\.c[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG15_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=15\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG15_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=15\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG15_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=15\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG15_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=15\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG15_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=15\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG15_6', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=15\\.6[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG15_7', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=15\\.7[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG15_8', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=15\\.8[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG15_9', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=15\\.9[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG15_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=15\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG15_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=15\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG15_c', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=15\\.c[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG16_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=16\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG16_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=16\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG16_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=16\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG16_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=16\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG16_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=16\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG16_6', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=16\\.6[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG16_7', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=16\\.7[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG16_8', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=16\\.8[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG16_9', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=16\\.9[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG16_10', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=16\\.10[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG16_a', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=16\\.a[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG16_b', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=16\\.b[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_1', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.1[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_2', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.2[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_3', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.3[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_4', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.4[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_5', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.5[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_6', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.6[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_7', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.7[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_8', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.8[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_9', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.9[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_10', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.10[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_11', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.11[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_12', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.12[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_13', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.13[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_14', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.14[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_15', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.15[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_16', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.16[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_17', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.17[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_18', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.18[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG17_19', 'SDG_keywords': '(sdg|goal|target|indicator)[^0-9]{0,2}(?=17\\.19[\\.]{0,1})', 'match_type': 'direct'}, 
            {'SDG_id': 'SDG1_1', 'SDG_keywords': '^(?=.*(?:poverty|\\bpoor\\S*|impover\\S*|destitution.?|underprivileg\\S*|necessitous\\S*|homeless|\\bhobo.?|low.?income|lower.?income|underclass\\S*))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*))(?=.*(?:extreme|\\bmost\\b|excess\\S*|exceeding|\\bhigh\\b|\\bhuge\\b|great|\\bover\\b|remarkabl\\S*|striking|\\bsevere|serious)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG1_2', 'SDG_keywords': '^(?=.*(?:poverty|\\bpoor\\S*|impover\\S*|destitution.?|underprivileg\\S*|necessitous\\S*|homeless|\\bhobo.?|low.?income|lower.?income|underclass\\S*))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG1_3', 'SDG_keywords': '^(?=.*(?:poverty|\\bpoor\\S*|impover\\S*|destitution.?|underprivileg\\S*|necessitous\\S*|homeless|\\bhobo.?|low.?income|lower.?income|underclass\\S*|the vulnerable.?))(?=.*(?:assure|\\bcare.?\\b|\\bcover\\S*|preserve\\S*|protect\\S*|safeguard\\S*|secure|shelter.?|shield\\S*|support\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG1_4', 'SDG_keywords': '^(?!.*(?:Financial risk\\S*|Financial Disclosure\\S*|Financial Stability|financial sector\\S*|financial group\\S*|financial crisis|financial condition\\S*|financial impact\\S*|financial inclusive\\S*|financial statement\\S*|Financial Times|financial press|financial result\\S*|financial instrument\\S*|Financial Review\\S*|financial assumption\\S*|finance corporation\\S*|Access Bank|voting right\\S*|human resource\\S*))(?=.*(?:access to|\\brights to))(?=.*(?:resource.?\\b|basic service.?|property|inheritance|ownership|\\bland|financial service.?|\\bestate\\S*|\\bhome\\b|\\bhouse\\b|\\bhouses\\b|\\bhousing\\b|\\bfarms)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG1_5', 'SDG_keywords': '^(?=.*(?:poverty|\\bpoor\\S*|impover\\S*|destitution.?|underprivileg\\S*|necessitous\\S*|homeless|\\bhobo.?|low.?income|lower.?income|underclass\\S*|vulnerab\\S*))(?=.*(?:shock\\S*|disaster.?|catastroph\\S*|cataclysm|casualt\\S*|calamit\\S*|hazard\\S*|mishap\\S*|hurricane\\S*|tornado\\S*|cyclone\\S*|flood\\S*|drought\\S*|\\bharm.?\\b|\\bharmed\\b|wild.?fire|fire.?storm|Extreme event.?|extreme climate|extreme weather|extreme temperature|extreme heat|heat.?wave|cold wave|extreme precipitation|lightning|thunderstorm.?|ice storm.?|blizzard\\S*|hailstorm\\S*|tropical storm.?|earthquake.?|volcanic eruption.?|limnic eruption.?|exploding lake.?|landslide.?|mudslide.?|debris flow.?|tsunami\\S*|sinkhole\\S*|subsidence\\S*))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG1_a', 'SDG_keywords': '^(?=.*(?:poverty|\\bpoor\\S*|impover\\S*|destitution.?|underprivileg\\S*|necessitous\\S*|homeless|\\bhobo.?|low.?income|lower.?income|underclass\\S*))(?=.*(?:econom\\S*|financ\\S*|develop\\S*))(?=.*(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold|empower\\S*|relie\\S*|program\\S*|\\bpolicy|\\bpolicies)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG1_a', 'SDG_keywords': '^(?=.*(?:government\\S*))(?=.*(?:expenditure\\S*|\\bspend\\S*))(?=.*(?:essential service.?|education\\S*|health|social protection.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG1_a', 'SDG_keywords': '^(?=.*(?:development cooperation.?))(?=.*(?:program\\S*|\\bpolicy|\\bpolicies))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*))(?=.*(?:poverty|\\bpoor\\S*|impover\\S*|destitution.?|underprivileg\\S*|necessitous\\S*|homeless|\\bhobo.?|low.?income|lower.?income|underclass\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG1_b', 'SDG_keywords': '^(?=.*(?:poverty|\\bpoor\\S*|impover\\S*|destitution.?|underprivileg\\S*|necessitous\\S*|homeless|\\bhobo.?|low.?income|lower.?income|underclass\\S*))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*))(?=.*(?:action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*|financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG1_b', 'SDG_keywords': '^(?=.*(?:government\\S*))(?=.*(?:expenditure\\S*|\\bspend\\S*))(?=.*(?:women|\\bpoor|vulnerable.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_1', 'SDG_keywords': '^(?=.*(?:income|livelihood|expenditure|earning|\\bpay\\b|\\bwage))(?=.*(?:household|per capita|population))(?=.*(?:empower\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_2', 'SDG_keywords': '^(?!.*(?:financial inclusion.?))(?=.*(?:inclusi\\S*))(?=.*(?:empower\\S*|\\breform\\S*|Prioritiz\\S*|\\bstimulat\\S*|strengthen\\S*|support\\S*|\\bcommitment\\S*|provid\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*))(?=.*(?:social|economic|socio.?economic|political|\\bage\\b|\\bsex|\\bgender|woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?|\\bLGBT\\S*|\\blesbian|\\bgay\\b|bisexual|transgender|\\bQueer\\b|Questioning|Intersex|\\bAllies\\b|\\bAsexual\\b|Pansexual|Disabled|disabilit\\S*|handicapped|incapacitated|crippled|\\bblind\\b|disadvantaged|\\brace|racial|ethnic|origin|religi\\S*|low.?income|lower.?income|demographic)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_2', 'SDG_keywords': '^(?=.*(?:financial inclusion.?))(?=.*(?:empower\\S*|\\breform\\S*|Prioritiz\\S*|\\bstimulat\\S*|strengthen\\S*|support\\S*|\\bcommitment\\S*|provid\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_3', 'SDG_keywords': '(((?:discrimin\\S*|\\bbias\\S*|prejudice\\S*|\\bunfair\\S*|inequal\\S*|inequit\\S*|disparit\\S*|imparit\\S*|stereotype\\S*|harass\\S*|homophobia\\S*|racism|sexism)\\s(?:\\w+\\s){0,10}(?=(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)))|((?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)\\s(?:\\w+\\s){0,10}(?=(?:discrimin\\S*|\\bbias\\S*|prejudice\\S*|\\bunfair\\S*|inequal\\S*|inequit\\S*|disparit\\S*|imparit\\S*|stereotype\\S*|harass\\S*|homophobia\\S*|racism|sexism))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_3', 'SDG_keywords': '^(?=.*(?:equal opportunit\\S*|equal treatment.?|\\bequitab\\S*|\\bequality|\\bun.?bias\\S*|unprejudic\\S*|impartial\\S*|fairness))(?=.*(?:\\bensure|\\bassur\\S*|guarantee\\b|promot\\S*|empower\\S*|support\\S*|\\bstimulat\\S*|strengthen\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_4', 'SDG_keywords': '^(?!.*(?:\\bequal to|equalization|\\bprice|fixed income|gender equality)).*(((?:equal\\S*|inequalit\\S*)\\s(?:\\w+\\s){0,10}(?=(?:\\bpolicy|\\bpolicies|fiscal|economic|financ\\S*|\\bwage|income|social|socio.?economic)))|((?:\\bpolicy|\\bpolicies|fiscal|economic|financ\\S*|\\bwage|income|social|socio.?economic)\\s(?:\\w+\\s){0,10}(?=(?:equal\\S*|inequalit\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_4', 'SDG_keywords': '\\bGINI\\b|social protection polic\\S*|Labo.?r share of GDP', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_5', 'SDG_keywords': '^(?!.*(?:regulatory|regulator.?|General government|Corporate Governance|Financial Institutions Act|Pension Fund\\S*))(?=.*(?:\\bregulat\\S*|monitor\\S*|administer\\S*|govern.?\\b|governed|governing|\\bsound\\b))(?=.*(?:financial market.?|financial institution.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_6', 'SDG_keywords': '^(?!.*(?:Financial risk\\S*|Financial Disclosure\\S*|Financial Stability|financial sector\\S*|financial group\\S*|financial crisis|financial condition\\S*|financial impact\\S*|financial inclusive\\S*|financial statement\\S*|Financial Times|financial press|financial result\\S*|financial instrument\\S*|Financial Review\\S*|financial assumption\\S*|finance corporation\\S*))(?=.*(?:representation.?|\\bvoic\\S*|\\bright.?|\\bvot\\S*|effective|credib\\S*|accountabl\\S*|legitimate|justif\\S*|lawful))(?=.*(?:econom\\S*|financ\\S*|\\bfund.?\\b|\\bfunding\\b))(?=.*(?:institution.?|organization.?|organisation.?|association.?|\\bunion.?|\\bsystem.?))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_6', 'SDG_keywords': '^(?=.*(?:\\bno \\b|\\bnot\\b|\\none\\b))(?=.*(?:casting vot\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_6', 'SDG_keywords': '(((?:\\beach\\b)\\s(?:\\w+\\s){0,6}(?=(?:one vote)))|((?:one vote)\\s(?:\\w+\\s){0,6}(?=(?:\\beach\\b))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_7', 'SDG_keywords': '^(?=.*(?:migrat\\S*))(?=.*(?:orderly|safe|regular|responsible|\\bpolicy|\\bpolicies)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_7', 'SDG_keywords': '^(?=.*(?:orderly|safe|regular|responsible|\\bpolicy|\\bpolicies)).+(((?:mobili\\S*)\\s(?:\\w+\\s){0,4}(?=(?:people|population|employee\\S*)))|((?:people|population|employee\\S*)\\s(?:\\w+\\s){0,4}(?=(?:mobili\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_7', 'SDG_keywords': 'refugee.?', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_a', 'SDG_keywords': '^(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*|\\bspecial|differential|\\bfree\\b))(?=.*(?:tariff.?|duty|\\btax\\b|\\bWTO\\b))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_b', 'SDG_keywords': '^(?!.*(?:Financial risk\\S*|Financial Disclosure\\S*|Financial Stability|financial sector\\S*|financial group\\S*|financial crisis|financial condition\\S*|financial impact\\S*|financial inclusive\\S*|financial statement\\S*|Financial Times|financial press|financial result\\S*|financial instrument\\S*|Financial Review\\S*|financial assumption\\S*|finance corporation\\S*))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+(((?:financ\\S*|\\bfunding|\\bassistance|budget.?|\\baid.? to|government aid.?\\b|state aid.?\\b|invest\\S*|donor|donat\\S*|official flow.?)\\s(?:\\w+\\s){0,5}(?=(?:develop\\S*|resource.?|capabilit\\S*|national plan\\S*|program\\S*)))|((?:develop\\S*|resource.?|capabilit\\S*|national plan\\S*|program\\S*)\\s(?:\\w+\\s){0,5}(?=(?:financ\\S*|\\bfunding|\\bassistance|budget.?|\\baid.? to|government aid.?\\b|state aid.?\\b|invest\\S*|donor|donat\\S*|official flow.?))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_b', 'SDG_keywords': '^(?=.*(?:north-south divide\\S*|financial flow.?|resource flow.?|foreign direct investment.?|\\bFDI\\b|\\bODA\\b))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_c', 'SDG_keywords': '^(?=.*(?:remittance\\S*))(?=.*(?:\\bcost\\b|\\bcosts\\b))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_c', 'SDG_keywords': '^(?=.*(?:remittance\\S*))(?=.*(?:migrant\\S*|emigrant\\S*|immigrant\\S*|corridor\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG10_general', 'SDG_keywords': '^(?=.*(?:\\bequal\\S*|inequalit\\S*|unequal\\S*))(?=.*(?:\\bSocial|societal|societ\\S*|\\bSocio\\S*|environm\\S*|health\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_1', 'SDG_keywords': '^(?!.*(?:Access Bank)).*(((?:access|availab\\S*|affordab\\S*|adequate|formal|safe|insufficient|deficient|\\black|scarce|scant|unsatisfactory)\\s(?:\\w+\\s){0,5}(?=(?:\\bhouse\\b|\\bhouses\\b|\\bhousing\\b|\\bhome\\b|apartment.?|condo|dwelling\\S*|residence|accommodation\\S*|\\bshelter|basic service.?|sanitation.?|hygiene|electricity|slum\\b|slums\\b|slummy|Shanty|\\bliving)))|((?:\\bhouse\\b|\\bhouses\\b|\\bhousing\\b|\\bhome\\b|apartment.?|condo|dwelling\\S*|residence|accommodation\\S*|\\bshelter|basic service.?|sanitation.?|hygiene|electricity|slum\\b|slums\\b|slummy|Shanty|\\bliving)\\s(?:\\w+\\s){0,5}(?=(?:access|availab\\S*|affordab\\S*|adequate|formal|safe|insufficient|deficient|\\black|scarce|scant|unsatisfactory))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_1', 'SDG_keywords': '^(?=.*(?:urbaniz\\S*|\\burban|\\bcity|\\bcities|Megacit\\S*|human settlement.?|land consumption.?|land.?use|metropoli\\S*|town\\S*|municipal\\S*|oppidan\\S*|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*|upgrad\\S*|enhanc\\S*))(?=.*(?:slum\\b|slums\\b|slummy)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_1', 'SDG_keywords': 'formal settlement.?|housing finance', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_2', 'SDG_keywords': '^(?!.*(?:suppl\\S*|equipment\\S*|Access Bank)).*(((?:access|availab\\S*|affordable)\\s(?:\\w+\\s){0,6}(?=(?:transport\\S*|\x08road.?\\b|congestion\\S*|shipment.?|\\btransit.?\\b|\\bbus\\b|\\bbuses\\b|\\bbusses\\b|shuttle.?)))|((?:transport\\S*|\x08road.?\\b|congestion\\S*|shipment.?|\\btransit.?\\b|\\bbus\\b|\\bbuses\\b|\\bbusses\\b|shuttle.?)\\s(?:\\w+\\s){0,6}(?=(?:access|availab\\S*|affordable))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_3', 'SDG_keywords': '^(?=.*(?:urbaniz\\S*|\\burban|\\bcity|\\bcities|Megacit\\S*|human settlement.?|land consumption.?|land.?use|metropoli\\S*|town\\S*|municipal\\S*|oppidan\\S*))(?=.*(?:planning|management.?))(?=.*(?:participat\\S*|democrat\\S*|integrated)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_3', 'SDG_keywords': '(((?:buildings|urbaniz\\S*|\\burban|\\bcity|\\bcities|Megacit\\S*|human settlement.?|land consumption.?|land.?use|metropoli\\S*|town\\S*|municipal\\S*|oppidan\\S*)\\s(?:\\w+\\s){0,6}(?=(?:inclusi\\S*|sustainab\\S*|resilien\\S*|zero.?carbon|zero.?energy|low.?carbon|low.?energy)))|((?:inclusi\\S*|sustainab\\S*|resilien\\S*|zero.?carbon|zero.?energy|low.?carbon|low.?energy)\\s(?:\\w+\\s){0,6}(?=(?:buildings|urbaniz\\S*|\\burban|\\bcity|\\bcities|Megacit\\S*|human settlement.?|land consumption.?|land.?use|metropoli\\S*|town\\S*|municipal\\S*|oppidan\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_4', 'SDG_keywords': '(((?:protect\\S*|safeguard\\S*|preserv\\S*|conserv\\S*|assure|retain\\S*|maintenance|preventive method\\S*|preventive measure.?|financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold)\\s(?:\\w+\\s){0,6}(?=(?:heritage|archaeological site.?|geological site.?|monumental sculpture\\S*|monumental painting\\S*|monument.?|museum.?|Architectural|cultural landscape\\S*|local cultur\\S*|Rare breed\\S*|historic\\S{0,4} building\\S*|historic\\S{0,4} site\\S*|historic\\S{0,4} place.?|\\btradition.?\\b|\\btraditional music|\\bcustom.?\\b|aesthetic belief|spiritual belief.?|artistic expression\\S*|African music|\\blanguage.?|performing art\\S*|social practice\\S*|\\britual.?\\b|festive event\\S*|traditional craftsmanship|nature reserve.?|natural habitat.?|protected natural area.?|marine ecosystem.?|sanctuar\\S*|zoological garden.?|Botanical garden.?)))|((?:heritage|archaeological site.?|geological site.?|monumental sculpture\\S*|monumental painting\\S*|monument.?|museum.?|Architectural|cultural landscape\\S*|local cultur\\S*|Rare breed\\S*|historic\\S{0,4} building\\S*|historic\\S{0,4} site\\S*|historic\\S{0,4} place.?|\\btradition.?\\b|\\btraditional music|\\bcustom.?\\b|aesthetic belief|spiritual belief.?|artistic expression\\S*|African music|\\blanguage.?|performing art\\S*|social practice\\S*|\\britual.?\\b|festive event\\S*|traditional craftsmanship|nature reserve.?|natural habitat.?|protected natural area.?|marine ecosystem.?|sanctuar\\S*|zoological garden.?|Botanical garden.?)\\s(?:\\w+\\s){0,6}(?=(?:protect\\S*|safeguard\\S*|preserv\\S*|conserv\\S*|assure|retain\\S*|maintenance|preventive method\\S*|preventive measure.?|financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_4', 'SDG_keywords': '^(?=.*(?:protect\\S*|safeguard\\S*|preserv\\S*|conserv\\S*|assure|retain\\S*|maintenance|preventive method\\S*|preventive measure.?|financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold)).+(((?:Cultural\\S*|symbolic\\S*|historic\\S*|artistic\\S*|aesthetic\\S*|ethnological\\S*|anthropological\\S*|scientific\\S*|social\\S*)\\s(?:\\w+\\s){0,2}(?=(?:significance.?|diversity)))|((?:significance.?|diversity)\\s(?:\\w+\\s){0,2}(?=(?:Cultural\\S*|symbolic\\S*|historic\\S*|artistic\\S*|aesthetic\\S*|ethnological\\S*|anthropological\\S*|scientific\\S*|social\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_5', 'SDG_keywords': '^(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*))(?=.*(?:mortal\\S*|death|\\bdead|\\bdie\\b|\\bdies\\b|\\bdied\\b|\\bdying|fatal|deceas\\S*|\\bdemis\\S*|\\bkilled|lethal|perish\\S*|lose.*life|pass away|economic loss|\\bmissing|affected|damag\\S*|\\bdisrupt\\S*))(?=.*(?:shock\\S*|disaster.?|catastroph\\S*|cataclysm|casualt\\S*|calamit\\S*|hazard\\S*|mishap\\S*|hurricane\\S*|tornado\\S*|cyclone\\S*|flood\\S*|drought\\S*|\\bharm.?\\b|\\bharmed\\b|wild.?fire|fire.?storm|Extreme event.?|extreme climate|extreme weather|extreme temperature|extreme heat|heat.?wave|cold wave|extreme precipitation|lightning|thunderstorm.?|ice storm.?|blizzard\\S*|hailstorm\\S*|tropical storm.?|earthquake.?|volcanic eruption.?|limnic eruption.?|exploding lake.?|landslide.?|mudslide.?|debris flow.?|tsunami\\S*|sinkhole\\S*|subsidence\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_6', 'SDG_keywords': '^(?=.*(?:contaminat\\S*|environment impact.?|environmental impact.?|impact.? environment\\S*|\\bair.?quality|\\bsmog.?|\\bhaze|pm.?2.?5|pm.?10|particulate matter.?|waste\\S*|rubbish|garbage\\S*|junk|debris|trash|litter.?|sewage\\S*|sludge|scrap metal|scrap lumber|solvent\\S*|product residue\\S*|kiln dust|slag|fly ash|spill\\S*|\\bsoil\\b|footprint.?|pollution\\S*|pollutant\\S*|recycl\\S*|circular|toxin|toxic))(?=.*(?:urbaniz\\S*|\\burban|\\bcity|\\bcities|Megacit\\S*|human settlement.?|land consumption.?|land.?use|metropoli\\S*|town\\S*|municipal\\S*|oppidan\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_6', 'SDG_keywords': 'waste generat\\S*|waste manag\\S*|waste collected|waste controlled|alternative waste disposal.?', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_7', 'SDG_keywords': '^(?=.*(?:safe|secure|inclusi\\S*|accessible|available|reachable|\\bgreen\\b|\\bpublic|\\bnatur\\S*))(?=.*(?:\\bspace.?\\b|bikeway)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_7', 'SDG_keywords': '^(?=.*(?:physical|sexual))(?=.*(?:harass\\S*))(?=.*(?:urbaniz\\S*|\\burban|\\bcity|\\bcities|Megacit\\S*|human settlement.?|land consumption.?|land.?use|metropoli\\S*|town\\S*|municipal\\S*|oppidan\\S*|public space.?|Work.?place.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_a', 'SDG_keywords': '^(?=.*(?:econom\\S*|social|socio\\S*|environment\\S*|socio.?economic|ecolog\\S*))(?=.*(?:\\blink\\S*|balanc\\S*|\\bbind\\S*|bridg\\S*|connect\\S*|network\\S*))(?=.*(?:urbaniz\\S*|\\burban|\\bcity|\\bcities|Megacit\\S*|human settlement.?|land consumption.?|land.?use|metropoli\\S*|town\\S*|municipal\\S*|oppidan\\S*))(?=.*(?:rural|Countryside| peri.?urban|\\bsuburb|\\boutskirt)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_a', 'SDG_keywords': '^(?=.*(?:urbaniz\\S*|\\burban|\\bcity|\\bcities|Megacit\\S*|human settlement.?|land consumption.?|land.?use|metropoli\\S*|town\\S*|municipal\\S*|oppidan\\S*))(?=.*(?:development plan.?|fiscal|action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*))(?=.*(?:\\bnational|regional|balanced territorial development|local fiscal space)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_b', 'SDG_keywords': '^(?=.*(?:urbaniz\\S*|\\burban|\\bcity|\\bcities|Megacit\\S*|human settlement.?|land consumption.?|land.?use|metropoli\\S*|town\\S*|municipal\\S*|oppidan\\S*|local government))(?=.*(?:action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*))(?=.*(?:inclusi\\S*|resource efficien\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_b', 'SDG_keywords': '^(?=.*(?:urbaniz\\S*|\\burban|\\bcity|\\bcities|Megacit\\S*|human settlement.?|land consumption.?|land.?use|metropoli\\S*|town\\S*|municipal\\S*|oppidan\\S*|local government))(?=.*(?:action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*))(?=.*(?:mitigation\\S*|adaptation\\S*|resilien\\S*))(?=.*(?:climate change|shock\\S*|disaster.?|catastroph\\S*|cataclysm|casualt\\S*|calamit\\S*|hazard\\S*|mishap\\S*|hurricane\\S*|tornado\\S*|cyclone\\S*|flood\\S*|drought\\S*|\\bharm.?\\b|\\bharmed\\b|wild.?fire|fire.?storm|Extreme event.?|extreme climate|extreme weather|extreme temperature|extreme heat|heat.?wave|cold wave|extreme precipitation|lightning|thunderstorm.?|ice storm.?|blizzard\\S*|hailstorm\\S*|tropical storm.?|earthquake.?|volcanic eruption.?|limnic eruption.?|exploding lake.?|landslide.?|mudslide.?|debris flow.?|tsunami\\S*|sinkhole\\S*|subsidence\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_b', 'SDG_keywords': '(((?:risk management\\S*|risk reduction.?)\\s(?:\\w+\\s){0,4}(?=(?:climate change|shock\\S*|disaster.?|catastroph\\S*|cataclysm|casualt\\S*|calamit\\S*|hazard\\S*|mishap\\S*|hurricane\\S*|tornado\\S*|cyclone\\S*|flood\\S*|drought\\S*|\\bharm.?\\b|\\bharmed\\b|wild.?fire|fire.?storm|Extreme event.?|extreme climate|extreme weather|extreme temperature|extreme heat|heat.?wave|cold wave|extreme precipitation|lightning|thunderstorm.?|ice storm.?|blizzard\\S*|hailstorm\\S*|tropical storm.?|earthquake.?|volcanic eruption.?|limnic eruption.?|exploding lake.?|landslide.?|mudslide.?|debris flow.?|tsunami\\S*|sinkhole\\S*|subsidence\\S*)))|((?:climate change|shock\\S*|disaster.?|catastroph\\S*|cataclysm|casualt\\S*|calamit\\S*|hazard\\S*|mishap\\S*|hurricane\\S*|tornado\\S*|cyclone\\S*|flood\\S*|drought\\S*|\\bharm.?\\b|\\bharmed\\b|wild.?fire|fire.?storm|Extreme event.?|extreme climate|extreme weather|extreme temperature|extreme heat|heat.?wave|cold wave|extreme precipitation|lightning|thunderstorm.?|ice storm.?|blizzard\\S*|hailstorm\\S*|tropical storm.?|earthquake.?|volcanic eruption.?|limnic eruption.?|exploding lake.?|landslide.?|mudslide.?|debris flow.?|tsunami\\S*|sinkhole\\S*|subsidence\\S*)\\s(?:\\w+\\s){0,4}(?=(?:risk management\\S*|risk reduction.?))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG11_c', 'SDG_keywords': '^(?=.*(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold))(?=.*(?:resilient building|sustainable building))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_1', 'SDG_keywords': '^(?!.*(?:consumer.?|responsible for\\b|demand for products)).*(((?:sustainab\\S*|\\bgreen\\b|\\bgreener\\b|\\bclean\\b|Responsible|Eco.?Friendly|Environmentally.?Friendly|Environment.?Friendly|Recyclable|\\befficien\\S*)\\s(?:\\w+\\s){0,8}(?=(?:consum\\S*|\\bproduction.?|products|manufactur\\S*)))|((?:consum\\S*|\\bproduction.?|products|manufactur\\S*)\\s(?:\\w+\\s){0,8}(?=(?:sustainab\\S*|\\bgreen\\b|\\bgreener\\b|\\bclean\\b|Responsible|Eco.?Friendly|Environmentally.?Friendly|Environment.?Friendly|Recyclable|\\befficien\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_1', 'SDG_keywords': '\\bSCP\\b|\\b10YFP\\b', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_2', 'SDG_keywords': '^(?=.*(?:material.?\\b|resource.?|\\bland\\b|biomass|fossil.?fuel.?|Fossil.?energy|metal ores|industrial mineral.?))(?=.*(?:\\bcoal\\b|\\bpetroleum\\b|natural gas|oil shale|\\bbitumen\\S*|\\btar sand.?|heavy oil.?))(?=.*(?:footprint.?|\\bintensity|\\bflow\\b|\\bflows\\b|consum\\S*|depletion\\S*|overconsumption))(?=.*(?:manag\\S*|per GDP|per capita|\\befficien\\S*|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_2', 'SDG_keywords': '^(?!.*(?:Human Resource.?))(?=.*(?:sustainab\\S*|\\befficien\\S*))(?=.*(?:resource.?|material.?\\b|\\bland\\b))(?=.*(?:manag\\S*|\\busing\\b|\\buse\\b|\\buses\\b|consumption.?|production.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_2', 'SDG_keywords': '^(?=.*(?:manag\\S*|conserv\\S*|protocol.?))(?=.*(?:natural.?resource.?|natural capital|natural asset.?|biological resource.?|Renewable resource.?|raw material.?|basic material.?|primary material.?|\\btimber.?|land resource.?|forest resource.?|mineral resource.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_2', 'SDG_keywords': '^(?=.*(?:resource.?efficien\\S*|efficient resource.?))(?=.*(?:accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_3', 'SDG_keywords': '^(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*|halve|\\bhalf)).+(((?:food|harvest\\S*|supply chain.?)\\s(?:\\w+\\s){0,4}(?=(?:food|harvest\\S*|supply chain.?)))|((?:food|harvest\\S*|supply chain.?)\\s(?:\\w+\\s){0,4}(?=(?:food|harvest\\S*|supply chain.?))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_4', 'SDG_keywords': '^(?!.*(?:chemical.? industr\\S*|Chemical.? division.?|Chemical.? segment\\S*|chemical.? business\\S*|Chemical.? Index|treatment plant.?)).*(((?:manag\\S*|\\btreat\\S*|agreement.?|responsib\\S*|collected|controlled|handled|removal|life cycle|per capita|environmentally.?sound|Eco.?Friendly|Environmentally.?Friendly|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)\\s(?:\\w+\\s){0,8}(?=(?:waste\\S*|rubbish|garbage\\S*|junk|debris|trash|litter.?|sewage\\S*|sludge|scrap metal|scrap lumber|solvent\\S*|product residue\\S*|kiln dust|slag|fly ash|chemical.?|contaminat\\S*|pesticide\\S*|pollut\\S*|Heavy metal.?|Mercury|air emission.?|\\bpoison\\S*|hazardous\\S*|\\btoxin\\S*|\\btoxic\\S*|virulent|radioactive|Chlorinated aliphatic hydrocarbons|\\bWood preserv\\S*|Multisource leachate\\S*|Petroleum refin\\S*|Explosives manufactur\\S*|\\bPFOA\\b|\\bPFOS\\b|\\bPFAS\\b|olatile organic compound.?|\\bVOC\\b|\\bPhenol|\\bEthane|\\bEthene|\\bCresol|\\bIndeno|\\bEndrin|\\bDibenz|\\bSilvex|\\bArsine|\\bPropen|\\bCumene|\\bXylene|\\bAldrin|\\bIsolan|\\bOxamyl|\\bKepone|\\bThiram|\\bBarban|\\bBenzene|\\bEthanol|\\bDiethyl|\\bPropane|\\bMercury|\\bMethane|\\bOxirane|\\bDibenzo|\\bAniline|\\bEthanal|\\bAcetone|\\bBrucine|\\bDinoseb|\\bIsodrin|\\bPhorate|\\bFamphur|\\bTirpate|\\bChloral|\\bLindane|\\bSafrole|\\bToluene|\\bBenomyl|\\bPropham|\\bacetone|\\bbenzene|\\bPyridine|\\bThiourea|\\bPlumbane|\\bThallium|\\bEthanone|\\bPentanol|\\bNicotine|\\bFurfuran|\\bFurfural|\\bMethanol|\\bAcrolein|\\bCyanogen|\\bDieldrin|\\bFluorine|\\bMethomyl|\\bAldicarb|\\bPhosgene|\\bAmitrole|\\bAuramine|\\bChrysene|\\bCreosote|\\bDiallate|\\bCarbaryl|\\bPropoxur|\\bmethanol|\\bpyridine|\\bBenzamide|\\bManganese|\\bArgentate|\\bGuanidine|\\bAcetamide|\\bChlordane|\\bHydrazine|\\bAziridine|\\bThiofanox|\\bEndothall|\\bParathion|\\bPhosphine|\\bToxaphene|\\bMetolcarb|\\bDimetilan|\\bPromecarb|\\bAzaserine|\\bBenzidine|\\bMelphalan|\\bPronamide|\\bReserpine|\\bBromoform|\\bTriallate|\\bVinylamine|\\bEthanamine|\\bPiperidine|\\bStrychnine|\\bThiophenol|\\bDisulfoton|\\bDimethoate|\\bEndosulfan|\\bHeptachlor|\\bSelenourea|\\bCarbofuran|\\bMethiocarb|\\bAcrylamide|\\bChloroform|\\bDaunomycin|\\bIsosafrole|\\bPhenacetin|\\bResorcinol|\\bBendiocarb|\\bThiodicarb|\\bisobutanol|\\bAcetic acid|\\bBenzenamine|\\bStrychnidin|\\bNitric acid|\\bMethanamine|\\bPyrrolidine|\\bNaphthalene|\\bThiophanate|\\bFormic acid|\\bCyclohexane|\\bEthyl ether|\\bEpinephrine|\\bMexacarbate|\\bCarbosulfan|\\bMitomycin C|\\bParaldehyde|\\bTrypan blue|\\bCarbendazim|\\bethyl ether|\\bVanadic acid|\\bMethanethiol|\\bAcetaldehyde|\\bArsinic acid|\\bAcetonitrile|\\bThiomethanol|\\bNitrobenzene|\\bAcrylic acid|\\bBenzenethiol|\\bBromoacetone|\\bDithiobiuret|\\bNitric oxide|\\bSodium azide|\\bZinc cyanide|\\bFormparanate|\\bAcetophenone|\\bChlorambucil|\\bFluoranthene|\\bFormaldehyde|\\bLasiocarpine|\\bLead acetate|\\bMethoxychlor|\\bProsulfocarb|\\bnitrobenzene|\\bGlucopyranose|\\bCarbamic acid|\\bHydroperoxide|\\bFulminic acid|\\bCarbonic acid|\\bSulfuric acid|\\bCyclohexanone|\\bDimethylamine|\\bDipropylamine|\\bEthyl acetate|\\bAllyl alcohol|\\bDiethylarsine|\\bEthyleneimine|\\bEthyl cyanide|\\bThallic oxide|\\bPhysostigmine|\\bAcrylonitrile|\\bChlornaphazin|\\bChlorobenzene|\\bMethyl iodide|\\bMalononitrile|\\bMethapyrilene|\\bThioacetamide|\\bTriethylamine|\\bchlorobenzene|\\bethyl acetate|\\bethyl benzene|\\bcyclohexanone|\\bPropanoic acid|\\bSelenious acid|\\bPropanenitrile|\\bBenzenediamine|\\bEthylene oxide|\\bNitroglycerine|\\bEthyl acrylate|\\bMethyl alcohol|\\bBarium cyanide|\\bCopper cyanide|\\bNickel cyanide|\\bPhenylthiourea|\\bSilver cyanide|\\bSodium cyanide|\\bMethyl bromide|\\bVinyl chloride|\\bCrotonaldehyde|\\bDihydrosafrole|\\bCacodylic acid|\\bLead phosphate|\\bStreptozotocin|\\bToluenediamine|\\bUracil mustard|\\bPhosphoric acid|\\bNaphthalenamine|\\bDiphosphoramide|\\bEthyl carbamate|\\bAcetyl chloride|\\bMethyl chloride|\\bZinc cyanide Zn|\\bTetrahydrofuran|\\bCalcium cyanide|\\bBenzyl chloride|\\bEthanedinitrile|\\bFluoroacetamide|\\bNickel carbonyl|\\bTetraethyl lead|\\bBenzal chloride|\\bChlorobenzilate|\\bEpichlorohydrin|\\bHexachlorophene|\\bLead subacetate|\\bEthanethioamide|\\btrifluoroethane|\\bBenzotrichloride|\\bCyanogen bromide|\\bIsobutyl alcohol|\\bAmmonium picrate|\\bSulfur phosphide|\\bArsenic trioxide|\\bBeryllium powder|\\bCarbon disulfide|\\bHydrogen cyanide|\\bHydrocyanic acid|\\bMethyl hydrazine|\\bMethyl parathion|\\bNitrogen dioxide|\\bOsmium tetroxide|\\bAldicarb sulfone|\\bCalcium chromate|\\bCyclophosphamide|\\bDimethyl sulfate|\\bEthylenethiourea|\\bGlycidylaldehyde|\\bHexachloroethane|\\bHydrogen sulfide|\\bMaleic anhydride|\\bMaleic hydrazide|\\bPropanedinitrile|\\bMethylthiouracil|\\bSelenium dioxide|\\bSelenium sulfide|\\bcarbon disulfide|\\bBenzeneethanamine|\\bDiphosphoric acid|\\bFluoroacetic acid|\\bDiethylene glycol|\\bCarbamic chloride|\\bOsmium oxide OsO4|\\bCyanogen chloride|\\bMercury fulminate|\\bHydrogen fluoride|\\bHydrofluoric acid|\\bMethacrylonitrile|\\bNickel cyanide Ni|\\bCopper cyanide Cu|\\bSilver cyanide Ag|\\bSodium cyanide Na|\\bTetranitromethane|\\bArsenic pentoxide|\\bMethyl isocyanate|\\bNitrogen oxide NO|\\bPotassium cyanide|\\bPropargyl alcohol|\\bThiosemicarbazide|\\bAmmonium vanadate|\\bPentachlorophenol|\\bMethylene bromide|\\bDibutyl phthalate|\\bDiethyl phthalate|\\bHexachlorobenzene|\\bPentachloroethane|\\bMethyl chloroform|\\bTrichloroethylene|\\bHexachloropropene|\\bBendiocarb phenol|\\bCarbofuran phenol|\\btrichloroethylene|\\bCarbamothioic acid|\\bNickel carbonyl Ni|\\bAluminum phosphide|\\bCarbon oxyfluoride|\\bCalcium cyanide Ca|\\bPhosphorus sulfide|\\bChloroacetaldehyde|\\bNitrogen oxide NO2|\\bHydrogen phosphide|\\bVanadium pentoxide|\\bEthylene dibromide|\\bMethylene chloride|\\bDimethyl phthalate|\\bEthyl methacrylate|\\bPentachlorobenzene|\\bPhthalic anhydride|\\bmethylene chloride|\\bMethyl ethyl ketone|\\bArsonous dichloride|\\bMethyl methacrylate|\\bPotassium cyanide K|\\bCarbonic dichloride|\\bVanadium oxide V2O5|\\bDichloroethyl ether|\\bCarbonic difluoride|\\bEthylene dichloride|\\bDiethylstilbesterol|\\bHexachlorobutadiene|\\bTetrachloroethylene|\\bmethyl ethyl ketone|\\bCarbamodithioic acid|\\bPhosphorothioic acid|\\bBenzenebutanoic acid|\\bTetraphosphoric acid|\\bChromic acid H2 CrO4|\\bMethanesulfonic acid|\\bToluene diisocyanate|\\bArsenic acid H3 AsO4|\\bArsenic oxide As2 O5|\\bArsenic oxide As2 O3|\\bDichloromethyl ether|\\bDichlorophenylarsine|\\bPropylene dichloride|\\bHydrogen sulfide H2S|\\bCarbon tetrachloride|\\bcarbon tetrachloride|\\bCarbonochloridic acid|\\bThiodiphosphoric acid|\\bPhenylmercury acetate|\\bThallium oxide Tl2 O3|\\bTrichloromethanethiol|\\bEthylidene dichloride|\\bPhosphorodithioic acid|\\bMethyl chlorocarbonate|\\bSelenium sulfide SeS2|\\bMethyl isobutyl ketone|\\bDichloromethoxy ethane|\\bDiethylhexyl phthalate|\\bEthyl methanesulfonate|\\bOxiranecarboxyaldehyde|\\bThallium chloride TlCl|\\btrichlorofluoromethane|\\bmethyl isobutyl ketone|\\bPhosphorofluoridic acid|\\bPentachloronitrobenzene|\\bAcetic acid ethyl ester|\\bHydrazinecarbothioamide|\\bDichloroisopropyl ether|\\bDichlorodifluoromethane|\\bBenzenesulfonyl chloride|\\bHexaethyl tetraphosphate|\\bPotassium silver cyanide|\\bTetraethyl pyrophosphate|\\bPhysostigmine salicylate|\\bFormetanate hydrochloride|\\bChloromethyl methyl ether|\\bHexachlorocyclopentadiene|\\bchlorinated fluorocarbons|\\bCresols and cresylic acid|\\bDiisopropylfluorophosphate|\\bDimethylcarbamoyl chloride|\\bTrichloromonofluoromethane|\\bThioimidodicarbonic diamide|\\bOctamethylpyrophosphoramide|\\bMethyl ethyl ketone peroxide|\\bBenzenesulfonic acid chloride|\\bTetraethyldithiopyrophosphate|\\bEthylenebisdithiocarbamic acid|\\bEthylene glycol monoethyl ether|\\bManganese dimethyldithiocarbamate|\\bDDD\\b|\\bDDT\\b)))|((?:waste\\S*|rubbish|garbage\\S*|junk|debris|trash|litter.?|sewage\\S*|sludge|scrap metal|scrap lumber|solvent\\S*|product residue\\S*|kiln dust|slag|fly ash|chemical.?|contaminat\\S*|pesticide\\S*|pollut\\S*|Heavy metal.?|Mercury|air emission.?|\\bpoison\\S*|hazardous\\S*|\\btoxin\\S*|\\btoxic\\S*|virulent|radioactive|Chlorinated aliphatic hydrocarbons|\\bWood preserv\\S*|Multisource leachate\\S*|Petroleum refin\\S*|Explosives manufactur\\S*|\\bPFOA\\b|\\bPFOS\\b|\\bPFAS\\b|olatile organic compound.?|\\bVOC\\b|\\bPhenol|\\bEthane|\\bEthene|\\bCresol|\\bIndeno|\\bEndrin|\\bDibenz|\\bSilvex|\\bArsine|\\bPropen|\\bCumene|\\bXylene|\\bAldrin|\\bIsolan|\\bOxamyl|\\bKepone|\\bThiram|\\bBarban|\\bBenzene|\\bEthanol|\\bDiethyl|\\bPropane|\\bMercury|\\bMethane|\\bOxirane|\\bDibenzo|\\bAniline|\\bEthanal|\\bAcetone|\\bBrucine|\\bDinoseb|\\bIsodrin|\\bPhorate|\\bFamphur|\\bTirpate|\\bChloral|\\bLindane|\\bSafrole|\\bToluene|\\bBenomyl|\\bPropham|\\bacetone|\\bbenzene|\\bPyridine|\\bThiourea|\\bPlumbane|\\bThallium|\\bEthanone|\\bPentanol|\\bNicotine|\\bFurfuran|\\bFurfural|\\bMethanol|\\bAcrolein|\\bCyanogen|\\bDieldrin|\\bFluorine|\\bMethomyl|\\bAldicarb|\\bPhosgene|\\bAmitrole|\\bAuramine|\\bChrysene|\\bCreosote|\\bDiallate|\\bCarbaryl|\\bPropoxur|\\bmethanol|\\bpyridine|\\bBenzamide|\\bManganese|\\bArgentate|\\bGuanidine|\\bAcetamide|\\bChlordane|\\bHydrazine|\\bAziridine|\\bThiofanox|\\bEndothall|\\bParathion|\\bPhosphine|\\bToxaphene|\\bMetolcarb|\\bDimetilan|\\bPromecarb|\\bAzaserine|\\bBenzidine|\\bMelphalan|\\bPronamide|\\bReserpine|\\bBromoform|\\bTriallate|\\bVinylamine|\\bEthanamine|\\bPiperidine|\\bStrychnine|\\bThiophenol|\\bDisulfoton|\\bDimethoate|\\bEndosulfan|\\bHeptachlor|\\bSelenourea|\\bCarbofuran|\\bMethiocarb|\\bAcrylamide|\\bChloroform|\\bDaunomycin|\\bIsosafrole|\\bPhenacetin|\\bResorcinol|\\bBendiocarb|\\bThiodicarb|\\bisobutanol|\\bAcetic acid|\\bBenzenamine|\\bStrychnidin|\\bNitric acid|\\bMethanamine|\\bPyrrolidine|\\bNaphthalene|\\bThiophanate|\\bFormic acid|\\bCyclohexane|\\bEthyl ether|\\bEpinephrine|\\bMexacarbate|\\bCarbosulfan|\\bMitomycin C|\\bParaldehyde|\\bTrypan blue|\\bCarbendazim|\\bethyl ether|\\bVanadic acid|\\bMethanethiol|\\bAcetaldehyde|\\bArsinic acid|\\bAcetonitrile|\\bThiomethanol|\\bNitrobenzene|\\bAcrylic acid|\\bBenzenethiol|\\bBromoacetone|\\bDithiobiuret|\\bNitric oxide|\\bSodium azide|\\bZinc cyanide|\\bFormparanate|\\bAcetophenone|\\bChlorambucil|\\bFluoranthene|\\bFormaldehyde|\\bLasiocarpine|\\bLead acetate|\\bMethoxychlor|\\bProsulfocarb|\\bnitrobenzene|\\bGlucopyranose|\\bCarbamic acid|\\bHydroperoxide|\\bFulminic acid|\\bCarbonic acid|\\bSulfuric acid|\\bCyclohexanone|\\bDimethylamine|\\bDipropylamine|\\bEthyl acetate|\\bAllyl alcohol|\\bDiethylarsine|\\bEthyleneimine|\\bEthyl cyanide|\\bThallic oxide|\\bPhysostigmine|\\bAcrylonitrile|\\bChlornaphazin|\\bChlorobenzene|\\bMethyl iodide|\\bMalononitrile|\\bMethapyrilene|\\bThioacetamide|\\bTriethylamine|\\bchlorobenzene|\\bethyl acetate|\\bethyl benzene|\\bcyclohexanone|\\bPropanoic acid|\\bSelenious acid|\\bPropanenitrile|\\bBenzenediamine|\\bEthylene oxide|\\bNitroglycerine|\\bEthyl acrylate|\\bMethyl alcohol|\\bBarium cyanide|\\bCopper cyanide|\\bNickel cyanide|\\bPhenylthiourea|\\bSilver cyanide|\\bSodium cyanide|\\bMethyl bromide|\\bVinyl chloride|\\bCrotonaldehyde|\\bDihydrosafrole|\\bCacodylic acid|\\bLead phosphate|\\bStreptozotocin|\\bToluenediamine|\\bUracil mustard|\\bPhosphoric acid|\\bNaphthalenamine|\\bDiphosphoramide|\\bEthyl carbamate|\\bAcetyl chloride|\\bMethyl chloride|\\bZinc cyanide Zn|\\bTetrahydrofuran|\\bCalcium cyanide|\\bBenzyl chloride|\\bEthanedinitrile|\\bFluoroacetamide|\\bNickel carbonyl|\\bTetraethyl lead|\\bBenzal chloride|\\bChlorobenzilate|\\bEpichlorohydrin|\\bHexachlorophene|\\bLead subacetate|\\bEthanethioamide|\\btrifluoroethane|\\bBenzotrichloride|\\bCyanogen bromide|\\bIsobutyl alcohol|\\bAmmonium picrate|\\bSulfur phosphide|\\bArsenic trioxide|\\bBeryllium powder|\\bCarbon disulfide|\\bHydrogen cyanide|\\bHydrocyanic acid|\\bMethyl hydrazine|\\bMethyl parathion|\\bNitrogen dioxide|\\bOsmium tetroxide|\\bAldicarb sulfone|\\bCalcium chromate|\\bCyclophosphamide|\\bDimethyl sulfate|\\bEthylenethiourea|\\bGlycidylaldehyde|\\bHexachloroethane|\\bHydrogen sulfide|\\bMaleic anhydride|\\bMaleic hydrazide|\\bPropanedinitrile|\\bMethylthiouracil|\\bSelenium dioxide|\\bSelenium sulfide|\\bcarbon disulfide|\\bBenzeneethanamine|\\bDiphosphoric acid|\\bFluoroacetic acid|\\bDiethylene glycol|\\bCarbamic chloride|\\bOsmium oxide OsO4|\\bCyanogen chloride|\\bMercury fulminate|\\bHydrogen fluoride|\\bHydrofluoric acid|\\bMethacrylonitrile|\\bNickel cyanide Ni|\\bCopper cyanide Cu|\\bSilver cyanide Ag|\\bSodium cyanide Na|\\bTetranitromethane|\\bArsenic pentoxide|\\bMethyl isocyanate|\\bNitrogen oxide NO|\\bPotassium cyanide|\\bPropargyl alcohol|\\bThiosemicarbazide|\\bAmmonium vanadate|\\bPentachlorophenol|\\bMethylene bromide|\\bDibutyl phthalate|\\bDiethyl phthalate|\\bHexachlorobenzene|\\bPentachloroethane|\\bMethyl chloroform|\\bTrichloroethylene|\\bHexachloropropene|\\bBendiocarb phenol|\\bCarbofuran phenol|\\btrichloroethylene|\\bCarbamothioic acid|\\bNickel carbonyl Ni|\\bAluminum phosphide|\\bCarbon oxyfluoride|\\bCalcium cyanide Ca|\\bPhosphorus sulfide|\\bChloroacetaldehyde|\\bNitrogen oxide NO2|\\bHydrogen phosphide|\\bVanadium pentoxide|\\bEthylene dibromide|\\bMethylene chloride|\\bDimethyl phthalate|\\bEthyl methacrylate|\\bPentachlorobenzene|\\bPhthalic anhydride|\\bmethylene chloride|\\bMethyl ethyl ketone|\\bArsonous dichloride|\\bMethyl methacrylate|\\bPotassium cyanide K|\\bCarbonic dichloride|\\bVanadium oxide V2O5|\\bDichloroethyl ether|\\bCarbonic difluoride|\\bEthylene dichloride|\\bDiethylstilbesterol|\\bHexachlorobutadiene|\\bTetrachloroethylene|\\bmethyl ethyl ketone|\\bCarbamodithioic acid|\\bPhosphorothioic acid|\\bBenzenebutanoic acid|\\bTetraphosphoric acid|\\bChromic acid H2 CrO4|\\bMethanesulfonic acid|\\bToluene diisocyanate|\\bArsenic acid H3 AsO4|\\bArsenic oxide As2 O5|\\bArsenic oxide As2 O3|\\bDichloromethyl ether|\\bDichlorophenylarsine|\\bPropylene dichloride|\\bHydrogen sulfide H2S|\\bCarbon tetrachloride|\\bcarbon tetrachloride|\\bCarbonochloridic acid|\\bThiodiphosphoric acid|\\bPhenylmercury acetate|\\bThallium oxide Tl2 O3|\\bTrichloromethanethiol|\\bEthylidene dichloride|\\bPhosphorodithioic acid|\\bMethyl chlorocarbonate|\\bSelenium sulfide SeS2|\\bMethyl isobutyl ketone|\\bDichloromethoxy ethane|\\bDiethylhexyl phthalate|\\bEthyl methanesulfonate|\\bOxiranecarboxyaldehyde|\\bThallium chloride TlCl|\\btrichlorofluoromethane|\\bmethyl isobutyl ketone|\\bPhosphorofluoridic acid|\\bPentachloronitrobenzene|\\bAcetic acid ethyl ester|\\bHydrazinecarbothioamide|\\bDichloroisopropyl ether|\\bDichlorodifluoromethane|\\bBenzenesulfonyl chloride|\\bHexaethyl tetraphosphate|\\bPotassium silver cyanide|\\bTetraethyl pyrophosphate|\\bPhysostigmine salicylate|\\bFormetanate hydrochloride|\\bChloromethyl methyl ether|\\bHexachlorocyclopentadiene|\\bchlorinated fluorocarbons|\\bCresols and cresylic acid|\\bDiisopropylfluorophosphate|\\bDimethylcarbamoyl chloride|\\bTrichloromonofluoromethane|\\bThioimidodicarbonic diamide|\\bOctamethylpyrophosphoramide|\\bMethyl ethyl ketone peroxide|\\bBenzenesulfonic acid chloride|\\bTetraethyldithiopyrophosphate|\\bEthylenebisdithiocarbamic acid|\\bEthylene glycol monoethyl ether|\\bManganese dimethyldithiocarbamate|\\bDDD\\b|\\bDDT\\b)\\s(?:\\w+\\s){0,8}(?=(?:manag\\S*|\\btreat\\S*|agreement.?|responsib\\S*|collected|controlled|handled|removal|life cycle|per capita|environmentally.?sound|Eco.?Friendly|Environmentally.?Friendly|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_4', 'SDG_keywords': '^(?=.*(?:waste\\S*|rubbish|garbage\\S*|junk|debris|trash|litter.?|sewage\\S*|sludge|scrap metal|scrap lumber|solvent\\S*|product residue\\S*|kiln dust|slag|fly ash|chemical.?|contaminat\\S*|pesticide\\S*|pollut\\S*|Heavy metal.?|Mercury|air emission.?|\\bpoison\\S*|hazardous\\S*|\\btoxin\\S*|\\btoxic\\S*|virulent|radioactive|Chlorinated aliphatic hydrocarbons|\\bWood preserv\\S*|Multisource leachate\\S*|Petroleum refin\\S*|Explosives manufactur\\S*|\\bPFOA\\b|\\bPFOS\\b|\\bPFAS\\b|olatile organic compound.?|\\bVOC\\b|\\bPhenol|\\bEthane|\\bEthene|\\bCresol|\\bIndeno|\\bEndrin|\\bDibenz|\\bSilvex|\\bArsine|\\bPropen|\\bCumene|\\bXylene|\\bAldrin|\\bIsolan|\\bOxamyl|\\bKepone|\\bThiram|\\bBarban|\\bBenzene|\\bEthanol|\\bDiethyl|\\bPropane|\\bMercury|\\bMethane|\\bOxirane|\\bDibenzo|\\bAniline|\\bEthanal|\\bAcetone|\\bBrucine|\\bDinoseb|\\bIsodrin|\\bPhorate|\\bFamphur|\\bTirpate|\\bChloral|\\bLindane|\\bSafrole|\\bToluene|\\bBenomyl|\\bPropham|\\bacetone|\\bbenzene|\\bPyridine|\\bThiourea|\\bPlumbane|\\bThallium|\\bEthanone|\\bPentanol|\\bNicotine|\\bFurfuran|\\bFurfural|\\bMethanol|\\bAcrolein|\\bCyanogen|\\bDieldrin|\\bFluorine|\\bMethomyl|\\bAldicarb|\\bPhosgene|\\bAmitrole|\\bAuramine|\\bChrysene|\\bCreosote|\\bDiallate|\\bCarbaryl|\\bPropoxur|\\bmethanol|\\bpyridine|\\bBenzamide|\\bManganese|\\bArgentate|\\bGuanidine|\\bAcetamide|\\bChlordane|\\bHydrazine|\\bAziridine|\\bThiofanox|\\bEndothall|\\bParathion|\\bPhosphine|\\bToxaphene|\\bMetolcarb|\\bDimetilan|\\bPromecarb|\\bAzaserine|\\bBenzidine|\\bMelphalan|\\bPronamide|\\bReserpine|\\bBromoform|\\bTriallate|\\bVinylamine|\\bEthanamine|\\bPiperidine|\\bStrychnine|\\bThiophenol|\\bDisulfoton|\\bDimethoate|\\bEndosulfan|\\bHeptachlor|\\bSelenourea|\\bCarbofuran|\\bMethiocarb|\\bAcrylamide|\\bChloroform|\\bDaunomycin|\\bIsosafrole|\\bPhenacetin|\\bResorcinol|\\bBendiocarb|\\bThiodicarb|\\bisobutanol|\\bAcetic acid|\\bBenzenamine|\\bStrychnidin|\\bNitric acid|\\bMethanamine|\\bPyrrolidine|\\bNaphthalene|\\bThiophanate|\\bFormic acid|\\bCyclohexane|\\bEthyl ether|\\bEpinephrine|\\bMexacarbate|\\bCarbosulfan|\\bMitomycin C|\\bParaldehyde|\\bTrypan blue|\\bCarbendazim|\\bethyl ether|\\bVanadic acid|\\bMethanethiol|\\bAcetaldehyde|\\bArsinic acid|\\bAcetonitrile|\\bThiomethanol|\\bNitrobenzene|\\bAcrylic acid|\\bBenzenethiol|\\bBromoacetone|\\bDithiobiuret|\\bNitric oxide|\\bSodium azide|\\bZinc cyanide|\\bFormparanate|\\bAcetophenone|\\bChlorambucil|\\bFluoranthene|\\bFormaldehyde|\\bLasiocarpine|\\bLead acetate|\\bMethoxychlor|\\bProsulfocarb|\\bnitrobenzene|\\bGlucopyranose|\\bCarbamic acid|\\bHydroperoxide|\\bFulminic acid|\\bCarbonic acid|\\bSulfuric acid|\\bCyclohexanone|\\bDimethylamine|\\bDipropylamine|\\bEthyl acetate|\\bAllyl alcohol|\\bDiethylarsine|\\bEthyleneimine|\\bEthyl cyanide|\\bThallic oxide|\\bPhysostigmine|\\bAcrylonitrile|\\bChlornaphazin|\\bChlorobenzene|\\bMethyl iodide|\\bMalononitrile|\\bMethapyrilene|\\bThioacetamide|\\bTriethylamine|\\bchlorobenzene|\\bethyl acetate|\\bethyl benzene|\\bcyclohexanone|\\bPropanoic acid|\\bSelenious acid|\\bPropanenitrile|\\bBenzenediamine|\\bEthylene oxide|\\bNitroglycerine|\\bEthyl acrylate|\\bMethyl alcohol|\\bBarium cyanide|\\bCopper cyanide|\\bNickel cyanide|\\bPhenylthiourea|\\bSilver cyanide|\\bSodium cyanide|\\bMethyl bromide|\\bVinyl chloride|\\bCrotonaldehyde|\\bDihydrosafrole|\\bCacodylic acid|\\bLead phosphate|\\bStreptozotocin|\\bToluenediamine|\\bUracil mustard|\\bPhosphoric acid|\\bNaphthalenamine|\\bDiphosphoramide|\\bEthyl carbamate|\\bAcetyl chloride|\\bMethyl chloride|\\bZinc cyanide Zn|\\bTetrahydrofuran|\\bCalcium cyanide|\\bBenzyl chloride|\\bEthanedinitrile|\\bFluoroacetamide|\\bNickel carbonyl|\\bTetraethyl lead|\\bBenzal chloride|\\bChlorobenzilate|\\bEpichlorohydrin|\\bHexachlorophene|\\bLead subacetate|\\bEthanethioamide|\\btrifluoroethane|\\bBenzotrichloride|\\bCyanogen bromide|\\bIsobutyl alcohol|\\bAmmonium picrate|\\bSulfur phosphide|\\bArsenic trioxide|\\bBeryllium powder|\\bCarbon disulfide|\\bHydrogen cyanide|\\bHydrocyanic acid|\\bMethyl hydrazine|\\bMethyl parathion|\\bNitrogen dioxide|\\bOsmium tetroxide|\\bAldicarb sulfone|\\bCalcium chromate|\\bCyclophosphamide|\\bDimethyl sulfate|\\bEthylenethiourea|\\bGlycidylaldehyde|\\bHexachloroethane|\\bHydrogen sulfide|\\bMaleic anhydride|\\bMaleic hydrazide|\\bPropanedinitrile|\\bMethylthiouracil|\\bSelenium dioxide|\\bSelenium sulfide|\\bcarbon disulfide|\\bBenzeneethanamine|\\bDiphosphoric acid|\\bFluoroacetic acid|\\bDiethylene glycol|\\bCarbamic chloride|\\bOsmium oxide OsO4|\\bCyanogen chloride|\\bMercury fulminate|\\bHydrogen fluoride|\\bHydrofluoric acid|\\bMethacrylonitrile|\\bNickel cyanide Ni|\\bCopper cyanide Cu|\\bSilver cyanide Ag|\\bSodium cyanide Na|\\bTetranitromethane|\\bArsenic pentoxide|\\bMethyl isocyanate|\\bNitrogen oxide NO|\\bPotassium cyanide|\\bPropargyl alcohol|\\bThiosemicarbazide|\\bAmmonium vanadate|\\bPentachlorophenol|\\bMethylene bromide|\\bDibutyl phthalate|\\bDiethyl phthalate|\\bHexachlorobenzene|\\bPentachloroethane|\\bMethyl chloroform|\\bTrichloroethylene|\\bHexachloropropene|\\bBendiocarb phenol|\\bCarbofuran phenol|\\btrichloroethylene|\\bCarbamothioic acid|\\bNickel carbonyl Ni|\\bAluminum phosphide|\\bCarbon oxyfluoride|\\bCalcium cyanide Ca|\\bPhosphorus sulfide|\\bChloroacetaldehyde|\\bNitrogen oxide NO2|\\bHydrogen phosphide|\\bVanadium pentoxide|\\bEthylene dibromide|\\bMethylene chloride|\\bDimethyl phthalate|\\bEthyl methacrylate|\\bPentachlorobenzene|\\bPhthalic anhydride|\\bmethylene chloride|\\bMethyl ethyl ketone|\\bArsonous dichloride|\\bMethyl methacrylate|\\bPotassium cyanide K|\\bCarbonic dichloride|\\bVanadium oxide V2O5|\\bDichloroethyl ether|\\bCarbonic difluoride|\\bEthylene dichloride|\\bDiethylstilbesterol|\\bHexachlorobutadiene|\\bTetrachloroethylene|\\bmethyl ethyl ketone|\\bCarbamodithioic acid|\\bPhosphorothioic acid|\\bBenzenebutanoic acid|\\bTetraphosphoric acid|\\bChromic acid H2 CrO4|\\bMethanesulfonic acid|\\bToluene diisocyanate|\\bArsenic acid H3 AsO4|\\bArsenic oxide As2 O5|\\bArsenic oxide As2 O3|\\bDichloromethyl ether|\\bDichlorophenylarsine|\\bPropylene dichloride|\\bHydrogen sulfide H2S|\\bCarbon tetrachloride|\\bcarbon tetrachloride|\\bCarbonochloridic acid|\\bThiodiphosphoric acid|\\bPhenylmercury acetate|\\bThallium oxide Tl2 O3|\\bTrichloromethanethiol|\\bEthylidene dichloride|\\bPhosphorodithioic acid|\\bMethyl chlorocarbonate|\\bSelenium sulfide SeS2|\\bMethyl isobutyl ketone|\\bDichloromethoxy ethane|\\bDiethylhexyl phthalate|\\bEthyl methanesulfonate|\\bOxiranecarboxyaldehyde|\\bThallium chloride TlCl|\\btrichlorofluoromethane|\\bmethyl isobutyl ketone|\\bPhosphorofluoridic acid|\\bPentachloronitrobenzene|\\bAcetic acid ethyl ester|\\bHydrazinecarbothioamide|\\bDichloroisopropyl ether|\\bDichlorodifluoromethane|\\bBenzenesulfonyl chloride|\\bHexaethyl tetraphosphate|\\bPotassium silver cyanide|\\bTetraethyl pyrophosphate|\\bPhysostigmine salicylate|\\bFormetanate hydrochloride|\\bChloromethyl methyl ether|\\bHexachlorocyclopentadiene|\\bchlorinated fluorocarbons|\\bCresols and cresylic acid|\\bDiisopropylfluorophosphate|\\bDimethylcarbamoyl chloride|\\bTrichloromonofluoromethane|\\bThioimidodicarbonic diamide|\\bOctamethylpyrophosphoramide|\\bMethyl ethyl ketone peroxide|\\bBenzenesulfonic acid chloride|\\bTetraethyldithiopyrophosphate|\\bEthylenebisdithiocarbamic acid|\\bEthylene glycol monoethyl ether|\\bManganese dimethyldithiocarbamate|\\bDDD\\b|\\bDDT\\b)).+(((?:\\bsafe\\S*|responsib\\S*|sustainab\\S*|manag\\S*)\\s(?:\\w+\\s){0,4}(?=(?:disposal.?|handl\\S*|incinerat\\S*|land.?fill\\S*)))|((?:disposal.?|handl\\S*|incinerat\\S*|land.?fill\\S*)\\s(?:\\w+\\s){0,4}(?=(?:\\bsafe\\S*|responsib\\S*|sustainab\\S*|manag\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_4', 'SDG_keywords': 'environmental permit.?|Basel Convention|Rotterdam Convention|Stockholm Convention|Montreal Protocol|Minamata Convention', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_4', 'SDG_keywords': '^(?!.*(?:Limiting Our Environmental Impact)).*(((?:environmental impact.?|environmental issue.?|environmental risk.?)\\s(?:\\w+\\s){0,6}(?=(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*|de.?coupl\\S*|informed|\\baddress\\S*|tackl\\S*|response to|cope.?with|coping with|deal.?with|dealing with|handl\\S*|\\bmeasure.?\\b|\\blower\\b|\\bless\\b)))|((?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*|de.?coupl\\S*|informed|\\baddress\\S*|tackl\\S*|response to|cope.?with|coping with|deal.?with|dealing with|handl\\S*|\\bmeasure.?\\b|\\blower\\b|\\bless\\b)\\s(?:\\w+\\s){0,6}(?=(?:environmental impact.?|environmental issue.?|environmental risk.?))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_5', 'SDG_keywords': '(((?:recycl\\S*|\\bre.?us\\S*|re.?utiliz\\S*|re.?possess\\S*|\\bregenerat\\S*|circular|circulat\\S*|circulating|reclaimed|reclamation.?|\\breduc)\\s(?:\\w+\\s){0,6}(?=(?:waste\\S*|rubbish|garbage\\S*|junk|debris|trash|litter.?|sewage\\S*|sludge|scrap metal|scrap lumber|solvent\\S*|product residue\\S*|kiln dust|slag|fly ash|\\bpaper\\b|cardboard|packaging|\\bfibre.?|\\bfiber.?|\\bpulp\\b|plastic\\S*|\\bglass\\b|\\bresidue.?\\b|by.?product\\S*|material.?\\b|metal.?|resource.?|furniture.?|mattresse.?)))|((?:waste\\S*|rubbish|garbage\\S*|junk|debris|trash|litter.?|sewage\\S*|sludge|scrap metal|scrap lumber|solvent\\S*|product residue\\S*|kiln dust|slag|fly ash|\\bpaper\\b|cardboard|packaging|\\bfibre.?|\\bfiber.?|\\bpulp\\b|plastic\\S*|\\bglass\\b|\\bresidue.?\\b|by.?product\\S*|material.?\\b|metal.?|resource.?|furniture.?|mattresse.?)\\s(?:\\w+\\s){0,6}(?=(?:recycl\\S*|\\bre.?us\\S*|re.?utiliz\\S*|re.?possess\\S*|\\bregenerat\\S*|circular|circulat\\S*|circulating|reclaimed|reclamation.?|\\breduc))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_5', 'SDG_keywords': '(((?:\\brepair\\S*|\\brefurbish\\S*)\\s(?:\\w+\\s){0,6}(?=(?:material.?\\b|resource.?|products)))|((?:material.?\\b|resource.?|products)\\s(?:\\w+\\s){0,6}(?=(?:\\brepair\\S*|\\brefurbish\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_5', 'SDG_keywords': 'cradle to cradle|Life cycle assessment.?|Circular economy|recycling rate.?|refurbishment.?', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_6', 'SDG_keywords': '^(?!.*(?:Annual Report.?|Corporate Information|Initiatives for Sustainable Growth|Sustainability Meeting.?|Corporate Governance Sustainability|Company Overview))(?=.*(?:\\bcompany\\b|\\bcompanies|\\bfirm.?\\b|\\bcorporate\\b|\\bcorporation\\S*|business|enterprise\\S*)).+(((?:sustainab\\S*)\\s(?:\\w+\\s){0,4}(?=(?:practic\\S*|action.?|reporting|\\bpublish\\S*|information)))|((?:practic\\S*|action.?|reporting|\\bpublish\\S*|information)\\s(?:\\w+\\s){0,4}(?=(?:sustainab\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_6', 'SDG_keywords': '^(?!.*(?:Social Responsibility Committee))(?=.*(?:\\bsoci\\S*))(?=.*(?:responsibilit\\S*))(?=.*(?:\\bcompany\\b|\\bcompanies|\\bfirm.?\\b|\\bcorporate\\b|\\bcorporation\\S*|business|enterprise\\S*))(?=.*(?:accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_6', 'SDG_keywords': '^(?=.*(?:commitment\\S*))(?=.*(?:social responsibilit\\S*|environmental stewardship.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_6', 'SDG_keywords': '^(?=.*(?:\\bcompany\\b|\\bcompanies|\\bfirm.?\\b|\\bcorporate\\b|\\bcorporation\\S*|business|enterprise\\S*)).+(((?:\\bdisclos\\S*|\\bmanage|share)\\s(?:\\w+\\s){0,4}(?=(?:environmental information)))|((?:environmental information)\\s(?:\\w+\\s){0,4}(?=(?:\\bdisclos\\S*|\\bmanage|share))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_6', 'SDG_keywords': '^(?=.*(?:emission.?)).+(((?:\\bdisclos\\S*|reporting)\\s(?:\\w+\\s){0,6}(?=(?:information|data)))|((?:information|data)\\s(?:\\w+\\s){0,6}(?=(?:\\bdisclos\\S*|reporting))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_7', 'SDG_keywords': '^(?=.*(?:sustainab\\S*|\\bGreen\\b))(?=.*(?:procurement\\S*|acquisition.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_7', 'SDG_keywords': '^(?=.*(?:procurement\\S*|acquisition.?))(?=.*(?:national polic\\S*|national priorit\\S*|national action plan.?))(?=.*(?:in accordance with|\\bfollow\\S*|align.? with|according to|in line with)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_8', 'SDG_keywords': '^(?=.*(?:sustainable development|harmony with nature))(?=.*(?:information|awareness|educat\\S*|curricul\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_a', 'SDG_keywords': '^(?=.*(?:sustainab\\S*|\\bgreen\\b|\\bgreener\\b|\\bclean))(?=.*(?:consum\\S*|\\bproduc\\S*|manufactur\\S*|\\buse|\\busing\\b))(?=.*(?:scientific|\\bscience|tech\\S*|\\brenewable.?))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_b', 'SDG_keywords': '^(?=.*(?:sustainab\\S*|\\bgreen\\b))(?=.*(?:touris\\S*))(?=.*(?:monitor\\S*|manag\\S*|accounting|\\btrack\\S*|\\bregulat\\S*|administer\\S*|govern\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG12_c', 'SDG_keywords': '^(?=.*(?:fossil|\\bcoal\\b|\\bcoals\\b|petrol|natural gas|crude oil.?|gasoline|kerosene|non.?renewable.?|traditional energy|Conventional energy))(?=.*(?:\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis\\S*|expenditure|expens\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG13_1', 'SDG_keywords': '^(?=.*(?:\\bclimat\\S*|global change|Global dimming|global environment change|\\bENSO\\b|\\bEl Ni|Southern Oscillation|extreme weather|weather pattern.?|warming|\\bwarmer|warmest|temperature|hotter|hottest|heat.?up|heat.?wave.?|cloudburst|aridity|drought.?|rainfall shortfall|flood\\S*|\\bstorm\\S*|extreme heat\\S*|Heat Island|cold wave.?|extreme precipitation.?|extreme rainfall|heavy rain.?|heavy downpour\\S*|thunder.?storm.?|ice storm.?|blizzard\\S*|hailstorm.?|tropical storm.?|Human activit\\S*|anthropogenic\\S*|wild.?fire\\S*|fire.?storm\\S*|\\bsea.?level|\\bsea.?ice|\\bmelt\\S*|Ocean acidification|kyoto protocol))(?=.*(?:shock\\S*|disaster.?|catastroph\\S*|cataclysm|casualt\\S*|calamit\\S*|hazard\\S*|mishap\\S*|hurricane\\S*|tornado\\S*|cyclone\\S*|flood\\S*|drought\\S*|\\bharm.?\\b|\\bharmed\\b|wild.?fire|fire.?storm|Extreme event.?|extreme climate|extreme weather|extreme temperature|extreme heat|heat.?wave|cold wave|extreme precipitation|lightning|thunderstorm.?|ice storm.?|blizzard\\S*|hailstorm\\S*|tropical storm.?|earthquake.?|volcanic eruption.?|limnic eruption.?|exploding lake.?|landslide.?|mudslide.?|debris flow.?|tsunami\\S*|sinkhole\\S*|subsidence\\S*|mortal\\S*|death|\\bdead|\\bdie\\b|\\bdies\\b|\\bdied\\b|\\bdying|fatal|deceas\\S*|\\bdemis\\S*|\\bkilled|lethal|perish\\S*|lose.*life|pass away|\\bmissing person|human loss))(?=.*(?:resilien\\S*|adapt\\S*|adjust\\S*|\\bcombat\\S*|\\blimit.?\\b|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG13_2', 'SDG_keywords': '^(?=.*(?:\\bemission.?|\\bCO2\\b|carbon|green.?house|\\bGHG\\b|G\\.H\\.G\\.|Halocarbons|chlorofluorocarbon.?|\\bcfc\\b|c\\.f\\.c\\.|\\bCFCs\\b|water vapour|methane|\\bCH4\\b|nitrous oxide|\\bN2O\\b|Nitrogen Oxides|\\bNOx\\b|\\bozone.?|\\bO3\\b|fluorinated gas|perfluorocarbon.?|\\bPFCs\\b|hydrofluorocarbon.?|\\bHFCs\\b|sulphur hexafluoride|\\bSF6\\b|nitrogen trifluoride|\\bNF3\\b))(?=.*(?:captur\\S*|sequest\\S*|\\blimit.?\\b|\\bremov\\S*|absorb\\S*|stabiliz\\S*|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG13_2', 'SDG_keywords': '^(?!.*(?:Power segment\\S*|Power Green Camp\\S*|Renewables & Power|wind up|Clean Energy Fuels Corp|\\bltd\\b|Total Solar|alternative approach|Renewables segment\\S*|energy forward agreement\\S*)).*(energy transition\\S*|decarboni\\S*|((\\brenewables|biofuel|bioenergy|biodiesel|bio.?gas|bioethanol|hydropower|hydroelectric|electrofuel|\\be.?fuel|photovoltaic|wind farm\\S*|offshore wind|wind turbine\\S*|solar panel\\S*)|(?=.*(?:\\badvanc\\S*|alcohol|modern|\\bclean\\b|\\brenewable|alternative\\b|ethanol|biorefinery|\\bwind\\b|solar|biomass|nuclear|\\bsun\\b|sunlight.?\\b|\\btide.?\\b|tidal|\\bwave.?\\b|\\bwood.?\\b|thermal|geothermal|algae|\\balgal|\\bHydro\\S*|hybrid|hydrogen|synthetic\\S*|\\bgreen\\b|\\bgreener\\b|sustainable|enviro.?friendly|eco.?friendly|Environmentally.?Friendly|Environment.?Friendly))(?=.*(?:\\benergy|\\benergies|\\bfuel.?\\b|\\bpower\\b)))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG13_2', 'SDG_keywords': '^(?!.*(?:data.?base\\S*|data.?base\\S*)).*(\\bCOP\\b|\\bCOP.?\\d+|\\bIPCC\\b|\\bUNFCC\\b|Paris Agreement\\S*|Paris Climate Agreement.?|Montreal Protocol|nationally determined contribution.?|national adaptation plan.?|Rio Convention.?|1\\.5.?Â°C|2.?Â°C|1\\.5 degrees Celsius|2 degrees Fahrenheit\\S*|two degrees Celsius|net.?zero|negative emission\\S*|Carbon Neutral|carbon sink\\S*|Carbon negative|kyoto protocol|tipping point\\S*).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG13_2', 'SDG_keywords': '(((?:ocean acidification|deforest\\S*|desertificati\\S*|animal farming|farming livestock\\S*|fertilizer\\S*|air pollut\\S*|typhoon\\S*|hurricane\\S*)\\s(?:\\w+\\s){0,4}(?=(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)))|((?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)\\s(?:\\w+\\s){0,4}(?=(?:ocean acidification|deforest\\S*|desertificati\\S*|animal farming|farming livestock\\S*|fertilizer\\S*|air pollut\\S*|typhoon\\S*|hurricane\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG13_2', 'SDG_keywords': '^(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+(((?:fossil.?fuel\\S*|fossil.?gas|\\bcoal\\b|\\bcoals\\b|petrol\\S*|natural gas|methane|crude oil.?|traditional energy|Conventional energy)\\s(?:\\w+\\s){0,4}(?=(?:consumption.?|consumed|\\busage.?|\\busing\\b|\\buse\\b|\\buses\\b)))|((?:consumption.?|consumed|\\busage.?|\\busing\\b|\\buse\\b|\\buses\\b)\\s(?:\\w+\\s){0,4}(?=(?:fossil.?fuel\\S*|fossil.?gas|\\bcoal\\b|\\bcoals\\b|petrol\\S*|natural gas|methane|crude oil.?|traditional energy|Conventional energy))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG13_2', 'SDG_keywords': '^(?!.*(?:business climate|economic climate)).*(((?:\\bclimat\\S*|global change|Global dimming|global environment change|\\bENSO\\b|\\bEl Ni|Southern Oscillation|extreme weather|weather pattern.?|warming|\\bwarmer|warmest|temperature|hotter|hottest|heat.?up|heat.?wave.?|cloudburst|aridity|drought.?|rainfall shortfall|flood\\S*|\\bstorm\\S*|extreme heat\\S*|Heat Island|cold wave.?|extreme precipitation.?|extreme rainfall|heavy rain.?|heavy downpour\\S*|thunder.?storm.?|ice storm.?|blizzard\\S*|hailstorm.?|tropical storm.?|Human activit\\S*|anthropogenic\\S*|wild.?fire\\S*|fire.?storm\\S*|\\bsea.?level|\\bsea.?ice|\\bmelt\\S*|Ocean acidification|\\bCOP\\b|\\bCOP.?\\d+|\\bIPCC\\b|\\bUNFCC\\b|Paris Agreement\\S*|Paris Climate Agreement.?|Montreal Protocol|nationally determined contribution.?|national adaptation plan.?|Rio Convention.?|1\\.5.?Â°C|2.?Â°C|1\\.5 degrees Celsius|2 degrees Fahrenheit\\S*|two degrees Celsius|net.?zero|negative emission\\S*|Carbon Neutral|carbon sink\\S*|Carbon negative)\\s(?:\\w+\\s){0,8}(?=(?:adapt\\S*|Mitigation\\S*|action\\S*|\\bact\\b|legislation\\S*|contribut\\S*|convention\\S*|prepar\\S*|fight\\S*|\\bcombat\\S*|tackl\\S*|response to|cope.?with|coping with|deal.?with|dealing with|handl\\S*|\\bmeasure.?\\b|action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)))|((?:adapt\\S*|Mitigation\\S*|action\\S*|\\bact\\b|legislation\\S*|contribut\\S*|convention\\S*|prepar\\S*|fight\\S*|\\bcombat\\S*|tackl\\S*|response to|cope.?with|coping with|deal.?with|dealing with|handl\\S*|\\bmeasure.?\\b|action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)\\s(?:\\w+\\s){0,8}(?=(?:\\bclimat\\S*|global change|Global dimming|global environment change|\\bENSO\\b|\\bEl Ni|Southern Oscillation|extreme weather|weather pattern.?|warming|\\bwarmer|warmest|temperature|hotter|hottest|heat.?up|heat.?wave.?|cloudburst|aridity|drought.?|rainfall shortfall|flood\\S*|\\bstorm\\S*|extreme heat\\S*|Heat Island|cold wave.?|extreme precipitation.?|extreme rainfall|heavy rain.?|heavy downpour\\S*|thunder.?storm.?|ice storm.?|blizzard\\S*|hailstorm.?|tropical storm.?|Human activit\\S*|anthropogenic\\S*|wild.?fire\\S*|fire.?storm\\S*|\\bsea.?level|\\bsea.?ice|\\bmelt\\S*|Ocean acidification|\\bCOP\\b|\\bCOP.?\\d+|\\bIPCC\\b|\\bUNFCC\\b|Paris Agreement\\S*|Paris Climate Agreement.?|Montreal Protocol|nationally determined contribution.?|national adaptation plan.?|Rio Convention.?|1\\.5.?Â°C|2.?Â°C|1\\.5 degrees Celsius|2 degrees Fahrenheit\\S*|two degrees Celsius|net.?zero|negative emission\\S*|Carbon Neutral|carbon sink\\S*|Carbon negative))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG13_3', 'SDG_keywords': '^(?=.*(?:\\bclimat\\S*|global change|Global dimming|global environment change|\\bENSO\\b|\\bEl Ni|Southern Oscillation|extreme weather|weather pattern.?|warming|\\bwarmer|warmest|temperature|hotter|hottest|heat.?up|heat.?wave.?|cloudburst|aridity|drought.?|rainfall shortfall|flood\\S*|\\bstorm\\S*|extreme heat\\S*|Heat Island|cold wave.?|extreme precipitation.?|extreme rainfall|heavy rain.?|heavy downpour\\S*|thunder.?storm.?|ice storm.?|blizzard\\S*|hailstorm.?|tropical storm.?|Human activit\\S*|anthropogenic\\S*|wild.?fire\\S*|fire.?storm\\S*|\\bsea.?level|\\bsea.?ice|\\bmelt\\S*|Ocean acidification|kyoto protocol|\\bemission.?|\\bCO2\\b|carbon|green.?house|\\bGHG\\b|G\\.H\\.G\\.|Halocarbons|chlorofluorocarbon.?|\\bcfc\\b|c\\.f\\.c\\.|\\bCFCs\\b|water vapour|methane|\\bCH4\\b|nitrous oxide|\\bN2O\\b|Nitrogen Oxides|\\bNOx\\b|\\bozone.?|\\bO3\\b|fluorinated gas|perfluorocarbon.?|\\bPFCs\\b|hydrofluorocarbon.?|\\bHFCs\\b|sulphur hexafluoride|\\bSF6\\b|nitrogen trifluoride|\\bNF3\\b))(?=.*(?:adapt\\S*|captur\\S*|contribut\\S*|convention\\S*|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*|action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*))(?=.*(?:educat\\S*|aware\\S*|engag\\S*|outreach|communicat\\S*|\\binforming|\\binform\\b|\\binforms\\b|\\binformed\\b|\\btrain\\S*|tutor\\S*|instruct\\S*|teach\\S*|learn\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG13_a', 'SDG_keywords': '^(?!.*(?:Financial risk\\S*|Financial Disclosure\\S*|Financial Stability|financial sector\\S*|financial group\\S*|financial crisis|financial condition\\S*|financial impact\\S*|financial inclusive\\S*|financial statement\\S*|Financial Times|financial press|financial result\\S*|financial instrument\\S*|Financial Review\\S*|financial assumption\\S*|finance corporation\\S*|Martin storm.?|economic climate|temperature sensor.?|section page.?)).*(((?:\\bclimat\\S*|global change|Global dimming|global environment change|\\bENSO\\b|\\bEl Ni|Southern Oscillation|extreme weather|weather pattern.?|warming|\\bwarmer|warmest|temperature|hotter|hottest|heat.?up|heat.?wave.?|cloudburst|aridity|drought.?|rainfall shortfall|flood\\S*|\\bstorm\\S*|extreme heat\\S*|Heat Island|cold wave.?|extreme precipitation.?|extreme rainfall|heavy rain.?|heavy downpour\\S*|thunder.?storm.?|ice storm.?|blizzard\\S*|hailstorm.?|tropical storm.?|Human activit\\S*|anthropogenic\\S*|wild.?fire\\S*|fire.?storm\\S*|\\bsea.?level|\\bsea.?ice|\\bmelt\\S*|Ocean acidification|\\bCOP\\b|\\bCOP.?\\d+|\\bIPCC\\b|\\bUNFCC\\b|Paris Agreement\\S*|Paris Climate Agreement.?|Montreal Protocol|nationally determined contribution.?|national adaptation plan.?|Rio Convention.?|1\\.5.?Â°C|2.?Â°C|1\\.5 degrees Celsius|2 degrees Fahrenheit\\S*|two degrees Celsius|net.?zero|negative emission\\S*|Carbon Neutral|carbon sink\\S*|Carbon negative|kyoto protocol)\\s(?:\\w+\\s){0,6}(?=(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|dollar.?\\b|capital.?|mobiliz\\S*|convention\\S*)))|((?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|dollar.?\\b|capital.?|mobiliz\\S*|convention\\S*)\\s(?:\\w+\\s){0,6}(?=(?:\\bclimat\\S*|global change|Global dimming|global environment change|\\bENSO\\b|\\bEl Ni|Southern Oscillation|extreme weather|weather pattern.?|warming|\\bwarmer|warmest|temperature|hotter|hottest|heat.?up|heat.?wave.?|cloudburst|aridity|drought.?|rainfall shortfall|flood\\S*|\\bstorm\\S*|extreme heat\\S*|Heat Island|cold wave.?|extreme precipitation.?|extreme rainfall|heavy rain.?|heavy downpour\\S*|thunder.?storm.?|ice storm.?|blizzard\\S*|hailstorm.?|tropical storm.?|Human activit\\S*|anthropogenic\\S*|wild.?fire\\S*|fire.?storm\\S*|\\bsea.?level|\\bsea.?ice|\\bmelt\\S*|Ocean acidification|\\bCOP\\b|\\bCOP.?\\d+|\\bIPCC\\b|\\bUNFCC\\b|Paris Agreement\\S*|Paris Climate Agreement.?|Montreal Protocol|nationally determined contribution.?|national adaptation plan.?|Rio Convention.?|1\\.5.?Â°C|2.?Â°C|1\\.5 degrees Celsius|2 degrees Fahrenheit\\S*|two degrees Celsius|net.?zero|negative emission\\S*|Carbon Neutral|carbon sink\\S*|Carbon negative|kyoto protocol))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG13_a', 'SDG_keywords': 'United Nations Framework Convention on Climate Change|\\bunfccc\\b|U\\.N\\.F\\.C\\.C\\.C\\.|Green Climate Fund|\\bGCF\\b|G\\.C\\.F\\.', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG13_b', 'SDG_keywords': '^(?=.*(?:\\bclimat\\S*|global change|Global dimming|global environment change|\\bENSO\\b|\\bEl Ni|Southern Oscillation|extreme weather|weather pattern.?|warming|\\bwarmer|warmest|temperature|hotter|hottest|heat.?up|heat.?wave.?|cloudburst|aridity|drought.?|rainfall shortfall|flood\\S*|\\bstorm\\S*|extreme heat\\S*|Heat Island|cold wave.?|extreme precipitation.?|extreme rainfall|heavy rain.?|heavy downpour\\S*|thunder.?storm.?|ice storm.?|blizzard\\S*|hailstorm.?|tropical storm.?|Human activit\\S*|anthropogenic\\S*|wild.?fire\\S*|fire.?storm\\S*|\\bsea.?level|\\bsea.?ice|\\bmelt\\S*|Ocean acidification|\\bCOP\\b|\\bCOP.?\\d+|\\bIPCC\\b|\\bUNFCC\\b|Paris Agreement\\S*|Paris Climate Agreement.?|Montreal Protocol|nationally determined contribution.?|national adaptation plan.?|Rio Convention.?|1\\.5.?Â°C|2.?Â°C|1\\.5 degrees Celsius|2 degrees Fahrenheit\\S*|two degrees Celsius|net.?zero|negative emission\\S*|Carbon Neutral|carbon sink\\S*|Carbon negative|kyoto protocol))(?=.*(?:action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*|capacity|\\bscope|financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG13_general', 'SDG_keywords': '\\bclimat\\S*|global change|Global dimming|global environment change|\\bENSO\\b|\\bEl Ni|Southern Oscillation|extreme weather|weather pattern.?|warming|\\bwarmer|warmest|temperature|hotter|hottest|heat.?up|heat.?wave.?|cloudburst|aridity|drought.?|rainfall shortfall|flood\\S*|\\bstorm\\S*|extreme heat\\S*|Heat Island|cold wave.?|extreme precipitation.?|extreme rainfall|heavy rain.?|heavy downpour\\S*|thunder.?storm.?|ice storm.?|blizzard\\S*|hailstorm.?|tropical storm.?|Human activit\\S*|anthropogenic\\S*|wild.?fire\\S*|fire.?storm\\S*|\\bsea.?level|\\bsea.?ice|\\bmelt\\S*|Ocean acidification|\\bCOP\\b|\\bCOP.?\\d+|\\bIPCC\\b|\\bUNFCC\\b|Paris Agreement\\S*|Paris Climate Agreement.?|Montreal Protocol|nationally determined contribution.?|national adaptation plan.?|Rio Convention.?|1\\.5.?Â°C|2.?Â°C|1\\.5 degrees Celsius|2 degrees Fahrenheit\\S*|two degrees Celsius|net.?zero|negative emission\\S*|Carbon Neutral|carbon sink\\S*|Carbon negative|kyoto protocol|\\bemission.?|\\bCO2\\b|carbon|green.?house|\\bGHG\\b|G\\.H\\.G\\.|Halocarbons|chlorofluorocarbon.?|\\bcfc\\b|c\\.f\\.c\\.|\\bCFCs\\b|water vapour|methane|\\bCH4\\b|nitrous oxide|\\bN2O\\b|Nitrogen Oxides|\\bNOx\\b|\\bozone.?|\\bO3\\b|fluorinated gas|perfluorocarbon.?|\\bPFCs\\b|hydrofluorocarbon.?|\\bHFCs\\b|sulphur hexafluoride|\\bSF6\\b|nitrogen trifluoride|\\bNF3\\b', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_1', 'SDG_keywords': '^(?=.*(?:marine|maritime|ocean|oceanography|\\bsea\\b|seawater\\S*|sublittoral|littoral|coast|tidal|aquatic|coral))(?=.*(?:pollut\\S*|nutrient\\S*|eutroph\\S*|Kelp|\\balga\\S*|plastic\\S*|micro.?plastic\\S*|debris\\S*|run.?off\\S*|chemical\\S*|arsenic\\S*|contaminat\\S*|fertiliz\\S*|waste)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_2', 'SDG_keywords': '^(?=.*(?:marine|maritime|ocean|oceanography|\\bsea\\b|seawater\\S*|sublittoral|littoral|coast|tidal|aquatic|coral|coral))(?=.*(?:sustainab\\S*|resilien\\S*|\\brestor\\S*|manag\\S*|mitigat\\S*|health|productiv\\S*|habitat\\S*|bleach\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_3', 'SDG_keywords': '^(?=.*(?:marine|maritime|ocean|oceanography|\\bsea\\b|seawater\\S*|sublittoral|littoral|coast|tidal|aquatic|coral))(?=.*(?:acidi\\S*|\\bpH\\b)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_4', 'SDG_keywords': '^(?=.*(?:\\bfish\\S*|seafood|blue food|\\bcatch\\b|\\bcatches\\b|bycatch|harvest\\S*|overfish\\S*))(?=.*(?:illegal|criminal|illegitimate|illicit|unauthorized|unlawful|unlicensed|unconstitutional|prohibited|forbidden|banned|unreported|underreport|unregulated|destruct\\S*|destro\\S*|diminish\\S*|exploit\\S*|sustainab\\S*|\\brestor\\S*|conserv\\S*|manag\\S*|mitig\\S*|\\bregulat\\S*|monitor\\S*|restrict\\S*|enforc\\S*|prohibit\\S*|\\bquota\\b|monitor\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_4', 'SDG_keywords': 'overfish\\S*|maximum sustainable yield|\\bMSY\\b', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_5', 'SDG_keywords': '^(?!.*(?:Marine and Protective Coatings|Volvo Ocean Race)).*(((?:marine|maritime|ocean|oceanography|\\bsea\\b|seawater\\S*|sublittoral|littoral|coast|tidal|aquatic|coral)\\s(?:\\w+\\s){0,6}(?=(?:\\brestor\\S*|conserv\\S*|protect\\S*|safeguard\\S*|preserv\\S*|\\breduc\\S*|\\bplan\\b|\\bplans\\b|planning|mitig\\S*|restrict\\S*|enforc\\S*|monitor\\S*|prohibit\\S*|reporting)))|((?:\\brestor\\S*|conserv\\S*|protect\\S*|safeguard\\S*|preserv\\S*|\\breduc\\S*|\\bplan\\b|\\bplans\\b|planning|mitig\\S*|restrict\\S*|enforc\\S*|monitor\\S*|prohibit\\S*|reporting)\\s(?:\\w+\\s){0,6}(?=(?:marine|maritime|ocean|oceanography|\\bsea\\b|seawater\\S*|sublittoral|littoral|coast|tidal|aquatic|coral))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_6', 'SDG_keywords': '^(?=.*(?:\\bfish\\S*|seafood|\\bcatch\\b|\\bcatches\\b|bycatch|harvest\\S*|aquaculture|blue food|mariculture))(?=.*(?:\\bsubsidy|\\bsubsidies|\\bsubsidiz|\\bsubsidis)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_6', 'SDG_keywords': '^(?=.*(?:\\bfish\\S*|seafood|\\bcatch\\b|\\bcatches\\b|bycatch|harvest\\S*|aquaculture|blue food|mariculture))(?=.*(?:illegal|criminal|illegitimate|illicit|unauthorized|unlawful|unlicensed|unconstitutional|prohibited|forbidden|banned|unreported|unregulated|destructive|destro\\S*|diminish\\S*|exploit\\S*|poach\\S*|traffick\\S*))(?=.*(?:instrument\\S*|\\blaw\\S*|enforc\\S*|restrict\\S*|prohibit\\S*|\\bquota\\b|\\bregulat\\S*|monitor\\S*|action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_7', 'SDG_keywords': '^(?=.*(?:econom\\S*|benefi\\S*|sustain\\S*))(?=.*(?:\\bfish\\S*|aquacultur\\S*|seafood|\\bcatch\\b|\\bcatches\\b|bycatch|blue food|mariculture))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_7', 'SDG_keywords': '^(?=.*(?:econom\\S*|benefi\\S*|sustain\\S*))(?=.*(?:marine|maritime|ocean|oceanography|\\bsea\\b|seawater\\S*|sublittoral|littoral|coast|tidal|aquatic|coral))(?=.*(?:resource\\S*|touris\\S*))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_a', 'SDG_keywords': '^(?=.*(?:marine|maritime|ocean|oceanography|\\bsea\\b|seawater\\S*|sublittoral|littoral|coast|tidal|aquatic|coral))(?=.*(?:scient\\S*|\\bknowledge|research\\S*|technolog\\S*|budget.?|\\bspending|health\\S*))(?=.*(?:accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_a', 'SDG_keywords': '^(?=.*(?:marine|maritime|ocean|oceanography|\\bsea\\b|seawater\\S*|sublittoral|littoral|coast|tidal|aquatic|coral))(?=.*(?:scient\\S*|\\bknowledge|research\\S*|technolog\\S*|budget.?|\\bspending|health\\S*))(?=.*(?:mammal\\S*|species|\\bplant\\S*|animal\\S*|bird.?|biodivers\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_a', 'SDG_keywords': '^(?=.*(?:scient\\S*|\\bknowledge|research\\S*|technolog\\S*|budget.?|\\bspending|health\\S*))(?=.*(?:\\bfish\\S*|cetacean\\S*|\\bwhale.?\\b)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_a', 'SDG_keywords': 'Intergovernmental Oceanographic Commission|Guidelines on the Transfer of Marine Technology', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_b', 'SDG_keywords': '^(?=.*(?:artisan\\S*|tradition\\S*|small.?scale))(?=.*(?:\\bfish\\S*|seafood|\\bcatch\\b|\\bcatches\\b|bycatch|harvest\\S*))(?=.*(?:resource\\S*|market.?|\\blaw.?|legal|\\bpolicy|\\bpolicies|institutional|\\bregulat\\S*|jurisdiction\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG14_c', 'SDG_keywords': '^(?=.*(?:marine|maritime|ocean|oceanography|\\bsea\\b|seawater\\S*|sublittoral|littoral|coast|tidal|aquatic|coral))(?=.*(?:restor\\S*|conserv\\S*|protect\\S*|safeguard\\S*|sustain\\S*|manag\\S*|mitig\\S*|monitor\\S*))(?=.*(?:\\blaw\\S*|legal\\S*|\\bpolicy|\\bpolicies|institutional|\\bregulat\\S*|jurisdiction\\S*|instrument\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_1', 'SDG_keywords': '^(?=.*(?:terrestrial|inland|fresh.?water|water eco.?system.?|\\bforest\\S*|wood.?land|wetland|marsh|mountain.?|dryland|rain.?forest\\S*|agroforest\\S*|tundra))(?=.*(?:conserv\\S*|\\brestor\\S*|reserv\\S*|rehabilitat\\S*|mainten\\S*|protect\\S*|preserv\\S*|safeguard\\S*|secur\\S*|sustain\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_1', 'SDG_keywords': '^(?!.*(?:financial service.?|nature reserve.?))(?=.*(?:conserv\\S*|\\brestor\\S*|reserv\\S*|rehabilitat\\S*|mainten\\S*|protect\\S*|preserv\\S*|safeguard\\S*|secur\\S*|sustain\\S*)).+(((?:eco.?system.?|\\becolog\\S*|environment\\S*|\\bnatur\\S*|environs\\S*|biosphere\\S*)\\s(?:\\w+\\s){0,3}(?=(?:service\\S*|\\bgood.?\\b|\\bproduct.?\\b|\\bsupply|\\bsupplies|contribution\\S*)))|((?:service\\S*|\\bgood.?\\b|\\bproduct.?\\b|\\bsupply|\\bsupplies|contribution\\S*)\\s(?:\\w+\\s){0,3}(?=(?:eco.?system.?|\\becolog\\S*|environment\\S*|\\bnatur\\S*|environs\\S*|biosphere\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_2', 'SDG_keywords': '^(?=.*(?:sustainable)).+(((?:forest\\S*)\\s(?:\\w+\\s){0,4}(?=(?:management\\S*)))|((?:management\\S*)\\s(?:\\w+\\s){0,4}(?=(?:forest\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_2', 'SDG_keywords': '(((?:\\btree.?plant\\S*|plant.? tree\\S*|planting tree\\S*|deforest\\S*|afforest\\S*|reforest\\S*|silvicultur\\S*|mangrove\\S*|silviculture|shrub)\\s(?:\\w+\\s){0,4}(?=(?:conserv\\S*|\\brestor\\S*|sustain\\S*|manag\\S*|mitig\\S*|health\\S*|resilien\\S*|stewardship\\S*|certifi\\S*|audit\\S*|account\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)))|((?:conserv\\S*|\\brestor\\S*|sustain\\S*|manag\\S*|mitig\\S*|health\\S*|resilien\\S*|stewardship\\S*|certifi\\S*|audit\\S*|account\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)\\s(?:\\w+\\s){0,4}(?=(?:\\btree.?plant\\S*|plant.? tree\\S*|planting tree\\S*|deforest\\S*|afforest\\S*|reforest\\S*|silvicultur\\S*|mangrove\\S*|silviculture|shrub))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_2', 'SDG_keywords': '(((?:deforestation|forest product\\S*|timber\\S*|degraded forest\\S*)\\s(?:\\w+\\s){0,9}(?=(?:lower|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)))|((?:lower|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)\\s(?:\\w+\\s){0,9}(?=(?:deforestation|forest product\\S*|timber\\S*|degraded forest\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_2', 'SDG_keywords': 'Preventive silviculture|\\bREDD\\b|R\\.E\\.D\\.D\\.|Reducing Emissions from Deforestation and forest Degradation', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_3', 'SDG_keywords': '^(?=.*(?:degrad\\S*|desertif\\S*|contamin\\S*|pollut\\S*|de.?nitrificat\\S*|health\\S*|nitro\\S*|drought\\S*|flood\\S*))(?=.*(?:\\bland|\\bsoil\\b|sediment\\S*))(?=.*(?:\\bcombat\\S*|conserv\\S*|\\brestor\\S*|sustain\\S*|manag\\S*|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_4', 'SDG_keywords': '^(?=.*(?:mountain\\S*|alpine\\S*))(?=.*(?:eco.?system.?|\\becolog\\S*|environment\\S*|\\bnatur\\S*|environs\\S*|biosphere\\S*|biodiver\\S*|vegetation\\S*|protected)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_4', 'SDG_keywords': 'Mountain Green Cover Index', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_5', 'SDG_keywords': '^(?!.*(?:natural gas))(?=.*(?:nature|natural))(?=.*(?:habitat\\S*|\\breserve.?\\b|\\bpreserve|\\bpark.?\\b)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_5', 'SDG_keywords': 'Protected Area\\S*|protection area\\S*|conservation area\\S*|conservation park\\S*|biodivers\\S*|biological diversity|Red List|habitat conversion|habitat degradation\\S*|habitat fragmentation\\S*|habitat loss', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_5', 'SDG_keywords': '^(?!.*(?:habitat for human|human habitat)).*(((?:habitat|\\breserve.?\\b|sanctuar\\S*|threaten\\S*|endanger\\S*|extinct\\S*|Refuge\\b|\\bcorridor.?|\\bdiversity|richness|evenness|abundance|vulnerab\\S*|population fragmentation|extirpate\\S*|environment\\S*|terrestrial|inland|fresh.?water|forest\\S*|grassland|Wetland|Mountain\\S*)\\s(?:\\w+\\s){0,4}(?=(?:species|Wildlife|animal\\S*|vertebrate\\S*|mammal\\S*|amphibian\\S*|\\bBird.?|Flora|Fauna)))|((?:species|Wildlife|animal\\S*|vertebrate\\S*|mammal\\S*|amphibian\\S*|\\bBird.?|Flora|Fauna)\\s(?:\\w+\\s){0,4}(?=(?:habitat|\\breserve.?\\b|sanctuar\\S*|threaten\\S*|endanger\\S*|extinct\\S*|Refuge\\b|\\bcorridor.?|\\bdiversity|richness|evenness|abundance|vulnerab\\S*|population fragmentation|extirpate\\S*|environment\\S*|terrestrial|inland|fresh.?water|forest\\S*|grassland|Wetland|Mountain\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_6', 'SDG_keywords': '^(?=.*(?:genetic resource\\S*|genetic|\\bgene\\b))(?=.*(?:\\bfair\\S*|equitab\\S*|access\\S*|availab\\S*|equal\\S*|\\bshare.?\\b|sharing)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_7', 'SDG_keywords': '^(?=.*(?:poach\\S*|traffic\\S*|illegal|criminal|illegitimate|illicit|unauthorized|unlawful|unlicensed|unconstitutional|prohibited|forbidden|banned))(?=.*(?:species|flora|fauna|wildlife|logg\\S*|animal\\S*|mammal\\S*|\\bhunt\\S*|cultivat\\S*|\\bcatch\\b|\\bcatches\\b)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_8', 'SDG_keywords': '\\binvasive|\\binvasion|\\balien\\S*|\\binvade\\S*|nonindigenous|non.?indigenous|non.?native', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_9', 'SDG_keywords': '^(?!.*(?:business environment\\S*|political environment\\S*|social environment\\S*))(?=.*(?:ecosystem\\S*|biodiver\\S*)).+(((?:\\bnation\\S*|countr\\S*|region\\S*|local)\\s(?:\\w+\\s){0,3}(?=(?:development|poverty reduction|accounting|reporting|Aichi|action plan\\S*|target\\S*|planning|strateg\\S*|action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*)))|((?:development|poverty reduction|accounting|reporting|Aichi|action plan\\S*|target\\S*|planning|strateg\\S*|action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*)\\s(?:\\w+\\s){0,3}(?=(?:\\bnation\\S*|countr\\S*|region\\S*|local))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_a', 'SDG_keywords': '^(?=.*(?:eco.?system.?|\\becolog\\S*|environment\\S*|\\bnatur\\S*|environs\\S*|biosphere\\S*|biodiver\\S*))(?=.*(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|revenue\\S*|\\bvalue|incentiv\\S*|\\bspending\\S*))(?=.*(?:conserv\\S*|preserv\\S*|sustainable use|sustainably use))(?!.*business environment)(?!.*political environment)(?!.*social environment)', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_b', 'SDG_keywords': '^(?=.*(?:forest\\S*|biodiversity))(?=.*(?:conserv\\S*|preserv\\S*|manag\\S*|\\bsustain\\S*))(?=.*(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold|revenue\\S*|\\bvalue|incentiv\\S*|\\bspending\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_b', 'SDG_keywords': '^(?=.*(?:reforestation\\S*))(?=.*(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold|revenue\\S*|\\bvalue|incentiv\\S*|\\bspending\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_c', 'SDG_keywords': '^(?=.*(?:poach\\S*|traffic\\S*|illicit\\S*|illegal))(?=.*(?:species|flora|fauna|wildlife|logg\\S*|animal\\S*|mammal\\S*|\\bhunt\\S*|cultivat\\S*|\\bcatch\\b|\\bcatches\\b))(?=.*(?:global support\\S*|\\blocal communit\\S*|local entit\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_general', 'SDG_keywords': '^((?=.*(?:eco.?system.?|\\becolog\\S*|environment\\S*|\\bnatur\\S*|environs\\S*|biosphere\\S*))(?=.*(?:resilien\\S*))|(?=.*(?:human))(?=.*(?:wildlife))(?=.*(?:conflict\\S*))|(?=.*(?:community))(?=.*(?:conserv\\S*))|eco.?touris\\S*).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG15_general', 'SDG_keywords': '^(?=.*(?:eco.?system.?|\\becolog\\S*|environment\\S*|\\bnatur\\S*|environs\\S*|biosphere\\S*))(?=.*(?:impact.?\\b|conserv\\S*|\\brestor\\S*|sustaina\\S*|manag\\S*|mitig\\S*|health.?\\b|\\bwell\\b|resilien\\S*|stewardship\\S*|audit\\S*|account\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_1', 'SDG_keywords': '^(?=.*(?:violen\\S*|victim\\S*|homicid\\S*|murder\\S*|\\bkill\\S*|assault\\S*|assassination\\S*))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*|\\bcombat\\S*|\\bavoid\\S*|\\baddress\\S*|fight|tackl\\S*|response to|cope.?with|coping with|deal.?with|dealing with|handl\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_1', 'SDG_keywords': '^(?=.*(?:verbal|physical|domestic|psychological|child|\\bsex\\S*))(?=.*(?:\\babus\\S*|violen\\S*|assault\\S*|torture))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*|\\bcombat\\S*|\\bavoid\\S*|\\baddress\\S*|fight|tackl\\S*|response to|cope.?with|coping with|deal.?with|dealing with|handl\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_1', 'SDG_keywords': 'safe walking|peaceful societ\\S*', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_10', 'SDG_keywords': '^(?=.*(?:public access|availab\\S*|attack\\S*|freedom|\\bkill\\S*|kidnap\\S*|murder\\S*|enforc\\S*|disappear\\S*|deten\\S*|detain\\S*|tortur\\S*))(?=.*(?:journalis\\S*|media|\\bpress|unionis\\S*|human rights advocate\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_10', 'SDG_keywords': 'Aarhus Convention', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_2', 'SDG_keywords': '^(?=.*(?:child\\S*|\\bteen.?\\b|teenage\\S*|juvenile\\S*|youth|young|\\bminor.?\\b|under 5|under five|underfive|before fifth|adolescen\\S*|\\bgirl\\S*|\\bboy\\b|\\bboys\\b|\\bkid\\b|\\bkids\\b|\\bkiddo|\\bkiddy|\\bkiddies|offspring\\S*))(?=.*(?:\\babus\\S*|bully|kidnap\\S*|exploit\\S*|traffick\\S*|victim\\S*|violen\\S*|tortur\\S*|punish\\S*|aggress\\S*|\\brap\\S*|\\bporn\\S*))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_3', 'SDG_keywords': '^(?!.*(?:Access Bank)).*(((?:access\\S*|resort to|promot\\S*)\\s(?:\\w+\\s){0,6}(?=(?:\\bcode.?\\b|\\bnorm.?\\b|justice|authorit\\S*|\\bpolice\\S*|prosecutor.?|\\brule.?\\b|\\blaw.?\\b|Bylaw.?\\b|\\blegal|legislation|litigation|conflict resolution\\S*|dispute resolution\\S*)))|((?:\\bcode.?\\b|\\bnorm.?\\b|justice|authorit\\S*|\\bpolice\\S*|prosecutor.?|\\brule.?\\b|\\blaw.?\\b|Bylaw.?\\b|\\blegal|legislation|litigation|conflict resolution\\S*|dispute resolution\\S*)\\s(?:\\w+\\s){0,6}(?=(?:access\\S*|resort to|promot\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_3', 'SDG_keywords': '^(?=.*(?:victim\\S*))(?=.*(?:competent authorit\\S*|violence|detain\\S*|prison|inmate|disput\\S*|officially recognized conflict\\S*))(?!.*Annual Report)', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_3', 'SDG_keywords': 'actual innocence|false confession|Un.?sentenced detain\\S*|pre.?sentence detention.?|Arbitrary detent\\S*|Enforced disappearance|crime reporting', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_4', 'SDG_keywords': '^(?!.*(?:statement\\S*|\\bgranted|investigat\\S*|Financial risk\\S*|Financial Disclosure\\S*|Financial Stability|financial sector\\S*|financial group\\S*|financial crisis|financial condition\\S*|financial impact\\S*|financial inclusive\\S*|financial statement\\S*|Financial Times|financial press|financial result\\S*|financial instrument\\S*|Financial Review\\S*|financial assumption\\S*|finance corporation\\S*))(?=.*(?:\\brecovery|\\breturn|\\bagainst\\b|\\bAnti.?\\b|\\bcombat\\S*|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+(((?:illegal|criminal|illegitimate|illicit|unauthorized|unlawful|unlicensed|unconstitutional|prohibited|forbidden|banned|crime|cybercrime|irregular\\S*|prohibited|smuggl\\S*|unwarranted|stolen|\\bsteal|theft|seized|traced|conflict\\S*|traffic\\S*|terroris\\S*)\\s(?:\\w+\\s){0,6}(?=(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|\\barm\\S*|\\bgun\\S*|weapon\\S*|ammunition\\S*|rifle\\S*|pistol\\S*|firearm\\S*|shotgun\\S*|\\basset\\S*)))|((?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|\\barm\\S*|\\bgun\\S*|weapon\\S*|ammunition\\S*|rifle\\S*|pistol\\S*|firearm\\S*|shotgun\\S*|\\basset\\S*)\\s(?:\\w+\\s){0,6}(?=(?:illegal|criminal|illegitimate|illicit|unauthorized|unlawful|unlicensed|unconstitutional|prohibited|forbidden|banned|crime|cybercrime|irregular\\S*|prohibited|smuggl\\S*|unwarranted|stolen|\\bsteal|theft|seized|traced|conflict\\S*|traffic\\S*|terroris\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_4', 'SDG_keywords': 'unauthorized acquisition\\S*|money.?launder|money.?washing|launder money|laundering money', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_5', 'SDG_keywords': 'anticorruption|Abuse of discretion', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_5', 'SDG_keywords': '(((?:corrupt\\S*|\\bbrib\\S*|lobbying|extortion\\S*|cronyism|nepotism|parochialism|patronage\\S*|influence peddling|\\bgraft\\S*|embezzl\\S*|fraud\\S*|\\bextort\\S*|blackmail|Favoritism|clientelism|Tax evasion\\S*)\\s(?:\\w+\\s){0,6}(?=(?:identif\\S*|takes into account|aware of|\\bpolicy|\\bpolicies|legislation\\S*|\\bregulat\\S*|manag\\S*|\\brule.?\\b|\\bagainst\\b|\\bAnti.?\\b|\\bcombat\\S*|\\bavoid\\S*|\\baddress\\S*|fight\\S*|tackl\\S*|cope.?with|coping with|deal.?with|dealing with|handl\\S*|\\bmeasure.?\\b|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)))|((?:identif\\S*|takes into account|aware of|\\bpolicy|\\bpolicies|legislation\\S*|\\bregulat\\S*|manag\\S*|\\brule.?\\b|\\bagainst\\b|\\bAnti.?\\b|\\bcombat\\S*|\\bavoid\\S*|\\baddress\\S*|fight\\S*|tackl\\S*|cope.?with|coping with|deal.?with|dealing with|handl\\S*|\\bmeasure.?\\b|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)\\s(?:\\w+\\s){0,6}(?=(?:corrupt\\S*|\\bbrib\\S*|lobbying|extortion\\S*|cronyism|nepotism|parochialism|patronage\\S*|influence peddling|\\bgraft\\S*|embezzl\\S*|fraud\\S*|\\bextort\\S*|blackmail|Favoritism|clientelism|Tax evasion\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_5', 'SDG_keywords': '^(?=.*(?:contact\\S*|asked|\\bpay\\b|\\bpaid|extort\\S*|\\bentrust\\S*))(?=.*(?:\\bofficial.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_5', 'SDG_keywords': '^(?=.*(?:miscarriage))(?=.*(?:justice)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_6', 'SDG_keywords': '(((?:institut\\S*|\\bgovern\\S*|legislat\\S*|judicia\\S*|judicial system.?|penal system.?|legal system.?|criminal tribunal|management system.?|internal control system.?|Supervisory Board.?|\\bBoard\\b|public service\\S*|civil service\\S*|health.?care service.?|health.?care system.?|education service.?|Education system.?|curriculum|School facilit\\S*|government service.?|social welfare service.?|organization.?\\b|association.?\\b|society|societies|peer group.?|social group.?|\\breligion\\S*|communit\\S*|Chairman)\\s(?:\\w+\\s){0,4}(?=(?:effective|accountab\\S*|transparent\\S*|satisf\\S*|availability|accessib\\S*|Waiting time|acceptability|adequate standard|\\bAfford\\S*|Quality of facilit\\S*|Equal treatment.?|treated equally|Courtesy|courteous)))|((?:effective|accountab\\S*|transparent\\S*|satisf\\S*|availability|accessib\\S*|Waiting time|acceptability|adequate standard|\\bAfford\\S*|Quality of facilit\\S*|Equal treatment.?|treated equally|Courtesy|courteous)\\s(?:\\w+\\s){0,4}(?=(?:institut\\S*|\\bgovern\\S*|legislat\\S*|judicia\\S*|judicial system.?|penal system.?|legal system.?|criminal tribunal|management system.?|internal control system.?|Supervisory Board.?|\\bBoard\\b|public service\\S*|civil service\\S*|health.?care service.?|health.?care system.?|education service.?|Education system.?|curriculum|School facilit\\S*|government service.?|social welfare service.?|organization.?\\b|association.?\\b|society|societies|peer group.?|social group.?|\\breligion\\S*|communit\\S*|Chairman))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_6', 'SDG_keywords': 'budget reliability|efficient service delivery|actual.?to.?budget.?', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_6', 'SDG_keywords': '(((?:peace\\S*|inclusive|\\bfair\\S*)\\s(?:\\w+\\s){0,4}(?=(?:societ\\S*)))|((?:societ\\S*)\\s(?:\\w+\\s){0,4}(?=(?:peace\\S*|inclusive|\\bfair\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_6', 'SDG_keywords': '(((?:public financ\\S*|Public Expenditure.?|government budget\\S*|government expenditure.?)\\s(?:\\w+\\s){0,4}(?=(?:management.?|Accountab\\S*)))|((?:management.?|Accountab\\S*)\\s(?:\\w+\\s){0,4}(?=(?:public financ\\S*|Public Expenditure.?|government budget\\S*|government expenditure.?))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_6', 'SDG_keywords': '^(?=.*(?:Actual expenditure.?|Aggregate expenditure.?|final budget\\S*))(?=.*(?:approved budget\\S*|budgeted expenditure.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_6', 'SDG_keywords': '^(?=.*(?:ratio|share of|proportion.?|\\bpercent\\S*)).+(((?:expenditure.?|spending.?)\\s(?:\\w+\\s){0,4}(?=(?:budget.?\\b)))|((?:budget.?\\b)\\s(?:\\w+\\s){0,4}(?=(?:expenditure.?|spending.?))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_7', 'SDG_keywords': '^(?=.*(?:all members))(?=.*(?:meeting\\S*|discussion\\S*))(?=.*(?:\\binformed|\\bengag\\S*|\\bparticipat\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_7', 'SDG_keywords': '^(?=.*(?:\\bBoard\\b|Committee\\b|leadership))(?=.*(?:inclusive|participatory|representative.?))(?=.*(?:\\bgender|\\bsex\\S*|ethni\\S*|\\brace|racial|\\breligion|Disabled|disabilit\\S*|handicapped|incapacitated|crippled|\\bblind\\b|disadvantaged|woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?|\\bLGBT\\S*|\\blesbian|\\bgay\\b|bisexual|transgender|\\bQueer\\b|Questioning|Intersex|\\bAllies\\b|\\bAsexual\\b|Pansexual)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_7', 'SDG_keywords': '^(?=.*(?:decision.?|legislature|institution\\S*|public service\\S*|judiciary))(?=.*(?:responsive|inclusive|participatory|representative.?|independen\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_7', 'SDG_keywords': 'democracy', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_7', 'SDG_keywords': '^(?=.*(?:separat\\S*))(?=.*(?:\\bpower\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_8', 'SDG_keywords': '(((?:\\beffective)\\s(?:\\w+\\s){0,2}(?=(?:participation\\S*|\\bteam.?\\b)))|((?:participation\\S*|\\bteam.?\\b)\\s(?:\\w+\\s){0,2}(?=(?:\\beffective))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_8', 'SDG_keywords': '^(?=.*(?:institution\\S*|global govern\\S*|international organization\\S*))(?=.*(?:participat\\S*|\\bvote|\\bvoting|\\bvoice|suffrag\\S*|representation|\\belection|electoral))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_8', 'SDG_keywords': '^(?=.*(?:\\bno \\b|\\bnot\\b|\\none\\b))(?=.*(?:casting vot\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_8', 'SDG_keywords': '(((?:\\beach\\b)\\s(?:\\w+\\s){0,6}(?=(?:one vote)))|((?:one vote)\\s(?:\\w+\\s){0,6}(?=(?:\\beach\\b))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_9', 'SDG_keywords': '^(?=.*(?:legal))(?=.*(?:identity)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_9', 'SDG_keywords': '^(?=.*(?:birth))(?=.*(?:regist\\S*|certifi\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_a', 'SDG_keywords': '^(?=.*(?:\\bnation\\S*|countr\\S*|\\bstate.?\\b|domestic|international))(?=.*(?:institution\\S*|cooperat\\S*|collaborat\\S*|joint effort\\S*|partnership\\S*))(?=.*(?:violen\\S*|terroris\\S*|\\bcrime|criminal|genocid\\S*|murder\\S*|human traffick\\S*|refugee\\S*|extremis\\S*|insurgen\\S*|\\bwar\\b|\\bwars\\b|warfare\\S*))(?=.*(?:\\bagainst\\b|\\bAnti.?\\b|\\bcombat\\S*|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_a', 'SDG_keywords': '^(?=.*(?:\\bnation\\S*|countr\\S*|\\bstate.?\\b|domestic|international))(?=.*(?:institution\\S*|cooperat\\S*|collaborat\\S*|joint effort\\S*|partnership\\S*))(?=.*(?:\\barm\\S*|\\bgun\\S*|weapon\\S*))(?=.*(?:conflict\\S*))(?=.*(?:\\bagainst\\b|\\bAnti.?\\b|\\bcombat\\S*|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_a', 'SDG_keywords': '^(?=.*(?:\\bnation\\S*|countr\\S*|\\bstate.?\\b|domestic))(?=.*(?:independen\\S*))(?=.*(?:institution\\S*|human right\\S*|civil right\\S*|democracy|treaty|\\bcivil))(?=.*(?:accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_a', 'SDG_keywords': '^(?=.*(?:accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+(((?:\\bpeace)\\s(?:\\w+\\s){0,3}(?=(?:\\bkeep\\S*)))|((?:\\bkeep\\S*)\\s(?:\\w+\\s){0,3}(?=(?:\\bpeace))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_a', 'SDG_keywords': 'Paris Principle\\S*|Geneva Convention', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_b', 'SDG_keywords': '^(?=.*(?:\\blaw\\S*|legislat\\S*|\\bpolicy|\\bpolicies|human right\\S*|protect\\S*|safeguard\\S*))(?=.*(?:discrimin\\S*|harass\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_general', 'SDG_keywords': 'ethnic conflict\\S*|exonerat\\S*|justice system\\S*|^(?=.*(?:environment\\S*))(?=.*(?:\\blaw\\S*|govern\\S*|\\benact\\S*|legistlat\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_general', 'SDG_keywords': '\\bLGBT\\S*|\\blesbian|\\bgay\\b|bisexual|transgender|\\bQueer\\b|Questioning|Intersex|\\bAllies\\b|\\bAsexual\\b|Pansexual|\\bDEI\\b|\\bDEIJ\\b|Social Justice|inclusive societ\\S*|diversity and inclusion', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_general', 'SDG_keywords': '(((?:\\bDiversity|Inclusion)\\s(?:\\w+\\s){0,3}(?=(?:\\bEquity)))|((?:\\bEquity)\\s(?:\\w+\\s){0,3}(?=(?:\\bDiversity|Inclusion))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_general', 'SDG_keywords': '(((?:\\bdata|\\binformation|\\bcyber\\b|\\bcloud\\b|\\bInternet\\b|\\bnetwork\\b|\\bmobile\\b)\\s(?:\\w+\\s){0,4}(?=(?:privacy|security|protection|sensitive|confidential\\S*|\\battack\\S*|\\bhack\\S*|\\bcrime|\\bterroris\\S*|warfare\\S*)))|((?:privacy|security|protection|sensitive|confidential\\S*|\\battack\\S*|\\bhack\\S*|\\bcrime|\\bterroris\\S*|warfare\\S*)\\s(?:\\w+\\s){0,4}(?=(?:\\bdata|\\binformation|\\bcyber\\b|\\bcloud\\b|\\bInternet\\b|\\bnetwork\\b|\\bmobile\\b))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG16_general', 'SDG_keywords': 'unauthorized access|\\bGDPR\\b|Privacy Protection|Privacy Act|\\bCOPPA\\b|\\bHIPPA\\b|\\bECPA\\b|\\bInfoSec|Cybercrime|Cyber.?sex\\S*|Computer fraud|Cybergeddon|Cyberterrorism|Cyber.?warfare|Data breach|IT risk.?|cybersecurity|Identity theft', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_1', 'SDG_keywords': '^(?=.*(?:domestic resource\\S*|domestic capacity|domestic budget\\S*))(?=.*(?:revenue\\S*|budget\\S*|\\btax|expenditure\\S*))(?!.*governmental charge)', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_1', 'SDG_keywords': '^(?=.*(?:government revenue\\S*))(?=.*(?:\\bGDP\\b)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_10', 'SDG_keywords': '^(?=.*(?:\\btrade\\b|\\btrading|\\bWTO\\b))(?=.*(?:universal|rules.?based|\\bopen\\b|non.?discrimin\\S*|equitab\\S*|equal\\S*|multilateral))(?!.*equity methodS*)(?!.*equity instrumentS*)(?!.*liabilities and equity)(?!.*trading income)(?!.*open group)(?!.*Private Limited)', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_10', 'SDG_keywords': 'Doha Development Agenda|^(?=.*(?:tariff\\S*))(?=.*(?:average)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_11', 'SDG_keywords': '^(?=.*(?:accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*))(?=.*(?:export\\S*))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_12', 'SDG_keywords': '^(?=.*(?:market access))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_12', 'SDG_keywords': '^(?=.*(?:duty|duties|\\bquota\\b|quotum))(?=.*(?:\\bfree\\b))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_13', 'SDG_keywords': '^(?=.*(?:macroeconomic\\S*|macro.?econom\\S*))(?=.*(?:stability)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_13', 'SDG_keywords': '^(?=.*(?:macroeconomic\\S*|macro.?econom\\S*))(?=.*(?:\\bpolicy|\\bpolicies))(?=.*(?:coordination|coherence)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_14', 'SDG_keywords': '^(?=.*(?:action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*))(?=.*(?:coheren\\S*|coordinat\\S*|consistent|systematic))(?=.*(?:sustainab\\S*|\\bSDG.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_15', 'SDG_keywords': '^(?!.*(?:with respect to))(?=.*(?:respect))(?=.*(?:leadership|initiative|\\blead\\S*|direction\\S*|\\bpolicy|\\bpolicies|framework\\S*|planning))(?=.*(?:countr\\S*|\\bnation\\S*|\\bState\\b|government\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_15', 'SDG_keywords': '^(?=.*(?:\\bpolicy|\\bpolicies|framework\\S*|\\bplan\\b|\\bplans\\b|planning|objective\\S*|priorit\\S*|goal.?|target.?))(?=.*(?:country.?owned|country.?led|nation.?owned|nation.?led|\\bState.?owned|\\bState.?led|government.?owned|government.?led)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_16', 'SDG_keywords': '^(?=.*(?:Sustainable|\\bSDG.?|goal.?)).+(((?:\\bmulti.?)\\s(?:\\w+\\s){0,3}(?=(?:stakeholder\\S*|partner\\S*|cooperat\\S*|collaborat\\S*)))|((?:stakeholder\\S*|partner\\S*|cooperat\\S*|collaborat\\S*)\\s(?:\\w+\\s){0,3}(?=(?:\\bmulti.?))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_16', 'SDG_keywords': '^(?=.*(?:\\bshare.?\\b|\\bsharing|mobiliz\\S*|assembl\\S*|marshal\\S*))(?=.*(?:\\bknowledge|expertise|\\btech\\S*|automation|financial resource\\S*))(?=.*(?:Sustainable|\\bSDG.?|goal.?\\b)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_16', 'SDG_keywords': '^(?=.*(?:Global Partnership|joint effort\\S*))(?=.*(?:sustainable|\\bSDG.?|goal.?\\b)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_17', 'SDG_keywords': '^(?=.*(?:partnership\\S*))(?=.*(?:\\bpublic|private|civil societ\\S*|government\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_18', 'SDG_keywords': '^(?=.*(?:\\bdata|statistic\\S*|indicator\\S*))(?=.*(?:high.?quality|timely|reliable|availab\\S*))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_19', 'SDG_keywords': '^(?=.*(?:regist\\S*))(?=.*(?:birth|death)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_19', 'SDG_keywords': '^(?=.*(?:measur\\S*|monitor\\S*))(?=.*(?:sustainable develop\\S*|\\bSDG.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_19', 'SDG_keywords': '^(?=.*(?:statistic\\S*))(?=.*(?:capacity|strengthen\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_19', 'SDG_keywords': '^(?=.*(?:census))(?=.*(?:population|\\bhousing)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_2', 'SDG_keywords': '\\bODA\\b|^(?=.*(?:development assistance))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_3', 'SDG_keywords': '^(?!.*(?:statement\\S*|\\bgrant.?\\b|subsid\\S*|budget\\S*|investigat\\S*|Financial risk\\S*|Financial Disclosure\\S*|Financial Stability|financial sector\\S*|financial group\\S*|financial crisis|financial condition\\S*|financial impact\\S*|financial inclusive\\S*|financial statement\\S*|Financial Times|financial press|financial result\\S*|financial instrument\\S*|Financial Review\\S*|financial assumption\\S*|finance corporation\\S*|Principles for Responsible Investment))(?=.*(?:financial resource\\S*|\\bfund.?\\b|\\bfunding\\b|financial assist\\S*|financial aid|\\baid.? to|government aid|state aid|invest\\S*|\\bdonat\\S*|official flow\\S*)).+(((?:\\bto\\b|\\bfor\\b)\\s(?:\\w+\\s){0,3}(?=(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))))|((?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))\\s(?:\\w+\\s){0,3}(?=(?:\\bto\\b|\\bfor\\b))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_3', 'SDG_keywords': '^(?=.*(?:foreign direct investment|\\bFDI\\b|official development assistance|South.?South cooperation.?|remittance\\S*))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_4', 'SDG_keywords': '^(?!.*(?:Financial risk\\S*|Financial Disclosure\\S*|Financial Stability|financial sector\\S*|financial group\\S*|financial crisis|financial condition\\S*|financial impact\\S*|financial inclusive\\S*|financial statement\\S*|Financial Times|financial press|financial result\\S*|financial instrument\\S*|Financial Review\\S*|financial assumption\\S*|finance corporation\\S*))(?=.*(?:debt\\S*))(?=.*(?:financ\\S*|relief\\S*|restructuring|sustainab\\S*|service\\S*|distress\\S*))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_5', 'SDG_keywords': '^(?=.*(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?))(?=.*(?:promot\\S*))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_6', 'SDG_keywords': '^(?=.*(?:access\\S*|availab\\S*|facilit\\S*))(?=.*(?:\\bscience|\\btech\\S*|innovation\\S*|knowledge.?sharing|Internet|broadband))(?=.*(?:North.?South|South.?South|triangular region\\S*|((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_7', 'SDG_keywords': '^(?=.*(?:environment\\S*))(?=.*(?:technolog\\S*))(?=.*(?:development\\S*|transfer.?|dissemination\\S*|diffusion\\S*))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_8', 'SDG_keywords': '^(?=.*(?:technolog\\S*|\\bscience|innovation\\S*|information|communication.?|internet))(?=.*(?:capacity))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_9', 'SDG_keywords': '^(?=.*(?:capacity building|international support.?))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_9', 'SDG_keywords': '^(?=.*(?:financ\\S*|\\btechnical|technolog\\S*))(?=.*(?:assistance|\\baid\\b))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b)))))(?!.*financial statementS*)', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_9', 'SDG_keywords': '^(?=.*(?:North.?South|South.?South|triangular))(?=.*(?:cooperat\\S*|collaborat\\S*|joint effort\\S*|partnership\\S*))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_general', 'SDG_keywords': '(((?:sustainab\\S*|global)\\s(?:\\w+\\s){0,4}(?=(?:partner\\S*|cooperat\\S*|collaborat\\S*|joint effort\\S*|Alliance|coordinat\\S*|\\bstabil\\S*|stabl\\S*)))|((?:partner\\S*|cooperat\\S*|collaborat\\S*|joint effort\\S*|Alliance|coordinat\\S*|\\bstabil\\S*|stabl\\S*)\\s(?:\\w+\\s){0,4}(?=(?:sustainab\\S*|global))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG17_general', 'SDG_keywords': '^(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+(((?:partner\\S*|cooperat\\S*|collaborat\\S*|joint effort\\S*|Alliance)\\s(?:\\w+\\s){0,6}(?=(?:between)))|((?:between)\\s(?:\\w+\\s){0,6}(?=(?:partner\\S*|cooperat\\S*|collaborat\\S*|joint effort\\S*|Alliance))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_1', 'SDG_keywords': '^(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*))(?=.*(?:hunger|undernourish\\S*|undernutrion|starv\\S*|famine\\S*|malnourish\\S*|malnutrition\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_1', 'SDG_keywords': '^(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+(((?:food|nutrition.?)\\s(?:\\w+\\s){0,5}(?=(?:insecurity|desert.?\\b|deprivation.?|deficien\\S*)))|((?:insecurity|desert.?\\b|deprivation.?|deficien\\S*)\\s(?:\\w+\\s){0,5}(?=(?:food|nutrition.?))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_1', 'SDG_keywords': '^(?=.*(?:food|nutrition.?))(?=.*(?:access|safe|secur\\S*|nutritious|sufficient|\\bample|plentiful|abundant)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_2', 'SDG_keywords': '^(?=.*(?:malnutrition.?|malnourish|undernourish|undernutrition|under nourished|stunting|wasting|overweight\\S*|underweight\\S*|\\bpolio\\S*|paralysis\\S*|tephromyelitis\\S*|nutrition\\S*|\\banaem\\S*|\\banem\\S*))(?=.*(?:child\\S*|\\bteen.?\\b|teenage\\S*|juvenile\\S*|youth|young|\\bminor.?\\b|under 5|under five|underfive|before fifth|adolescen\\S*|\\bgirl\\S*|\\bboy\\b|\\bboys\\b|\\bkid\\b|\\bkids\\b|\\bkiddo|\\bkiddy|\\bkiddies|offspring\\S*|infant\\S*|neonate\\S*|newborn|baby|babies|toddler|older)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_2', 'SDG_keywords': '^(?=.*(?:malnutrition.?|malnourish|undernourish|undernutrition|under nourished|stunting|wasting|overweight\\S*|underweight\\S*|\\bpolio\\S*|paralysis\\S*|tephromyelitis\\S*|nutrition\\S*|\\banaem\\S*|\\banem\\S*))(?=.*(?:pregnan\\S*|lactat\\S*))(?=.*(?:women|woman)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_3', 'SDG_keywords': '^(?=.*(?:accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*))(?=.*(?:agricultur\\S*|\\bagro\\S*|agronom\\S*|agrarian\\S*|\\bcrop\\S*|food\\S*|farm\\S*|forestry|pastoral|pasture|\\bfisher\\S*|horticulture|cultivation\\S*|husbandry|grazing|\\bgrain\\S*|planting|\\btillage|\\btilling))(?=.*(?:productiv\\S*|production.?|income)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_3', 'SDG_keywords': '^(?=.*(?:access to))(?=.*(?:agricultur\\S*|\\bagro\\S*|agronom\\S*|agrarian\\S*|\\bcrop\\S*|food\\S*|farm\\S*|forestry|pastoral|pasture|\\bfisher\\S*|horticulture|cultivation\\S*|husbandry|grazing|\\bgrain\\S*|planting|\\btillage|\\btilling))(?=.*(?:\\bland|land tenure right.?|land right.?|land own\\S*|resource.?|\\binput.?|knowledge\\S*|financial service.?|market.?|opportunit\\S*|employ\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_3', 'SDG_keywords': '^(?=.*(?:\\breform\\S*))(?=.*(?:agricultur\\S*|\\bagro\\S*|agronom\\S*|agrarian\\S*|\\bcrop\\S*|food\\S*|farm\\S*|forestry|pastoral|pasture|\\bfisher\\S*|horticulture|cultivation\\S*|husbandry|grazing|\\bgrain\\S*|planting|\\btillage|\\btilling))(?=.*(?:\\bland\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_4', 'SDG_keywords': '^(?=.*(?:\\bland\\S*|\\bsoil\\b))(?=.*(?:quality|fertility)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_4', 'SDG_keywords': '^(?=.*(?:agricultur\\S*|\\bagro\\S*|agronom\\S*|agrarian\\S*|\\bcrop\\S*|food\\S*|farm\\S*|forestry|pastoral|pasture|\\bfisher\\S*|horticulture|cultivation\\S*|husbandry|grazing|\\bgrain\\S*|planting|\\btillage|\\btilling))(?=.*(?:sustain\\S*|resilien\\S*|productiv\\S*|\\borganic|ecological)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_4', 'SDG_keywords': '^(?=.*(?:agricultur\\S*|\\bagro\\S*|agronom\\S*|agrarian\\S*|\\bcrop\\S*|food\\S*|farm\\S*|forestry|pastoral|pasture|\\bfisher\\S*|horticulture|cultivation\\S*|husbandry|grazing|\\bgrain\\S*|planting|\\btillage|\\btilling))(?=.*(?:adapt\\S*))(?=.*(?:shock\\S*|disaster.?|catastroph\\S*|cataclysm|casualt\\S*|calamit\\S*|hazard\\S*|mishap\\S*|hurricane\\S*|tornado\\S*|cyclone\\S*|flood\\S*|drought\\S*|\\bharm.?\\b|\\bharmed\\b|wild.?fire|fire.?storm|Extreme event.?|extreme climate|extreme weather|extreme temperature|extreme heat|heat.?wave|cold wave|extreme precipitation|lightning|thunderstorm.?|ice storm.?|blizzard\\S*|hailstorm\\S*|tropical storm.?|earthquake.?|volcanic eruption.?|limnic eruption.?|exploding lake.?|landslide.?|mudslide.?|debris flow.?|tsunami\\S*|sinkhole\\S*|subsidence\\S*|climate change|global warming|\\bwarm\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_4', 'SDG_keywords': '^(?=.*(?:adapt\\S*))(?=.*(?:temperat\\S*|\\bsea level))(?=.*(?:\\bris\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_5', 'SDG_keywords': '^(?=.*(?:genetic\\S*))(?=.*(?:manag\\S*|maintain\\S*|diversif\\S*|diversity|conserv\\S*|secur\\S*))(?=.*(?:cultivated|farmed|domesticated))(?=.*(?:seed\\S*|plant bank.?|animal|wild species)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_5', 'SDG_keywords': '^(?=.*(?:manag\\S*|maintain\\S*|diversif\\S*|diversity|conserv\\S*|secur\\S*|\\butiliz\\S*))(?=.*(?:local|\\btraditional\\b|indigen\\S*|aboriginal|native|endemic))(?=.*(?:breed\\S*|bred)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_5', 'SDG_keywords': '^(?=.*(?:genetically modified|\\bGMO\\b))(?=.*(?:food|agricultur\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_a', 'SDG_keywords': '^(?=.*(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold|\\badvanc\\S*|cooperat\\S*|collaborat\\S*|joint effort.?|\\bflow\\b|\\bflows\\b)).+(((?:rural|agricult\\S*)\\s(?:\\w+\\s){0,5}(?=(?:infrastructure.?|research\\S*|investig\\S*|extension.?\\b|technolog\\S*)))|((?:infrastructure.?|research\\S*|investig\\S*|extension.?\\b|technolog\\S*)\\s(?:\\w+\\s){0,5}(?=(?:rural|agricult\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_a', 'SDG_keywords': '^(?=.*(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold|\\badvanc\\S*|cooperat\\S*|collaborat\\S*|joint effort.?|\\bflow\\b|\\bflows\\b))(?=.*(?:\\bplant\\S*|\\bsoy\\S*|livestock\\S*|animal.?|cattle.?|\\bcow.?|\\bpig.?|sheep|\\bhog.?|horse.?|oxen|\\bherd\\S*|swine))(?=.*(?:gene bank.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_b', 'SDG_keywords': '^(?=.*(?:agricultur\\S*|\\bagro\\S*|agronom\\S*|agrarian\\S*|\\bcrop\\S*|food\\S*|farm\\S*|forestry|pastoral|pasture|\\bfisher\\S*|horticulture|cultivation\\S*|husbandry|grazing|\\bgrain\\S*|planting|\\btillage|\\btilling))(?=.*(?:export\\S*|\\btrade\\b|supply chain.?|value chain.?|market.?|business\\S*|commerce\\S*))(?=.*(?:\\bsubsidy|\\bsubsidies|\\bsubsidiz|\\bsubsidis|restrict\\S*|distort\\S*|allowance\\S*|financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_b', 'SDG_keywords': 'Doha Development Round|Doha Round|\\bDDR\\b|D\\.D\\.R\\.', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG2_c', 'SDG_keywords': '^(?=.*(?:agricultur\\S*|\\bagro\\S*|agronom\\S*|agrarian\\S*|\\bcrop\\S*|food\\S*|farm\\S*|forestry|pastoral|pasture|\\bfisher\\S*|horticulture|cultivation\\S*|husbandry|grazing|\\bgrain\\S*|planting|\\btillage|\\btilling))(?=.*(?:market.?|price))(?=.*(?:volatil\\S*|anomal\\S*|change.?|unstable|unsettled|elastic|elusive)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_1', 'SDG_keywords': '^(?=.*(?:matern\\S*|antenatal\\S*|birth|gestational|parturient|^(?=.*(?:post))(?=.*(?:natal|partum)).+))(?=.*(?:mortal\\S*|death|\\bdead|\\bdie\\b|\\bdies\\b|\\bdied\\b|\\bdying|fatal|deceas\\S*|\\bdemis\\S*|\\bkilled|lethal|perish\\S*|lose.*life|pass away|health.?care|complica\\S*|depress\\S*))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_2', 'SDG_keywords': '^(?=.*(?:child\\S*|\\bteen.?\\b|teenage\\S*|juvenile\\S*|youth|young|\\bminor.?\\b|under 5|under five|underfive|before fifth|adolescen\\S*|\\bgirl\\S*|\\bboy\\b|\\bboys\\b|\\bkid\\b|\\bkids\\b|\\bkiddo|\\bkiddy|\\bkiddies|offspring\\S*|newborn\\S*|foetal|premature|preterm|pediatric\\S*|perinatal|infant.?|neonat\\S*))(?=.*(?:mortal\\S*|death|\\bdead|\\bdie\\b|\\bdies\\b|\\bdied\\b|\\bdying|fatal|deceas\\S*|\\bdemis\\S*|\\bkilled|lethal|perish\\S*|lose.*life|pass away|syndrome|wellness|well.?being))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_3', 'SDG_keywords': '^(?=.*(?:epidemic\\S*|pandemic|outbreak.?|communicable disease.?|\\binfect\\S*|contagious|endemic|\\bSARS\\b|acute respiratory syndrome|zika|Zikv\\S*|dengue|schistosomiasis|ebola|measles|cholera|Chagas\\S*|\\bAIDS\\b|\\bHIV\\b|Acquired immunodeficiency syndrome|Human immunodeficiency virus|Yellow fever|Middle East respiratory syndrome|MERS-CoV|Antiretroviral|tuberculos\\S*|malaria|tropical disease.?|trypanosom\\S*|hepatit\\S*|Lyme disease\\S*|COVID|2019.?nCoV|SARS.?CoV.?2|SARS.?CoV2|HCoV.?2019|\\bHCOV\\b|NCOVID.?19|coronavirus|corona virus|water borne|water.?borne|sexual\\S* transmi\\S*))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_4', 'SDG_keywords': '^(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+(((?:non.?communicable|\\bNCD\\b|cardiovascular|heart attack\\S*|myocard\\S* infarct\\S*|cerebrovascular accident\\S*|\\bCVA\\b|cancer|carcinoma\\S*|lung emphysema\\S*|neoplasm\\S*|tumor\\S*|tumour\\S*|diabet\\S*|copd|coad|asthma\\S*|diarrhea|diarrhoea|dysentery|\\bobes\\S*|suicid\\S*|stroke)\\s(?:\\w+\\s){0,4}(?=(?:mortal\\S*|death|\\bdead|\\bdie\\b|\\bdies\\b|\\bdied\\b|\\bdying|fatal|deceas\\S*|\\bdemis\\S*|\\bkilled|lethal|perish\\S*|lose.*life|pass away)))|((?:mortal\\S*|death|\\bdead|\\bdie\\b|\\bdies\\b|\\bdied\\b|\\bdying|fatal|deceas\\S*|\\bdemis\\S*|\\bkilled|lethal|perish\\S*|lose.*life|pass away)\\s(?:\\w+\\s){0,4}(?=(?:non.?communicable|\\bNCD\\b|cardiovascular|heart attack\\S*|myocard\\S* infarct\\S*|cerebrovascular accident\\S*|\\bCVA\\b|cancer|carcinoma\\S*|lung emphysema\\S*|neoplasm\\S*|tumor\\S*|tumour\\S*|diabet\\S*|copd|coad|asthma\\S*|diarrhea|diarrhoea|dysentery|\\bobes\\S*|suicid\\S*|stroke))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_4', 'SDG_keywords': '^(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+(((?:chronic\\S*)\\s(?:\\w+\\s){0,4}(?=(?:bronchitis|disease\\S*|hepatitis\\S*|pulmonary|respiratory|\\bstress)))|((?:bronchitis|disease\\S*|hepatitis\\S*|pulmonary|respiratory|\\bstress)\\s(?:\\w+\\s){0,4}(?=(?:chronic\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_4', 'SDG_keywords': '^(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+(((?:\\bmental\\S*|mood|psychological|psychiatric|psychosis|psychotic|\\bcogniti\\S*|emotion\\S*)\\s(?:\\w+\\s){0,4}(?=(?:disorder|disease\\S*|\\bhealth\\b|wellness|illness\\S*|\\bsick\\S*|disabilit\\S*)))|((?:disorder|disease\\S*|\\bhealth\\b|wellness|illness\\S*|\\bsick\\S*|disabilit\\S*)\\s(?:\\w+\\s){0,4}(?=(?:\\bmental\\S*|mood|psychological|psychiatric|psychosis|psychotic|\\bcogniti\\S*|emotion\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_4', 'SDG_keywords': '^(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+(((?:\\bCV\\b)\\s(?:\\w+\\s){0,2}(?=(?:death|mortality)))|((?:death|mortality)\\s(?:\\w+\\s){0,2}(?=(?:\\bCV\\b))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_5', 'SDG_keywords': '^(?=.*(?:substance|drug|alcohol|drinking|drunk|ethanol|liquor|liqueur|booze|\\bwine|\\bbeer.?|Narcotic))(?=.*(?:\\babus\\S*|misuse|misconduct.?|obsessive|addict\\S*|\\bharm.?\\b|\\bharmed\\b|hazardous|disorder\\S*))(?=.*(?:\\btreatment.?|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_6', 'SDG_keywords': '^(?=.*(?:\\broad.?\\b|\\broadway|\\blane\\S*|avenue|street|\\bdrive\\b|\\bcar\\b|automobile|\\bmotor|vehicle.?|highway|expressway|freeway|speed.?way|motorway|\\brail\\S*|congest\\S*|collision\\S*|collid\\S*|\\bjam.?|traffic|transport.?\\b|transportation.?|\\btransit.?\\b|travel\\S*))(?=.*(?:mortal\\S*|death|\\bdead|\\bdie\\b|\\bdies\\b|\\bdied\\b|\\bdying|fatal|deceas\\S*|\\bdemis\\S*|\\bkilled|lethal|perish\\S*|lose.*life|pass away|fatal|injur\\S*|accident.?|adversit\\S*|bottleneck\\S*|damag\\S*|wound|catastroph\\S*|calamit\\S*|casualt\\S*|crash|disaster.?|\\bharm.?\\b|\\bharmed\\b|hazard\\S*|emergenc\\S*|traged\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_6', 'SDG_keywords': '\\bTZD program\\S*|\\bTZD National Strateg\\S*|\\bTZD Strateg\\S*|Toward Zero Deaths|Road to Zero', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_7', 'SDG_keywords': '^(?=.*(?:family planning|contracept\\S*|condom.?|diaphragm\\S*|Birth Control|intrauterine device\\S*|\\bIUD\\b|conception control))(?=.*(?:access|availab\\S*|modern|information|informing|\\binform\\b|\\binforms\\b|\\binformed\\b|educat\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_7', 'SDG_keywords': '^(?=.*(?:\\bsex|reproductive))(?=.*(?:\\bcare\\b))(?=.*(?:access|availab\\S*|modern|information|informing|\\binform\\b|\\binforms\\b|\\binformed\\b|educat\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_7', 'SDG_keywords': '^(?=.*(?:unintended|unwanted))(?=.*(?:pregnanc\\S*|motherhood))(?=.*(?:access|availab\\S*|modern|information|informing|\\binform\\b|\\binforms\\b|\\binformed\\b|educat\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_7', 'SDG_keywords': '^(?=.*(?:child\\S*|\\bteen.?\\b|teenage\\S*|juvenile\\S*|youth|young|\\bminor.?\\b|under 5|under five|underfive|before fifth|adolescen\\S*|\\bgirl\\S*|\\bboy\\b|\\bboys\\b|\\bkid\\b|\\bkids\\b|\\bkiddo|\\bkiddy|\\bkiddies|offspring\\S*))(?=.*(?:birth|pregnan\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_8', 'SDG_keywords': '^(?=.*(?:health|Medical|\\bhearing|\\bDental|\\bVision\\b))(?=.*(?:coverage|\\bcare\\b|service.?|benefit.?))(?=.*(?:universal|access|availab\\S*|affordable|\\bpublic|essential)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_8', 'SDG_keywords': '^(?!.*(?:Financial risk\\S*|Financial Disclosure\\S*|Financial Stability|financial sector\\S*|financial group\\S*|financial crisis|financial condition\\S*|financial impact\\S*|financial inclusive\\S*|financial statement\\S*|Financial Times|financial press|financial result\\S*|financial instrument\\S*|Financial Review\\S*|financial assumption\\S*|finance corporation\\S*))(?=.*(?:health|medicine\\S*|vaccin\\S*|pharmac\\S*))(?=.*(?:household))(?=.*(?:expenditure\\S*|expense|income|financ\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_9', 'SDG_keywords': '^(?=.*(?:hazard\\S*|unsafe|unintentional|inadequate|contamin\\S*|pollut\\S*))(?=.*(?:chemical\\S*|\\bair\\b|\\bwater.?\\b|\\bsoil\\b|sanita\\S*|hygien\\S*|poison\\S*))(?=.*(?:mortal\\S*|death|\\bdead|\\bdie\\b|\\bdies\\b|\\bdied\\b|\\bdying|fatal|deceas\\S*|\\bdemis\\S*|\\bkilled|lethal|perish\\S*|lose.*life|pass away|illness|\\bsick)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_9', 'SDG_keywords': '^(?=.*(?:\\black))(?=.*(?:sanita\\S*|hygien\\S*|poison\\S*))(?=.*(?:mortal\\S*|death|\\bdead|\\bdie\\b|\\bdies\\b|\\bdied\\b|\\bdying|fatal|deceas\\S*|\\bdemis\\S*|\\bkilled|lethal|perish\\S*|lose.*life|pass away|illness\\S*|\\bsick\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_a', 'SDG_keywords': '^(?=.*(?:tobacco|nicotine|cigar\\S*|\\bvap\\S*|smok\\S*))(?=.*(?:control|\\bregulat\\S*|administer\\S*|\\bban\\b|\\bbans\\b|\\bbanned\\b|govern\\S*|manag\\S*|cessation\\S*|\\bquit\\S*|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*))(?!.*government)(?!.*Governance)(?!.*Management)(?!.*manager)', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_b', 'SDG_keywords': '^(?=.*(?:vaccin\\S*|medicin\\S*|medication\\S*|antibiotic|health facilit\\S*|health sector\\S*))(?=.*(?:research\\S*|develop\\S*|\\bR&D\\b))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b)))))(?=.*(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold))(?!.*development expense)(?!.*investigatS*)(?!.*Invest Ltd)', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_b', 'SDG_keywords': '^(?!.*(?:available data|extension|market access|access to equity))(?=.*(?:vaccin\\S*|medicin\\S*|medication\\S*|antibiotic|pharmac\\S*|health facilit\\S*))(?=.*(?:access|\\bavailab\\S*|afford\\b|affordabl\\S*|covered by|TRIPS Agreement.?|Trade.?Related Aspects of Intellectual Property Rights)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_c', 'SDG_keywords': '^(?!.*(?:Financial risk\\S*|Financial Disclosure\\S*|Financial Stability|financial sector\\S*|financial group\\S*|financial crisis|financial condition\\S*|financial impact\\S*|financial inclusive\\S*|financial statement\\S*|Financial Times|financial press|financial result\\S*|financial instrument\\S*|Financial Review\\S*|financial assumption\\S*|finance corporation\\S*|statement\\S*|granted|Global Grants Programme|investigat\\S*|First Aid|Animal Health|funded)).*(((?:\\bhealth\\b|well.?being)\\s(?:\\w+\\s){0,4}(?=(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassistance.?|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\b|investment\\S*|donor\\S*|donat\\S*|\\bgrant.?\\b|official flow.?)))|((?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassistance.?|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\b|investment\\S*|donor\\S*|donat\\S*|\\bgrant.?\\b|official flow.?)\\s(?:\\w+\\s){0,4}(?=(?:\\bhealth\\b|well.?being))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_c', 'SDG_keywords': '^(?=.*(?:\\bhealth\\b))(?=.*(?:workforce|\\bworker.?|employ\\S*|\\blabor|\\blabour))(?=.*(?:recruit\\S*|develop\\S*|\\btrain\\S*|retention.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_d', 'SDG_keywords': '^(?=.*(?:preparedness|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+(((?:\\bhealth\\b)\\s(?:\\w+\\s){0,6}(?=(?:early warning|manag\\S*|risk reduction|emergency|\\burgen\\S*)))|((?:early warning|manag\\S*|risk reduction|emergency|\\burgen\\S*)\\s(?:\\w+\\s){0,6}(?=(?:\\bhealth\\b))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_d', 'SDG_keywords': '^(?=.*(?:International Health Regulations|\\bIHR\\b|health risk))(?=.*(?:capacity)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_d', 'SDG_keywords': '^(?=.*(?:blood\\S*))(?=.*(?:\\binfect\\S*))(?=.*(?:resist\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_d', 'SDG_keywords': '^(?=.*(?:antibiotic|antimicr\\S*))(?=.*(?:resist\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_general', 'SDG_keywords': '^(?=.*(?:health|good|quality))(?=.*(?:\\blife\\b|\\blives\\b|child\\S*|\\bteen.?\\b|teenage\\S*|juvenile\\S*|youth|young|\\bminor.?\\b|under 5|under five|underfive|before fifth|adolescen\\S*|\\bgirl\\S*|\\bboy\\b|\\bboys\\b|\\bkid\\b|\\bkids\\b|\\bkiddo|\\bkiddy|\\bkiddies|offspring\\S*|woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG3_general', 'SDG_keywords': 'well.?being', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_1', 'SDG_keywords': '^(?=.*(?:child\\S*|\\bteen.?\\b|teenage\\S*|juvenile\\S*|youth|young|\\bminor.?\\b|under 5|under five|underfive|before fifth|adolescen\\S*|\\bgirl\\S*|\\bboy\\b|\\bboys\\b|\\bkid\\b|\\bkids\\b|\\bkiddo|\\bkiddy|\\bkiddies|offspring\\S*))(?=.*(?:\\bprimary|secondary|middle))(?=.*(?:educat\\S*|school\\S*))(?=.*(?:\\bcomplet\\S*|conclud\\S*|\\bend\\b|\\bfinish\\S*|Finaliz\\S*|\\bFulfill\\S*|accomplish\\S*|\\bachiev\\S*|wrap up)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_1', 'SDG_keywords': '^(?=.*(?:child\\S*|\\bteen.?\\b|teenage\\S*|juvenile\\S*|youth|young|\\bminor.?\\b|under 5|under five|underfive|before fifth|adolescen\\S*|\\bgirl\\S*|\\bboy\\b|\\bboys\\b|\\bkid\\b|\\bkids\\b|\\bkiddo|\\bkiddy|\\bkiddies|offspring\\S*))(?=.*(?:\\bgrade))(?=.*(?:\\b2\\b|\\b2nd\\b|second\\S*|\\btwo|\\b3\\b|third|\\b3rd\\b|three))(?=.*(?:\\bcomplet\\S*|conclud\\S*|\\bend\\b|\\bfinish\\S*|Finaliz\\S*|\\bFulfill\\S*|accomplish\\S*|\\bachiev\\S*|wrap up)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_1', 'SDG_keywords': '^(?=.*(?:child\\S*|\\bteen.?\\b|teenage\\S*|juvenile\\S*|youth|young|\\bminor.?\\b|under 5|under five|underfive|before fifth|adolescen\\S*|\\bgirl\\S*|\\bboy\\b|\\bboys\\b|\\bkid\\b|\\bkids\\b|\\bkiddo|\\bkiddy|\\bkiddies|offspring\\S*))(?=.*(?:reading|\\bmath\\S*|educat\\S*|school\\S*))(?=.*(?:proficiency|competence|skill\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_1', 'SDG_keywords': '^(?=.*(?:child\\S*|\\bteen.?\\b|teenage\\S*|juvenile\\S*|youth|young|\\bminor.?\\b|under 5|under five|underfive|before fifth|adolescen\\S*|\\bgirl\\S*|\\bboy\\b|\\bboys\\b|\\bkid\\b|\\bkids\\b|\\bkiddo|\\bkiddy|\\bkiddies|offspring\\S*))(?=.*(?:inclusi\\S*|quality|equitab\\S*|\\bfree\\b|access|affordab\\S*))(?=.*(?:educat\\S*|school\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_2', 'SDG_keywords': '^(?=.*(?:child\\S*|\\bteen.?\\b|teenage\\S*|juvenile\\S*|youth|young|\\bminor.?\\b|under 5|under five|underfive|before fifth|adolescen\\S*|\\bgirl\\S*|\\bboy\\b|\\bboys\\b|\\bkid\\b|\\bkids\\b|\\bkiddo|\\bkiddy|\\bkiddies|offspring\\S*|infant|toddler))(?=.*(?:\\bcare.?\\b|pre.?primary educat\\S*|health|well.?being|psycho\\S*))(?!.*(?:young|Children.?s Centre|Children.?s Center))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_2', 'SDG_keywords': 'pre.?school|early childhood development', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_2', 'SDG_keywords': '(((?:primary entry age|\\bbefore\\b|ready for)\\s(?:\\w+\\s){0,4}(?=(?:educat\\S*|learning\\S*)))|((?:educat\\S*|learning\\S*)\\s(?:\\w+\\s){0,4}(?=(?:primary entry age|\\bbefore\\b|ready for))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_3', 'SDG_keywords': '^(?!.*(?:Access Bank|Information is available|job fair))(?=.*(?:technical|vocational|tertiary))(?=.*(?:educat\\S*|\\bcollege.?\\b|universit\\S*|\\btraining\\S*|learning\\S*|high school.?))(?=.*(?:access|availab\\S*|equitab\\S*|equal\\S*|\\bfree\\b|affordab\\S*|quality|particip\\S*|\\bjoin\\b|\\bjoins|\\bjoined|\\bjoining|attend\\S*|lifelong|adult\\S*|non.?traditional)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_3', 'SDG_keywords': '^(?!.*(?:Access Bank|Information is available|job fair))(?=.*(?:\\bGED\\b|G\\.E\\.D\\.|General Educational Development))(?=.*(?:access|availab\\S*|equitab\\S*|equal\\S*|\\bfree\\b|affordab\\S*|quality|particip\\S*|\\bjoin\\b|\\bjoins|\\bjoined|\\bjoining|attend\\S*|lifelong|adult\\S*|non.?traditional)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_4', 'SDG_keywords': '^(?=.*(?:technical|vocational|information and communications|\\bICT\\b))(?=.*(?:skill\\S*|competenc\\S*|technique\\S*|expert\\S*|certificate.?|diploma))(?=.*(?:\\bemployment.?|\\bjob.?|entrepreneur\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_4', 'SDG_keywords': '^(?=.*(?:financial literacy))(?=.*(?:\\bemployment\\S*|\\bjob\\S*|entrepreneur\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_5', 'SDG_keywords': '^(?=.*(?:education|vocational|\\btraining\\S*|school\\S*))(?=.*(?:disparit\\S*|parit\\S*|equal access|equit\\S*|equalit\\S*|inclusi\\S*|exclus\\S*|inequalit\\S*|discrimin\\S*))(?=.*(?:Disabled|disabilit\\S*|handicapped|incapacitated|crippled|\\bblind\\b|wounded|indigen\\S*|aboriginal|vulnerable|\\bgender|female|women|rural|underrepresented|wealth\\S*|low.?income)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_6', 'SDG_keywords': '^(?=.*(?:literacy|numeracy|literate\\S*|reading skill\\S*|writing skill\\S*))(?!.*financial literacy)', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_7', 'SDG_keywords': '^(?=.*(?:\\bknowledge|skill\\S*|educat\\S*|\\btraining\\S*|curricul\\S*|teach\\S*|student assessment.?))(?=.*(?:sustainable development|sustainable lifestyle\\S*|human right.?|\\bethics|gender equality|peace|non.?violence|cultural diversity)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_7', 'SDG_keywords': '(((?:global citizenship|international|Universal|\\bpolicy|\\bpolicies|Teacher.?\\b|trainer.?\\b|educator.?\\b)\\s(?:\\w+\\s){0,6}(?=(?:education)))|((?:education)\\s(?:\\w+\\s){0,6}(?=(?:global citizenship|international|Universal|\\bpolicy|\\bpolicies|Teacher.?\\b|trainer.?\\b|educator.?\\b))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_a', 'SDG_keywords': '^(?=.*(?:educat\\S*|learn\\S*|school\\S*))(?=.*(?:facilit\\S*|infrastructure\\S*|environment|basic service.?|electricity|internet|computer.?|drinking water|sanitation|hand.?washing))(?=.*(?:\\bbuild|\\bupgrad\\S*|\\boffer\\S*|\\bprovid\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_b', 'SDG_keywords': '^(?=.*(?:scholarship.?|fellowship.?|official development assistance|financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\baid.? to|government aid|state aid|invest\\S*|\\bgrant.?\\b|official flow.?))(?=.*(?:knowledge|skill\\S*|educat\\S*|vocational training.?|information technology|communications technology|information and communications technology|\\btechnical\\b|engineer\\S*|scien\\S*|mathemat\\S*|technolo\\S*|\\bSTEM\\b|S\\.T\\.E\\.M\\.))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b)))))(?!.*Corporate Governance)', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_c', 'SDG_keywords': '^(?=.*(?:teacher\\S*|educator\\S*|faculty|instructor\\S*|lecturer\\S*|professor\\S*|supervisor\\S*",\n                 "mentor.?\\b|tutor\\S*|trainer\\S*|adviser\\S*|advisor\\S*|\\bcoach\\b|\\bcoaches\\b|caregiver\\S*))(?=.*(?:supply|attrition|qualif|\\btrain|capab)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG4_general', 'SDG_keywords': '^(?=.*(?:school\\S*|educat\\S*|learning\\S*))(?=.*(?:inclusive|attend\\S*|enroll\\S*|basic|\\bequity|\\bequitab\\S*|safe|lifelong|lifetime|continuing)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_1', 'SDG_keywords': '^(?=.*(?:equality|\\bparity|justice|segregat\\S*|\\banti\\S*|hostile|marginali\\S*|discrimin\\S*|\\bbias\\S*|prejudice\\S*|\\bunfair\\S*|inequal\\S*|inequit\\S*|disparit\\S*|imparit\\S*|stereotype\\S*))(?=.*(?:woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?|\\bsex\\S*|\\bgender)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_1', 'SDG_keywords': 'misogyn\\S*|feminis\\S*', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_2', 'SDG_keywords': '^(?=.*(?:violence|assault\\S*|attack\\S*|aggression|offens\\S*|\\babuse|traffick\\S*|exploit\\S*|\\bforc\\S*|misconduct\\S*))(?=.*(?:woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?|domestic|\\bsex\\S*|prostitution\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_2', 'SDG_keywords': 'prostitut\\S*|\\brape\\S*|harass\\S*', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_3', 'SDG_keywords': '^(?=.*(?:child\\S*|\\bteen.?\\b|teenage\\S*|juvenile\\S*|youth|young|\\bminor.?\\b|under 5|under five|underfive|before fifth|adolescen\\S*|\\bgirl\\S*|\\bboy\\b|\\bboys\\b|\\bkid\\b|\\bkids\\b|\\bkiddo|\\bkiddy|\\bkiddies|offspring\\S*|\\bharm.?\\b|\\bharmed\\b|\\bearly|forced|before age 15|before age 18))(?=.*(?:marr\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_3', 'SDG_keywords': '^(?=.*(?:woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?|\\bgender))(?=.*(?:genital))(?=.*(?:mutilat\\S*|\\bcut\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_3', 'SDG_keywords': '^(?=.*(?:woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?))(?=.*(?:circumcision\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_4', 'SDG_keywords': '(((?:unpaid|shared responsibility|allocation|equity|equitab\\S*|fairness)\\s(?:\\w+\\s){0,4}(?=(?:\\bcare.?\\b|domestic work|household work|family work\\S*|woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?)))|((?:\\bcare.?\\b|domestic work|household work|family work\\S*|woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?)\\s(?:\\w+\\s){0,4}(?=(?:unpaid|shared responsibility|allocation|equity|equitab\\S*|fairness))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_5', 'SDG_keywords': '^(?=.*(?:leadership|leader\\S*|\\bseat\\S*|decision.?making|national parliament\\S*|government.?|autonomy|managerial position.?|political participation.?|politician|manager.?|in middle management|in senior management|in executive position.?|under.?representation|entrepreneurship|\\bpower|glass ceiling))(?=.*(?:woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_6', 'SDG_keywords': 'parent.? leave|Parental leave|paternity leave|family leave|adoption leave|Adoptive leave|maternity leave|Childbirth Leave|child.?care leave|Maternity care|paid maternity|Contraception service\\S*|Emergency contraception|abortion care|HIV test\\S*|HIV counsel\\S*|HIV care|HIV treatment|HPV vaccine|CSE curriculum|CSE law', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_6', 'SDG_keywords': '^(?=.*(?:access|availab|guarantee\\S*|\\bright.?|decision.?|decide.? on|autonomy|\\brights|\\blaw\\S*|regulation.?|information|educat\\S*))(?=.*(?:sexual|intercourse|\\breproduct\\S*|\\bcontracept\\S*|family planning|divorc\\S*|parenting plan.?|\\babort\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_6', 'SDG_keywords': '^(?=.*(?:\\bSex\\b|health.?care))(?=.*(?:information|educat\\S*))(?=.*(?:\\bfull\\b|\\bequal\\b)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_6', 'SDG_keywords': '^(?=.*(?:decision.?|\\breproduct\\S*))(?=.*(?:health.?care))(?=.*(?:woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_a', 'SDG_keywords': '^(?=.*(?:access|availab\\S*|\\bright.?\\b|\\bcontrol|\\breform\\S*|equal|\\blegal\\S*|\\blaw\\S*))(?=.*(?:resource.?|\\bfund|\\bland\\b|propert\\S*|financial service.?|finance|owner\\S*|budget.?|\\bquota\\b))(?=.*(?:woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?|\\bgender)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_a', 'SDG_keywords': '^(?=.*(?:ownership|inheritance right.?|right.? of inheritance|right.? to inherit\\S*|Mandatory quota.?|land tenure|land management|rights.?bearer\\S*))(?=.*(?:woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?|\\bgender)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_a', 'SDG_keywords': 'agrarian feminism', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_b', 'SDG_keywords': '^(?=.*(?:technolog\\S*|information|communications|mobile.?phone.?|telephone.?|smart.?phone.?|Cell.?phone.?|\\bICT\\b))(?=.*(?:\\bempower\\S*|promot\\S*))(?=.*(?:woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_c', 'SDG_keywords': '^(?=.*(?:\\bpolicy|\\bpolicies|program.?|legislation.?|\\bregulation.?|\\blaw\\b|\\blaws|government.?|authorit\\S*|national budget\\S*|budget allocation.?|resource allocation.?|public financ\\S*|public expenditure.?|fiscal system.?|monitoring system.?))(?=.*(?:\\bgender|\\bsex\\S*|woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?))(?=.*(?:equal\\S*|\\bequitab\\S*|\\bequalit\\S*|\\bun.?bias\\S*|unprejudic\\S*|\\bfair\\b|\\bfairly|\\bfairness\\S*|impartial\\S*|\\bparity|equit\\S*|promot\\S*|empower\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG5_general', 'SDG_keywords': '^(?=.*(?:\\bgender|\\bsex|woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?))(?=.*(?:equal\\S*|inclusi\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_1', 'SDG_keywords': '^(?=.*(?:access|availab\\S*|afford\\S*|safe|secure|\\bclean|manag\\S*|equitab\\S*))(?=.*(?:drinking water|drinkable water)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_2', 'SDG_keywords': '^(?=.*(?:access|availab\\S*|safe|manag\\S*|adequate\\S*|equitab\\S*|equal|facilit\\S*|service.?))(?=.*(?:sanita\\S*|hygien\\S*|soap|cleanliness|hand wash\\S*|wash.*hand\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_2', 'SDG_keywords': '^(?=.*(?:access|availab\\S*|safe|\\bopen|hygien\\S*|adequate|equal|health|\\bclean|manag\\S*))(?=.*(?:bathroom.?|defecation|toilet.?|restroom.?|lavatory|latrine|water closet.?|sewerage\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_3', 'SDG_keywords': '^(?=.*(?:dump\\S*|releas\\S*|recycl\\S*|\\bre.?us\\S*|untreated|\\btreated\\b|sustainab\\S*))(?=.*(?:hazard\\S*|chemical\\S*|toxicology|ecotoxicology|wastewater|sewer\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_3', 'SDG_keywords': '^(?=.*(?:\\bwater.?\\b|aquatic|aquifer))(?=.*(?:pollut\\S*|black|contamination.?))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_3', 'SDG_keywords': '(((?:\\bwater.?\\b|aquatic)\\s(?:\\w+\\s){0,6}(?=(?:recycl\\S*|\\bre.?us\\S*)))|((?:recycl\\S*|\\bre.?us\\S*)\\s(?:\\w+\\s){0,6}(?=(?:\\bwater.?\\b|aquatic))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_3', 'SDG_keywords': '^(?=.*(?:\\bwater.?\\b|aquatic))(?=.*(?:quality))(?=.*(?:good|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_4', 'SDG_keywords': '^(?=.*(?:\\bwater.?\\b|freshwater|groundwater))(?=.*(?:\\befficien\\S*|sustainab\\S*|secur\\S*|availab\\S*|conservat\\S*|recycl\\S*|\\bre.?us\\S*|re.?utiliz\\S*|adequate|abundan\\S*|plentiful|plentiful|sufficient\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_4', 'SDG_keywords': '^(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*|address\\S*|tackl\\S*|response to|cope.?with|coping with|deal.?with|dealing with|handl\\S*)).+(((?:\\bwater.?\\b|freshwater|groundwater)\\s(?:\\w+\\s){0,6}(?=(?:footprint.?|withdraw\\S*|consumption\\S*|consumed|\\busage\\S*|\\bgreen\\b|blue\\b|grey|scarcity|scarce|scant|shortage|\\bstress|dearth|deficit|\\black|shortfall|insufficien\\S*|inadequa\\S*|deficienc\\S*)))|((?:footprint.?|withdraw\\S*|consumption\\S*|consumed|\\busage\\S*|\\bgreen\\b|blue\\b|grey|scarcity|scarce|scant|shortage|\\bstress|dearth|deficit|\\black|shortfall|insufficien\\S*|inadequa\\S*|deficienc\\S*)\\s(?:\\w+\\s){0,6}(?=(?:\\bwater.?\\b|freshwater|groundwater))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_4', 'SDG_keywords': 'water balancing|water.?scarce|water.?stress', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_5', 'SDG_keywords': '^(?=.*(?:water resource.?|watershed.?))(?=.*(?:manag\\S*|transboundary|transnational|international|interbasin|cooperat\\S*|collaborat\\S*|joint effort.?|co.?operation|coping|action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_6', 'SDG_keywords': '^(?=.*(?:\\bwater.?\\b|mountain\\S*|forest|wetland|river|aquifer|lake.?))(?=.*(?:eco.?system.?))(?=.*(?:conserv\\S*|\\brestor\\S*|reserv\\S*|mainten\\S*|protect\\S*|preserv\\S*|safeguard\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_a', 'SDG_keywords': '^(?=.*(?:\\bwater.?\\b|sanita\\S*))(?=.*(?:development assistance|harvesting|desalina|\\befficien\\S*|waste\\S*|\\btreatment.?|recycl\\S*|\\bre.?us\\S*|re.?utiliz\\S*|technolog\\S*|purification|infrastructure.?|financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_a', 'SDG_keywords': '^(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+(((?:\\bwater.?\\b|sanita\\S*)\\s(?:\\w+\\s){0,8}(?=(?:international co.?op\\S*|international collab\\S*)))|((?:international co.?op\\S*|international collab\\S*)\\s(?:\\w+\\s){0,8}(?=(?:\\bwater.?\\b|sanita\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_a', 'SDG_keywords': '^(?=.*(?:\\bwater.?\\b|sanita\\S*))(?=.*(?:capacity))(?=.*(?:build\\S*))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG6_b', 'SDG_keywords': '^(?=.*(?:\\bwater.?\\b|sanita\\S*|hygiene|wastewater treatment))(?=.*(?:\\blocal communit\\S*|local administrat\\S*|local entit\\S*|ocal government\\S*|local authorit\\S*|local Stakeholder\\S*|each location|sub.?district\\S*|municipalit\\S*|\\bcommune\\S*|regional|resident\\S*|indigen\\S*|aboriginal|\\btraditional\\b|native|endemic))(?=.*(?:participat\\S*|action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG7_1', 'SDG_keywords': '^(?=.*(?:energy|\\bfuel|\\bpower\\b|electricity))(?=.*(?:reliable|affordab\\S*|modern|\\bclean\\b|sustainable))(?=.*(?:access\\S*|availab\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG7_1', 'SDG_keywords': 'Power outage.?', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG7_2', 'SDG_keywords': '(((?:((\\brenewables|biofuel|bioenergy|biodiesel|bio.?gas|bioethanol|hydropower|hydroelectric|electrofuel|\\be.?fuel|photovoltaic|wind farm\\S*|offshore wind|wind turbine\\S*|solar panel\\S*)|(?=.*(?:\\badvanc\\S*|alcohol|modern|\\bclean\\b|\\brenewable|alternative\\b|ethanol|biorefinery|\\bwind\\b|solar|biomass|nuclear|\\bsun\\b|sunlight.?\\b|\\btide.?\\b|tidal|\\bwave.?\\b|\\bwood.?\\b|thermal|geothermal|algae|\\balgal|\\bHydro\\S*|hybrid|hydrogen|synthetic\\S*|\\bgreen\\b|\\bgreener\\b|sustainable|enviro.?friendly|eco.?friendly|Environmentally.?Friendly|Environment.?Friendly))(?=.*(?:\\benergy|\\benergies|\\bfuel.?\\b|\\bpower\\b))))\\s(?:\\w+\\s){0,4}(?=(?:\\bshare|proportion|\\bpercent\\S*|\\bmix\\b|consum\\S*|transiti\\S*|shift\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)))|((?:\\bshare|proportion|\\bpercent\\S*|\\bmix\\b|consum\\S*|transiti\\S*|shift\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)\\s(?:\\w+\\s){0,4}(?=(?:((\\brenewables|biofuel|bioenergy|biodiesel|bio.?gas|bioethanol|hydropower|hydroelectric|electrofuel|\\be.?fuel|photovoltaic|wind farm\\S*|offshore wind|wind turbine\\S*|solar panel\\S*)|(?=.*(?:\\badvanc\\S*|alcohol|modern|\\bclean\\b|\\brenewable|alternative\\b|ethanol|biorefinery|\\bwind\\b|solar|biomass|nuclear|\\bsun\\b|sunlight.?\\b|\\btide.?\\b|tidal|\\bwave.?\\b|\\bwood.?\\b|thermal|geothermal|algae|\\balgal|\\bHydro\\S*|hybrid|hydrogen|synthetic\\S*|\\bgreen\\b|\\bgreener\\b|sustainable|enviro.?friendly|eco.?friendly|Environmentally.?Friendly|Environment.?Friendly))(?=.*(?:\\benergy|\\benergies|\\bfuel.?\\b|\\bpower\\b)))))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG7_2', 'SDG_keywords': '^(?=.*(?:((\\brenewables|biofuel|bioenergy|biodiesel|bio.?gas|bioethanol|hydropower|hydroelectric|electrofuel|\\be.?fuel|photovoltaic|wind farm\\S*|offshore wind|wind turbine\\S*|solar panel\\S*)|(?=.*(?:\\badvanc\\S*|alcohol|modern|\\bclean\\b|\\brenewable|alternative\\b|ethanol|biorefinery|\\bwind\\b|solar|biomass|nuclear|\\bsun\\b|sunlight.?\\b|\\btide.?\\b|tidal|\\bwave.?\\b|\\bwood.?\\b|thermal|geothermal|algae|\\balgal|\\bHydro\\S*|hybrid|hydrogen|synthetic\\S*|\\bgreen\\b|\\bgreener\\b|sustainable|enviro.?friendly|eco.?friendly|Environmentally.?Friendly|Environment.?Friendly))(?=.*(?:\\benergy|\\benergies|\\bfuel.?\\b|\\bpower\\b)))))(?=.*(?:\\bmeet\\S*|fulfill\\S*))(?=.*(?:\\demand\\S*|requirement.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG7_2', 'SDG_keywords': 'energy transition.?|hybrid vehicle.?|electric vehicle.?', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG7_2', 'SDG_keywords': '^(?!.*(?:year end|coal price\\S*|coal cost\\S*))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+(((?:fossil.?fuel.?|fossil.?gas|\\bcoal\\b|\\bcoals\\b|petrol|natural gas|methane|crude oil.?|gasoline|kerosene|non.?renewable.?|traditional energy|Conventional energy)\\s(?:\\w+\\s){0,4}(?=(?:consumption\\S*|consumed|\\busage\\S*|\\busing\\b|\\buse\\b|\\buses\\b)))|((?:consumption\\S*|consumed|\\busage\\S*|\\busing\\b|\\buse\\b|\\buses\\b)\\s(?:\\w+\\s){0,4}(?=(?:fossil.?fuel.?|fossil.?gas|\\bcoal\\b|\\bcoals\\b|petrol|natural gas|methane|crude oil.?|gasoline|kerosene|non.?renewable.?|traditional energy|Conventional energy))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG7_3', 'SDG_keywords': '(((?:energy|\\belectric\\S*|\\bfuel.?|\\bpower\\b|\\butilit\\S*)\\s(?:\\w+\\s){0,6}(?=(?:\\befficien\\S*|\\bintens\\S*|optimization tech\\S*|productivity|pollut\\S*|footprint.?|\\bleak.?\\b|\\bleakage.?|\\bper GDP|\\bper capita)))|((?:\\befficien\\S*|\\bintens\\S*|optimization tech\\S*|productivity|pollut\\S*|footprint.?|\\bleak.?\\b|\\bleakage.?|\\bper GDP|\\bper capita)\\s(?:\\w+\\s){0,6}(?=(?:energy|\\belectric\\S*|\\bfuel.?|\\bpower\\b|\\butilit\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG7_3', 'SDG_keywords': '^(?=.*(?:energy consumption|energy use\\S*|energy usage|energy inefficiency|energy.?intensive|energy burden|energy waste))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG7_3', 'SDG_keywords': 'smart grid.?|smart meter.?|Energy smart', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG7_a', 'SDG_keywords': '^(?!.*(?:Financial risk\\S*|Financial Disclosure\\S*|Financial Stability|financial sector\\S*|financial group\\S*|financial crisis|financial condition\\S*|financial impact\\S*|financial inclusive\\S*|financial statement\\S*|Financial Times|financial press|financial result\\S*|financial instrument\\S*|Financial Review\\S*|financial assumption\\S*|finance corporation\\S*|statement.?|granted|investigat\\S*|electricity trading))(?=.*(?:((\\brenewables|biofuel|bioenergy|biodiesel|bio.?gas|bioethanol|hydropower|hydroelectric|electrofuel|\\be.?fuel|photovoltaic|wind farm\\S*|offshore wind|wind turbine\\S*|solar panel\\S*)|(?=.*(?:\\badvanc\\S*|alcohol|modern|\\bclean\\b|\\brenewable|alternative\\b|ethanol|biorefinery|\\bwind\\b|solar|biomass|nuclear|\\bsun\\b|sunlight.?\\b|\\btide.?\\b|tidal|\\bwave.?\\b|\\bwood.?\\b|thermal|geothermal|algae|\\balgal|\\bHydro\\S*|hybrid|hydrogen|synthetic\\S*|\\bgreen\\b|\\bgreener\\b|sustainable|enviro.?friendly|eco.?friendly|Environmentally.?Friendly|Environment.?Friendly))(?=.*(?:\\benergy|\\benergies|\\bfuel.?\\b|\\bpower\\b)))))(?=.*(?:cooperat\\S*|collaborat\\S*|joint effort.?))(?=.*(?:research\\S*|\\btech\\S*|financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG7_a', 'SDG_keywords': '^(?!.*(?:electricity trading))(?=.*(?:accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*|financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold|access|availab\\S*)).+(((?:energy|\\belectricit\\S*|\\bfuel.?|electric vehicle.?|hybrid vehicle.?)\\s(?:\\w+\\s){0,8}(?=(?:research\\S*|technolog\\S*|infrastructure\\S*|hybrid system\\S*)))|((?:research\\S*|technolog\\S*|infrastructure\\S*|hybrid system\\S*)\\s(?:\\w+\\s){0,8}(?=(?:energy|\\belectricit\\S*|\\bfuel.?|electric vehicle.?|hybrid vehicle.?))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG7_b', 'SDG_keywords': '^(?=.*(?:((\\brenewables|biofuel|bioenergy|biodiesel|bio.?gas|bioethanol|hydropower|hydroelectric|electrofuel|\\be.?fuel|photovoltaic|wind farm\\S*|offshore wind|wind turbine\\S*|solar panel\\S*)|(?=.*(?:\\badvanc\\S*|alcohol|modern|\\bclean\\b|\\brenewable|alternative\\b|ethanol|biorefinery|\\bwind\\b|solar|biomass|nuclear|\\bsun\\b|sunlight.?\\b|\\btide.?\\b|tidal|\\bwave.?\\b|\\bwood.?\\b|thermal|geothermal|algae|\\balgal|\\bHydro\\S*|hybrid|hydrogen|synthetic\\S*|\\bgreen\\b|\\bgreener\\b|sustainable|enviro.?friendly|eco.?friendly|Environmentally.?Friendly|Environment.?Friendly))(?=.*(?:\\benergy|\\benergies|\\bfuel.?\\b|\\bpower\\b)))))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b)))))(?=.*(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG7_general', 'SDG_keywords': '((\\brenewables|biofuel|bioenergy|biodiesel|bio.?gas|bioethanol|hydropower|hydroelectric|electrofuel|\\be.?fuel|photovoltaic|wind farm\\S*|offshore wind|wind turbine\\S*|solar panel\\S*)|(?=.*(?:\\badvanc\\S*|alcohol|modern|\\bclean\\b|\\brenewable|alternative\\b|ethanol|biorefinery|\\bwind\\b|solar|biomass|nuclear|\\bsun\\b|sunlight.?\\b|\\btide.?\\b|tidal|\\bwave.?\\b|\\bwood.?\\b|thermal|geothermal|algae|\\balgal|\\bHydro\\S*|hybrid|hydrogen|synthetic\\S*|\\bgreen\\b|\\bgreener\\b|sustainable|enviro.?friendly|eco.?friendly|Environmentally.?Friendly|Environment.?Friendly))(?=.*(?:\\benergy|\\benergies|\\bfuel.?\\b|\\bpower\\b)))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_1', 'SDG_keywords': '^(?=.*(?:econom\\S*|\\bGDP\\b|gross domestic product|fiscal|monetary))(?=.*(?:per capita))(?=.*(?:Sustain\\S*|develop\\S*|prosper\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_10', 'SDG_keywords': '^(?!.*(?:Financial risk\\S*|Financial Disclosure\\S*|Financial Stability|financial sector\\S*|financial group\\S*|financial crisis|financial condition\\S*|financial impact\\S*|financial inclusive\\S*|financial statement\\S*|Financial Times|financial press|financial result\\S*|financial instrument\\S*|Financial Review\\S*|financial assumption\\S*|finance corporation\\S*|Access Bank))(?=.*(?:access to|inclusi\\S*))(?=.*(?:financial service.?|financial institution|\\bbanks|\\banking|bank branch\\S*|insurance|automated teller machine|\\bATMs\\b)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_2', 'SDG_keywords': '^(?!.*(?:Financial risk\\S*|Financial Disclosure\\S*|Financial Stability|financial sector\\S*|financial group\\S*|financial crisis|financial condition\\S*|financial impact\\S*|financial inclusive\\S*|financial statement\\S*|Financial Times|financial press|financial result\\S*|financial instrument\\S*|Financial Review\\S*|financial assumption\\S*|finance corporation\\S*))(?=.*(?:econom\\S*|\\bGDP\\b|gross domestic product|fiscal|monetary))(?=.*(?:\\bstimulat\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*))(?=.*(?:Productiv\\S*|\\befficien\\S*|technolo\\S*|innovation\\S*|moderniz\\S*|modernis\\S*|diversif\\S*|per employ\\S*|per work\\S*|per person)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_3', 'SDG_keywords': '^(?=.*(?:development))(?=.*(?:\\bpolicy|\\bpolicies))(?=.*(?:econom\\S*|\\bGDP\\b|gross domestic product|fiscal|monetary|employ\\S*))(?=.*(?:accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_3', 'SDG_keywords': '^(?=.*(?:\\bcreate|\\bcreati\\S*|support\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+(((?:\\bemploy\\S*|\\bjob.?|\\bwork\\S*)\\s(?:\\w+\\s){0,5}(?=(?:\\bdecent\\b|\\bseemly\\b|respectable|quality|stable|stabili\\S*|inclusiv\\S*)))|((?:\\bdecent\\b|\\bseemly\\b|respectable|quality|stable|stabili\\S*|inclusiv\\S*)\\s(?:\\w+\\s){0,5}(?=(?:\\bemploy\\S*|\\bjob.?|\\bwork\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_3', 'SDG_keywords': '(((?:productive activit\\S*|entrepreneurship\\S*)\\s(?:\\w+\\s){0,4}(?=(?:support\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)))|((?:support\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)\\s(?:\\w+\\s){0,4}(?=(?:productive activit\\S*|entrepreneurship\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_3', 'SDG_keywords': '^(?=.*(?:accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+(((?:micro.?|small.?|medium.?|starting|start.?up.?|kickstart|inclusiv\\S*)\\s(?:\\w+\\s){0,3}(?=(?:\\bcompany\\b|\\bcompanies|\\bfirm.?\\b|\\bcorporate\\b|\\bcorporation\\S*|business|enterprise\\S*|entrepren\\S*)))|((?:\\bcompany\\b|\\bcompanies|\\bfirm.?\\b|\\bcorporate\\b|\\bcorporation\\S*|business|enterprise\\S*|entrepren\\S*)\\s(?:\\w+\\s){0,3}(?=(?:micro.?|small.?|medium.?|starting|start.?up.?|kickstart|inclusiv\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_3', 'SDG_keywords': '^(?=.*(?:inclusive))(?=.*(?:economic growth)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_3', 'SDG_keywords': '^(?=.*(?:informal employment))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_4', 'SDG_keywords': '(((?:sustain\\S*|\\befficien\\S*)\\s(?:\\w+\\s){0,4}(?=(?:resource.?)))|((?:resource.?)\\s(?:\\w+\\s){0,4}(?=(?:sustain\\S*|\\befficien\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_4', 'SDG_keywords': '^(?=.*(?:resource.?efficien\\S*|efficient resource.?))(?=.*(?:accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_4', 'SDG_keywords': '^(?=.*(?:consumption.?|footprint.?))(?=.*(?:per GDP|per capita|\\befficien\\S*))(?=.*(?:material.?\\b)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_4', 'SDG_keywords': '(((?:environmental degradation)\\s(?:\\w+\\s){0,4}(?=(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*|de.?coupl\\S*|informed)))|((?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*|de.?coupl\\S*|informed)\\s(?:\\w+\\s){0,4}(?=(?:environmental degradation))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_5', 'SDG_keywords': '^(?!.*(?:full meeting.?|full potential|full Supervisory|full implement\\S*|full year|full integration.?)).*(((?:\\bfull\\b|\\bdecent\\b|\\bseemly\\b|respectable|productiv\\S*|inclusi\\S*|medical benefit.?|health benefit.?|healthcare benefit.?|insurance benefit.?)\\s(?:\\w+\\s){0,4}(?=(?:\\bemployment.?|\\bhiring|\\bemployee.?|\\bjob.?|\\bwork\\b|\\bworker.?|\\bstaff\\S*)))|((?:\\bemployment.?|\\bhiring|\\bemployee.?|\\bjob.?|\\bwork\\b|\\bworker.?|\\bstaff\\S*)\\s(?:\\w+\\s){0,4}(?=(?:\\bfull\\b|\\bdecent\\b|\\bseemly\\b|respectable|productiv\\S*|inclusi\\S*|medical benefit.?|health benefit.?|healthcare benefit.?|insurance benefit.?))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_5', 'SDG_keywords': '(((?:discrimin\\S*|\\bbias\\S*|prejudice\\S*|\\bunfair\\S*|inequal\\S*|inequit\\S*|disparit\\S*|imparit\\S*|stereotype\\S*|informal\\b|precarious)\\s(?:\\w+\\s){0,4}(?=(?:\\bemployment|\\bhiring|\\bemployee\\S*|\\bjob\\S*|\\bworker\\S*|\\bwork\\b|\\bworking)))|((?:\\bemployment|\\bhiring|\\bemployee\\S*|\\bjob\\S*|\\bworker\\S*|\\bwork\\b|\\bworking)\\s(?:\\w+\\s){0,4}(?=(?:discrimin\\S*|\\bbias\\S*|prejudice\\S*|\\bunfair\\S*|inequal\\S*|inequit\\S*|disparit\\S*|imparit\\S*|stereotype\\S*|informal\\b|precarious))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_5', 'SDG_keywords': '^(?!.*(?:instalment\\S*|retained earning\\S*|pay.?out|payable)).*(((?:equal\\S*|\\bequitab\\S*|\\bequalit\\S*|\\bun.?bias\\S*|unprejudic\\S*|\\bfair\\b|\\bfairly|\\bfairness\\S*|impartial\\S*|\\bparity)\\s(?:\\w+\\s){0,4}(?=(?:\\bwage|\\bpay.?\\b|\\bpaying|\\bpaid|\\bsalary|\\bsalaries|\\bearning|\\bstipend)))|((?:\\bwage|\\bpay.?\\b|\\bpaying|\\bpaid|\\bsalary|\\bsalaries|\\bearning|\\bstipend)\\s(?:\\w+\\s){0,4}(?=(?:equal\\S*|\\bequitab\\S*|\\bequalit\\S*|\\bun.?bias\\S*|unprejudic\\S*|\\bfair\\b|\\bfairly|\\bfairness\\S*|impartial\\S*|\\bparity))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_5', 'SDG_keywords': '^(?=.*(?:equal\\S*|\\bequitab\\S*|\\bequalit\\S*|\\bun.?bias\\S*|unprejudic\\S*|\\bfair\\b|\\bfairly|\\bfairness\\S*|impartial\\S*|\\bparity))(?=.*(?:opportunit\\S*))(?=.*(?:people|person|\\bemployee\\S*|\\bstaff\\S*|\\bworker.?|\\bwork\\b|\\bworking|\\bgender|\\bsex|ethni\\S*|\\brace|racial|\\breligion|Disabled|disabilit\\S*|handicapped|incapacitated|crippled|\\bblind\\b|disadvantaged|woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?|\\bLGBT\\S*|\\blesbian|\\bgay\\b|bisexual|transgender|\\bQueer\\b|Questioning|Intersex|\\bAllies\\b|\\bAsexual\\b|Pansexual)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_5', 'SDG_keywords': '^(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+(((?:\\bwage|\\bpay.?\\b|\\bpaying|\\bpaid|\\bsalary|\\bsalaries|\\bearning|\\bstipend)\\s(?:\\w+\\s){0,4}(?=(?:\\bgap\\b|difference|discrepan\\S*|dissimilarit\\S*|disproport\\S*|divergen\\S*|imbalance\\S*|discrimin\\S*|\\bbias\\S*|prejudice\\S*|\\bunfair\\S*|inequal\\S*|inequit\\S*|disparit\\S*|imparit\\S*|stereotype\\S*)))|((?:\\bgap\\b|difference|discrepan\\S*|dissimilarit\\S*|disproport\\S*|divergen\\S*|imbalance\\S*|discrimin\\S*|\\bbias\\S*|prejudice\\S*|\\bunfair\\S*|inequal\\S*|inequit\\S*|disparit\\S*|imparit\\S*|stereotype\\S*)\\s(?:\\w+\\s){0,4}(?=(?:\\bwage|\\bpay.?\\b|\\bpaying|\\bpaid|\\bsalary|\\bsalaries|\\bearning|\\bstipend))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_5', 'SDG_keywords': '^(?=.*(?:Share of|proportion|\\bpercent\\S*|discrimination))(?=.*(?:Disabled|disabilit\\S*|handicapped|incapacitated|crippled|\\bblind\\b|disadvantaged|\\breligion|\\bgender|woman|women|\\bgirl.?|female.?|\\blady\\b|\\bladies\\b|\\bmaid.?|\\bLGBT\\S*|\\blesbian|\\bgay\\b|bisexual|transgender|\\bQueer\\b|Questioning|Intersex|\\bAllies\\b|\\bAsexual\\b|Pansexual))(?=.*(?:workforce|employment|\\bemployee.?)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_5', 'SDG_keywords': '^(?=.*(?:unemployment|dismissal))(?=.*(?:\\baddress\\S*|tackl\\S*|response to|cope.?with|coping with|deal.?with|dealing with|handl\\S*|\\bmeasure.?\\b|\\bbelow\\b|\\blower\\b|\\bless\\b|alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_5', 'SDG_keywords': '^(?=.*(?:employment.?|\\bhiring|\\bemployee.?|\\bjob\\S*|\\bworker.?|\\blabor\\b|\\blabour\\b|coverage))(?=.*(?:Disabled|disabilit\\S*|handicapped|incapacitated|crippled|\\bblind\\b)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_5', 'SDG_keywords': 'disability benefit.?', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_6', 'SDG_keywords': '^(?=.*(?:youth|young people|\\bteen.?\\b|teenage\\S*)).+(((?:\\bin\\b|\\bwith\\b)\\s(?:\\w+\\s){0,4}(?=(?:educat\\S*|employment.?|\\btraining.?)))|((?:educat\\S*|employment.?|\\btraining.?)\\s(?:\\w+\\s){0,4}(?=(?:\\bin\\b|\\bwith\\b))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_7', 'SDG_keywords': '(((?:\\bforced|child\\S*|\\bteen.?\\b|teenage\\S*|juvenile\\S*|youth|young|\\bminor.?\\b|under 5|under five|underfive|before fifth|adolescen\\S*|\\bgirl\\S*|\\bboy\\b|\\bboys\\b|\\bkid\\b|\\bkids\\b|\\bkiddo|\\bkiddy|\\bkiddies|offspring\\S*)\\s(?:\\w+\\s){0,4}(?=(?:\\blabour|\\blabor|\\bwork\\S*|soldier.?|\\bslave\\S*|traffick\\S*)))|((?:\\blabour|\\blabor|\\bwork\\S*|soldier.?|\\bslave\\S*|traffick\\S*)\\s(?:\\w+\\s){0,4}(?=(?:\\bforced|child\\S*|\\bteen.?\\b|teenage\\S*|juvenile\\S*|youth|young|\\bminor.?\\b|under 5|under five|underfive|before fifth|adolescen\\S*|\\bgirl\\S*|\\bboy\\b|\\bboys\\b|\\bkid\\b|\\bkids\\b|\\bkiddo|\\bkiddy|\\bkiddies|offspring\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_7', 'SDG_keywords': 'modern slave\\S*|human traffick\\S*', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_8', 'SDG_keywords': '\\blabour right.?|\\blabor right.?|employee right.?', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_8', 'SDG_keywords': '^(?!.*(?:voting right.?|Rights issue.?|Annual Report.?)).*(((?:human right.?|compensation law)\\s(?:\\w+\\s){0,4}(?=(?:employ\\S*|\\blabor|\\blabour|\\bworker.?)))|((?:employ\\S*|\\blabor|\\blabour|\\bworker.?)\\s(?:\\w+\\s){0,4}(?=(?:human right.?|compensation law))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_8', 'SDG_keywords': '^(?=.*(?:\\bsafe|\\bsecure)).+(((?:\\bwork\\b|\\bworker.?|\\bworking|\\bjob.?\\b|occupational)\\s(?:\\w+\\s){0,4}(?=(?:environment\\b)))|((?:environment\\b)\\s(?:\\w+\\s){0,4}(?=(?:\\bwork\\b|\\bworker.?|\\bworking|\\bjob.?\\b|occupational))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_8', 'SDG_keywords': '^(?!.*\\breport.?\\b).*(zero incident.?|retirement fund\\S*|secure retirement.?)', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_8', 'SDG_keywords': '^(?!.*(?:alcohol|Drinking|\\bNo\\.))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*)).+(((?:mortal\\S*|death|\\bdead|\\bdie\\b|\\bdies\\b|\\bdied\\b|\\bdying|fatal|deceas\\S*|\\bdemis\\S*|\\bkilled|lethal|perish\\S*|lose.*life|pass away|injur\\S*|\\bharm.?\\b|\\bharmed\\b|danger\\S*|\\bincident\\S*)\\s(?:\\w+\\s){0,8}(?=(?:\\bjob.?\\b|\\bwork\\S*|\\bemploy\\S*|occupation\\S*)))|((?:\\bjob.?\\b|\\bwork\\S*|\\bemploy\\S*|occupation\\S*)\\s(?:\\w+\\s){0,8}(?=(?:mortal\\S*|death|\\bdead|\\bdie\\b|\\bdies\\b|\\bdied\\b|\\bdying|fatal|deceas\\S*|\\bdemis\\S*|\\bkilled|lethal|perish\\S*|lose.*life|pass away|injur\\S*|\\bharm.?\\b|\\bharmed\\b|danger\\S*|\\bincident\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_8', 'SDG_keywords': '(((?:ensure|prioritiz\\S*|\\bstimulat\\S*|management\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)\\s(?:\\w+\\s){0,10}(?=(?:employee benefit.?|employment benefit.?|occupational health|occupational safe\\S*)))|((?:employee benefit.?|employment benefit.?|occupational health|occupational safe\\S*)\\s(?:\\w+\\s){0,10}(?=(?:ensure|prioritiz\\S*|\\bstimulat\\S*|management\\S*|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_9', 'SDG_keywords': '^(?=.*(?:touris\\S*))(?=.*(?:sustainab\\S*|community.?based|\\bemployment.?|^(?=.*(?:\\bcreat\\S*))(?=.*(?:\\bjob.?)).+)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_9', 'SDG_keywords': '^(?=.*(?:\\btour\\S*))(?=.*(?:\\bpolicy|\\bpolicies|\\bGDP\\b|Gross Domestic Product)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_9', 'SDG_keywords': 'ecotourism', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_a', 'SDG_keywords': '^(?!.*(?:receivable|on-trade)).*(((?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold)\\s(?:\\w+\\s){0,4}(?=(?:\\btrade\\b)))|((?:\\btrade\\b)\\s(?:\\w+\\s){0,4}(?=(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG8_b', 'SDG_keywords': '^(?=.*(?:child\\S*|\\bteen.?\\b|teenage\\S*|juvenile\\S*|youth|young|\\bminor.?\\b|under 5|under five|underfive|before fifth|adolescen\\S*|\\bgirl\\S*|\\bboy\\b|\\bboys\\b|\\bkid\\b|\\bkids\\b|\\bkiddo|\\bkiddy|\\bkiddies|offspring\\S*))(?=.*(?:employ\\S*))(?=.*(?:action.?|activit\\S*|administ\\S*|agreement.?|approach\\S*|arrangement.?|blueprint.?|\\bdeal.?|\\bguide\\S*|govern\\S*|method.?|manag\\S*|\\bpolicy|\\bpolicies|\\bplan\\b|\\bplans\\b|planning|proced\\S*|program\\S*|project.?\\b|practice.?|procedure.?|propos\\S*|protocol.?|\\brule.?\\b|\\bregulat\\S*|\\blaw.?|\\btreat\\S*|\\bright.?|constitution.?|initiative.?|scheme.?|strateg\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_1', 'SDG_keywords': '(((?:quality|reliab\\S*|sustainable|resilien\\S*|afford\\S*|equitab\\S*|inclus\\S*)\\s(?:\\w+\\s){0,6}(?=(?:infrastructure.?|\\bhouse\\b|\\bhouses\\b|\\bhousing\\b|architecture.?|construction.?|freight\\S*|transport\\S*|\\broad.?\\b|\\broadway\\S*|highway|expressway|freeway|speed.?way|motorway|\\brail\\S*|\\bport.?\\b|power plant\\S*|steam network.?|gas network.?|\\bdams|bridge.?|airport.?|aviation\\S*|sewer\\S*|broadband\\S*|cellular infrastructure\\S*|internet\\S*|telecommunication.?|electricity|power grid\\S*|electrical grid\\S*|\\bpark.?\\b|tunnel\\S*|water supply|\\bCanal\\S*|Hospital\\S*|Irrigation scheme\\S*|Levee\\S*|Lighthouse\\S*|Pipeline.?|\\btransit.?\\b|Public space\\S*|Sewage treatment\\S*|Sewerage\\S*|Sluice\\S*|Solid waste\\S*|Utilities|\\bWeir\\S*|waterway.?|harbor\\S*|harbour\\S*|\\bdock\\S*|\\bdike\\S*|\\bdyke\\S*)))|((?:infrastructure.?|\\bhouse\\b|\\bhouses\\b|\\bhousing\\b|architecture.?|construction.?|freight\\S*|transport\\S*|\\broad.?\\b|\\broadway\\S*|highway|expressway|freeway|speed.?way|motorway|\\brail\\S*|\\bport.?\\b|power plant\\S*|steam network.?|gas network.?|\\bdams|bridge.?|airport.?|aviation\\S*|sewer\\S*|broadband\\S*|cellular infrastructure\\S*|internet\\S*|telecommunication.?|electricity|power grid\\S*|electrical grid\\S*|\\bpark.?\\b|tunnel\\S*|water supply|\\bCanal\\S*|Hospital\\S*|Irrigation scheme\\S*|Levee\\S*|Lighthouse\\S*|Pipeline.?|\\btransit.?\\b|Public space\\S*|Sewage treatment\\S*|Sewerage\\S*|Sluice\\S*|Solid waste\\S*|Utilities|\\bWeir\\S*|waterway.?|harbor\\S*|harbour\\S*|\\bdock\\S*|\\bdike\\S*|\\bdyke\\S*)\\s(?:\\w+\\s){0,6}(?=(?:quality|reliab\\S*|sustainable|resilien\\S*|afford\\S*|equitab\\S*|inclus\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_2', 'SDG_keywords': '(((?:inclusiv\\S*|sustainab\\S*|cradle to cradle|circular)\\s(?:\\w+\\s){0,4}(?=(?:\\bindustr\\S*)))|((?:\\bindustr\\S*)\\s(?:\\w+\\s){0,4}(?=(?:inclusiv\\S*|sustainab\\S*|cradle to cradle|circular))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_2', 'SDG_keywords': '^(?=.*(?:manufactur\\S*|\\bindustr\\S*))(?=.*(?:\\bvalue))(?=.*(?:per capita|\\bGDP\\b|gross domestic product)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_2', 'SDG_keywords': '^(?=.*(?:manufactur\\S*|\\bindustr\\S*)).+(((?:\\bemployment.?|\\bhiring|\\bemployee.?|\\bworker.?|\\bstaff.?)\\s(?:\\w+\\s){0,4}(?=(?:Share of|proportion\\S*|\\bpercent\\S*)))|((?:Share of|proportion\\S*|\\bpercent\\S*)\\s(?:\\w+\\s){0,4}(?=(?:\\bemployment.?|\\bhiring|\\bemployee.?|\\bworker.?|\\bstaff.?))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_3', 'SDG_keywords': '^(?=.*(?:\\bindustr\\S*|enterprise\\S*|entrepreneur\\S*))(?=.*(?:access|availab\\S*|\\breach))(?=.*(?:financial service.?|fiscal|\\bcredit.?|\\bloan.?|value chain.?|\\bbanking|\\binsurance|\\bfund.?\\b|\\bfunding\\b|micro.?credit.?|micro.?financ\\S*))(?!.*Access Bank)', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_3', 'SDG_keywords': '^(?=.*(?:small.?scale industr\\S*|micro.?enterprise\\S*|small.?sized business))(?=.*(?:Share of|proportion\\S*|\\bpercent\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_3', 'SDG_keywords': '^(?=.*(?:Share of|proportion\\S*|\\bpercent\\S*|financial service.?|affordable credit.?|credit union.?|\\bbanking|\\bInsurance|\\bbank.?\\b|\\bleasing|Retail deposit.?|financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold)).+(((?:\\bsmall|\\bmicro.?\\b|starting|start.?up.?|kickstart)\\s(?:\\w+\\s){0,4}(?=(?:entrepren\\S*|\\bcompany\\b|\\bcompanies|\\bfirm.?\\b|\\bcorporate\\b|\\bcorporation\\S*|business|enterprise\\S*)))|((?:entrepren\\S*|\\bcompany\\b|\\bcompanies|\\bfirm.?\\b|\\bcorporate\\b|\\bcorporation\\S*|business|enterprise\\S*)\\s(?:\\w+\\s){0,4}(?=(?:\\bsmall|\\bmicro.?\\b|starting|start.?up.?|kickstart))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_4', 'SDG_keywords': '^(?!.*(?:Industrial Investment)).*(((?:\\bclean|environmentally sound|\\bgreen\\b|\\bgreener\\b)\\s(?:\\w+\\s){0,4}(?=(?:technolog\\S*|\\bindustr\\S*)))|((?:technolog\\S*|\\bindustr\\S*)\\s(?:\\w+\\s){0,4}(?=(?:\\bclean|environmentally sound|\\bgreen\\b|\\bgreener\\b))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_4', 'SDG_keywords': '(((?:upgrad\\S*|retrofit\\S*)\\s(?:\\w+\\s){0,6}(?=(?:infrastructure.?|\\bhouse\\b|\\bhouses\\b|\\bhousing\\b|architecture.?|construction.?|freight\\S*|transport\\S*|\\broad.?\\b|\\broadway\\S*|highway|expressway|freeway|speed.?way|motorway|\\brail\\S*|\\bport.?\\b|power plant\\S*|steam network.?|gas network.?|\\bdams|bridge.?|airport.?|aviation\\S*|sewer\\S*|broadband\\S*|cellular infrastructure\\S*|internet\\S*|telecommunication.?|electricity|power grid\\S*|electrical grid\\S*|\\bpark.?\\b|tunnel\\S*|water supply|\\bCanal\\S*|Hospital\\S*|Irrigation scheme\\S*|Levee\\S*|Lighthouse\\S*|Pipeline.?|\\btransit.?\\b|Public space\\S*|Sewage treatment\\S*|Sewerage\\S*|Sluice\\S*|Solid waste\\S*|Utilities|\\bWeir\\S*|waterway.?|harbor\\S*|harbour\\S*|\\bdock\\S*|\\bdike\\S*|\\bdyke\\S*|\\bindustr\\S*)))|((?:infrastructure.?|\\bhouse\\b|\\bhouses\\b|\\bhousing\\b|architecture.?|construction.?|freight\\S*|transport\\S*|\\broad.?\\b|\\broadway\\S*|highway|expressway|freeway|speed.?way|motorway|\\brail\\S*|\\bport.?\\b|power plant\\S*|steam network.?|gas network.?|\\bdams|bridge.?|airport.?|aviation\\S*|sewer\\S*|broadband\\S*|cellular infrastructure\\S*|internet\\S*|telecommunication.?|electricity|power grid\\S*|electrical grid\\S*|\\bpark.?\\b|tunnel\\S*|water supply|\\bCanal\\S*|Hospital\\S*|Irrigation scheme\\S*|Levee\\S*|Lighthouse\\S*|Pipeline.?|\\btransit.?\\b|Public space\\S*|Sewage treatment\\S*|Sewerage\\S*|Sluice\\S*|Solid waste\\S*|Utilities|\\bWeir\\S*|waterway.?|harbor\\S*|harbour\\S*|\\bdock\\S*|\\bdike\\S*|\\bdyke\\S*|\\bindustr\\S*)\\s(?:\\w+\\s){0,6}(?=(?:upgrad\\S*|retrofit\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_4', 'SDG_keywords': '^(?=.*(?:resource.?))(?=.*(?:\\buse\\b|\\buses\\b|\\busage.?|consumption.?))(?=.*(?:\\befficien\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_4', 'SDG_keywords': '^(?=.*(?:\\bindustr\\S*))(?=.*(?:\\bemission.?|\\bCO2\\b|carbon|green.?house|\\bGHG\\b|G\\.H\\.G\\.|Halocarbons|chlorofluorocarbon.?|\\bcfc\\b|c\\.f\\.c\\.|\\bCFCs\\b|water vapour|methane|\\bCH4\\b|nitrous oxide|\\bN2O\\b|Nitrogen Oxides|\\bNOx\\b|\\bozone.?|\\bO3\\b|fluorinated gas|perfluorocarbon.?|\\bPFCs\\b|hydrofluorocarbon.?|\\bHFCs\\b|sulphur hexafluoride|\\bSF6\\b|nitrogen trifluoride|\\bNF3\\b))(?=.*(?:alleviat\\S*|\\babate\\S*|abridge\\S*|\\bavert\\S*|abolish\\S*|eradicat\\S*|eliminat\\S*|\\beras\\S*|\\bease\\S*|\\bend.?\\b|\\bended\\b|rid of|phase out|\\bwipe out|\\breduc\\S*|\\bcut.?\\b|\\bcurb\\S*|curtail\\S*|declin\\S*|decreas\\S*|diminish\\S*|diminution\\S*|\\bdrop\\S*|dwindl\\S*|\\bfade\\b|fall off|go down|goes down|went down|tone down|die down|cut down|\\bhalt\\S*|hinder\\S*|\\bhamper\\S*|impede\\S*|\\binhibit.?\\b|\\binhibited\\b|\\binhibiting|lessen\\S*|mitigat\\S*|slash\\S*|shrink\\S*|\\bstop\\S*|slump\\S*|\\btrim\\S*|weaken\\S*|\\bno\\b|\\bzero|prevent\\S*|prohibit\\S*|minimis\\S*|minimiz\\S*|manage\\S*|\\btreat\\S*)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_5', 'SDG_keywords': '^(?!.*(?:incremental cost|Technology Development Zone|COMBINED MANAGEMENT REPORT))(?=.*(?:\\bindustr\\S*|manufactur\\S*|business\\S*|\\boperation.?|\\bspending.?|\\bGDP\\b|gross domestic product|\\bproduction.?|\\bemployee\\S*|\\bjob.?|\\bworker.?|\\blabor\\b|\\blabour\\b|financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?)).+(((?:technolog\\S*|innov\\S*|\\binvention|research\\S*)\\s(?:\\w+\\s){0,6}(?=(?:accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*|upgrad\\S*|\\bencourag\\S*|prioritiz\\S*|Dedicated to|focus\\S*|\\bfurther\\b|\\bfortifie\\S*|drive.?\\b|driving|leverag\\S*|\\bcontinue\\S*|\\binculcat\\S*|\\bobtain\\S*|\\badapt\\S*|\\bdevelop\\S*)))|((?:accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*|upgrad\\S*|\\bencourag\\S*|prioritiz\\S*|Dedicated to|focus\\S*|\\bfurther\\b|\\bfortifie\\S*|drive.?\\b|driving|leverag\\S*|\\bcontinue\\S*|\\binculcat\\S*|\\bobtain\\S*|\\badapt\\S*|\\bdevelop\\S*)\\s(?:\\w+\\s){0,6}(?=(?:technolog\\S*|innov\\S*|\\binvention|research\\S*))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_5', 'SDG_keywords': '^(?!.*(?:Research Network|Research Alliance)).*(((?:scientific research|Researcher.?|scientist.?|\\bscholar.?\\b|specialist\\S*|\\bexpert.?\\b|\\bsavant.?\\b|academician|professor.?|Research and development|\\bR&D\\b|\\bR & D\\b|\\bR-D\\b|\\bRTD\\b|\\bR\\+D\\b)\\s(?:\\w+\\s){0,8}(?=(?:support.?|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)))|((?:support.?|accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*)\\s(?:\\w+\\s){0,8}(?=(?:scientific research|Researcher.?|scientist.?|\\bscholar.?\\b|specialist\\S*|\\bexpert.?\\b|\\bsavant.?\\b|academician|professor.?|Research and development|\\bR&D\\b|\\bR & D\\b|\\bR-D\\b|\\bRTD\\b|\\bR\\+D\\b))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_a', 'SDG_keywords': '^(?=.*(?:resilient|sustainable))(?=.*(?:infrastructure.?|\\bhouse\\b|\\bhouses\\b|\\bhousing\\b|architecture.?|construction.?|freight\\S*|transport\\S*|\\broad.?\\b|\\broadway\\S*|highway|expressway|freeway|speed.?way|motorway|\\brail\\S*|\\bport.?\\b|power plant\\S*|steam network.?|gas network.?|\\bdams|bridge.?|airport.?|aviation\\S*|sewer\\S*|broadband\\S*|cellular infrastructure\\S*|internet\\S*|telecommunication.?|electricity|power grid\\S*|electrical grid\\S*|\\bpark.?\\b|tunnel\\S*|water supply|\\bCanal\\S*|Hospital\\S*|Irrigation scheme\\S*|Levee\\S*|Lighthouse\\S*|Pipeline.?|\\btransit.?\\b|Public space\\S*|Sewage treatment\\S*|Sewerage\\S*|Sluice\\S*|Solid waste\\S*|Utilities|\\bWeir\\S*|waterway.?|harbor\\S*|harbour\\S*|\\bdock\\S*|\\bdike\\S*|\\bdyke\\S*))(?=.*(?:financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold))(?=.*(?:((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_b', 'SDG_keywords': '^(?!.*(?:Award.?|Financial Report.?|Annual Report.?|University of Science and Technology))(?=.*(?:technolog\\S*|innovation.?|research|medium.?tech\\S*|high.?tech\\S*|\\bR&D\\b|\\bR & D\\b|\\bR-D\\b|industrial diversification))(?=.*(?:accelerat\\S*|ascend\\S*|\\badvanc\\S*|augment\\S*|\\bamplif\\S*|magnif\\S*|burgeon\\S*|\\bclimb\\S*|better|boost\\S*|\\bboom\\S*|\\bdouble\\S*|escalat\\S*|expansion\\S*|\\bexpand\\S*|\\benlarge\\S*|\\bgrow\\S*|\\bhike|\\bhiking|heighten\\S*|improv\\S*|increas\\S*|foster\\S*|\\bfortif\\S*|facilitat\\S*|increment\\S*|jump\\S*|\\blift\\S*|\\brais\\S*|\\brise.?\\b|rising|\\brose\\S*|risen|\\brocket\\S*|skyrocket\\S*|\\bsurg\\S*|\\bsoar\\S*|promot\\S*|proliferat\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforc\\S*|upsurg\\S*|upward\\S*|financ\\S*|\\bfund.?\\b|\\bfunding\\b|\\bassist\\S*|budget\\S*|\\baid.? to|government aid|state aid|federal aid|national aid|invest\\S*|compensation\\S*|donor\\S*|donat\\S*|expenditure.?|\\bgrant.?\\b|\\bloan.?\\b|official flow.?|\\bsubsidy|\\bsubsidies|\\bsubsidiz\\S*|\\bsubsidis|Corporate sponsorship.?|support\\S*|transfer.?\\b|boost\\S*|bolster\\S*|\\bstimulat\\S*|\\bfortif\\S*|help\\S*|strengthen\\S*|enhanc\\S*|aggrandiz\\S*|reinforce\\S*|uphold))(?=.*(?:operational efficiency|domestic|((Aruba|Afghanistan|Angola|Anguilla|Albania|United Arab Emirates|Argentina|Armenia|American Samoa|French Southern Territories|Antigua and Barbuda|Azerbaijan|Burundi|Benin|Burkina Faso|Bangladesh|Bahrain|Bahamas|Bosnia and Herzegovina|Belarus|Belize|Bolivia|Brazil|Barbados|Brunei Darussalam|Bhutan|Botswana|Central African Republic|Chile|China|C.?te d.?Ivoire|Cameroon|Congo\\b|Cook Islands|Colombia|Comoros|Cabo Verde|Costa Rica|\\bCuba\\b|CuraÃ§ao|Cayman Islands|Cyprus|Cyprus|Djibouti|Dominica|Dominican Republic|Algeria|Ecuador|Egypt|Eritrea|Western Sahara|Ethiopia|Fiji|Micronesia|Gabon|Georgia|Ghana|Guinea|Gambia|Guinea.?Bissau|Equatorial Guinea|Grenada|Guatemala|Guam|Guyana|Heard Island and McDonald Islands|Honduras|Haiti|Indonesia|\\bIndia\\b|\\bIran\\b|\\bIraq\\b|Jamaica|Jordan|Kazakhstan|Kenya|Kyrgyzstan|Cambodia|Kiribati|Saint Kitts and Nevis|Kuwait|\\bLao.?\\b|Lebanon|Liberia|Libya|Saint Lucia|Sri Lanka|Lesotho|Macao|Saint Martin|Morocco|Moldova|Madagascar|Maldives|Mexico|Marshall Islands|North Macedonia|\\bMali\\b|Myanmar|Montenegro|Mongolia|Northern Mariana Islands|Mozambique|Mauritania|Montserrat|Mauritius|Malawi|Malaysia|Namibia|New Caledonia|Niger|Norfolk Island|Nigeria|Nicaragua|Niue|Nepal|Nauru|Oman|Pakistan|Panama|Pitcairn|Peru|Philippines|Palau|Papua New Guinea|Puerto Rico|Paraguay|Palestine|French Polynesia|Qatar|Russia|Rwanda|Sudan|Senegal|Singapore|South Georgia and the South Sandwich Islands|Saint Helena|Solomon Islands|Sierra Leone|El Salvador|Somalia|Serbia|South Sudan|Sao Tome and Principe|Suriname|Eswatini|Sint Maarten|Seychelles|Syrian|Turks and Caicos Islands|Chad|Togo|Thailand|Tajikistan|Turkmenistan|Timor.?Leste|Tonga|Trinidad and Tobago|Tunisia|Turkey|Tanzania|Uganda|Ukraine|Uruguay|Uzbekistan|Saint Vincent and the Grenadines|Venezuela|Virgin Islands|Viet Nam|Vanuatu|Wallis and Futuna|Samoa|Yemen|South Africa|Zambia|Zimbabwe|Somaliland|Kosovo|Ashmore|Cartier|Siachen Glacier|North Korea|\\bABW\\b|\\bAFG\\b|\\bAGO\\b|\\bAIA\\b|\\bALB\\b|\\bARG\\b|\\bARM\\b|\\bASM\\b|\\bATF\\b|\\bATG\\b|\\bAZE\\b|\\bBDI\\b|\\bBEN\\b|\\bBFA\\b|\\bBGD\\b|\\bBHR\\b|\\bBHS\\b|\\bBIH\\b|\\bBLR\\b|\\bBLZ\\b|\\bBOL\\b|\\bBRA\\b|\\bBRB\\b|\\bBRN\\b|\\bBTN\\b|\\bBWA\\b|\\bCAF\\b|\\bCHL\\b|\\bCHN\\b|\\bCIV\\b|\\bCMR\\b|\\bCOD\\b|\\bCOG\\b|\\bCOK\\b|\\bCOL\\b|\\bCOM\\b|\\bCPV\\b|\\bCRI\\b|\\bCUB\\b|\\bCUW\\b|\\bCYM\\b|\\bCYP\\b|\\bCYP\\b|\\bDJI\\b|\\bDMA\\b|\\bDOM\\b|\\bDZA\\b|\\bECU\\b|\\bEGY\\b|\\bERI\\b|\\bESH\\b|\\bETH\\b|\\bFJI\\b|\\bFSM\\b|\\bGAB\\b|\\bGEO\\b|\\bGHA\\b|\\bGIN\\b|\\bGMB\\b|\\bGNB\\b|\\bGNQ\\b|\\bGRD\\b|\\bGTM\\b|\\bGUM\\b|\\bGUY\\b|\\bHMD\\b|\\bHND\\b|\\bHTI\\b|\\bIDN\\b|\\bIND\\b|\\bIRN\\b|\\bIRQ\\b|\\bJAM\\b|\\bJOR\\b|\\bKAZ\\b|\\bKEN\\b|\\bKGZ\\b|\\bKHM\\b|\\bKIR\\b|\\bKNA\\b|\\bKOR\\b|\\bKWT\\b|\\bLAO\\b|\\bLBN\\b|\\bLBR\\b|\\bLBY\\b|\\bLCA\\b|\\bLKA\\b|\\bLSO\\b|\\bMAF\\b|\\bMDA\\b|\\bMDG\\b|\\bMDV\\b|\\bMEX\\b|\\bMHL\\b|\\bMKD\\b|\\bMLI\\b|\\bMMR\\b|\\bMNE\\b|\\bMNG\\b|\\bMNP\\b|\\bMOZ\\b|\\bMRT\\b|\\bMSR\\b|\\bMUS\\b|\\bMWI\\b|\\bMYS\\b|\\bNAM\\b|\\bNCL\\b|\\bNER\\b|\\bNFK\\b|\\bNGA\\b|\\bNIC\\b|\\bNIU\\b|\\bNPL\\b|\\bNRU\\b|\\bOMN\\b|\\bPAK\\b|\\bPAN\\b|\\bPCN\\b|\\bPHL\\b|\\bPLW\\b|\\bPNG\\b|\\bPRK\\b|\\bPRY\\b|\\bPSE\\b|\\bPYF\\b|\\bQAT\\b|\\bRUS\\b|\\bRWA\\b|\\bSDN\\b|\\bSEN\\b|\\bSGP\\b|\\bSGS\\b|\\bSHN\\b|\\bSLB\\b|\\bSLE\\b|\\bSLV\\b|\\bSOM\\b|\\bSRB\\b|\\bSSD\\b|\\bSTP\\b|\\bSUR\\b|\\bSWZ\\b|\\bSXM\\b|\\bSYC\\b|\\bSYR\\b|\\bTCA\\b|\\bTCD\\b|\\bTGO\\b|\\bTHA\\b|\\bTJK\\b|\\bTKM\\b|\\bTLS\\b|\\bTON\\b|\\bTTO\\b|\\bTUN\\b|\\bTUR\\b|\\bTZA\\b|\\bUGA\\b|\\bUKR\\b|\\bURY\\b|\\bUZB\\b|\\bVCT\\b|\\bVEN\\b|\\bVIR\\b|\\bVNM\\b|\\bVUT\\b|\\bWLF\\b|\\bWSM\\b|\\bYEM\\b|\\bZAF\\b|\\bZMB\\b|\\bZWE\\b|global south|Third World|Pacific Alliance))|((?=.*(?:developing|least.?develop\\S*|less.?develop\\S*|underdevel\\S*|\\bpoor|low.?income|lower.?income|small island\\S*|africa\\S*|\\bimpover\\S*|\\bpover\\S*|\\bemergent\\S*))(?=.*(?:countr\\S*|\\bnation.?|\\bstate.?\\b))))).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_b', 'SDG_keywords': '^(?=.*(?:medium.?tech\\S*|high.?tech\\S*))(?=.*(?:value added)).+', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_c', 'SDG_keywords': '^(?!.*(?:Access Bank|Access Line.?|inappropriate access|broadband accesses retail|Internet of Thing)).*(((?:access\\S*|covered by)\\s(?:\\w+\\s){0,8}(?=(?:internet|mobile network.?|cyberspace|information highway|information superhighway|wireless|Phone service.?|broadband|cellular network|\\bICT\\b|\\b5G\\b|\\b4G\\b)))|((?:internet|mobile network.?|cyberspace|information highway|information superhighway|wireless|Phone service.?|broadband|cellular network|\\bICT\\b|\\b5G\\b|\\b4G\\b)\\s(?:\\w+\\s){0,8}(?=(?:access\\S*|covered by))))', 'match_type': 'indirect'}, 
            {'SDG_id': 'SDG9_c', 'SDG_keywords': '^(?!.*(?:Access Bank|Access Line.?|inappropriate access|broadband accesses retail|Internet of Thing))(?=.*(?:\\btech\\S*)).+(((?:access\\S*|covered by)\\s(?:\\w+\\s){0,8}(?=(?:information|communication.?)))|((?:information|communication.?)\\s(?:\\w+\\s){0,8}(?=(?:access\\S*|covered by))))', 'match_type': 'indirect'}]
